@@ -99,6 +99,7 @@ class DiskRestoreConfig(util.RestrictedDict):
         "Size",
         "ProvisionedThroughput",
         "StoragePool",
+        "ClearOverridesFieldMask",
     ]
     super(DiskRestoreConfig, self).__init__(supported_flags, *args, **kwargs)
 
@@ -552,6 +553,12 @@ class BackupsClient(util.BackupDrClientBase):
           )
       )
 
+    # ClearOverridesFieldMask
+    if "ClearOverridesFieldMask" in restore_config:
+      restore_request.clearOverridesFieldMask = restore_config[
+          "ClearOverridesFieldMask"
+      ]
+
     # GuestOsFeatures
     if "GuestOsFeatures" in restore_config:
       guest_os_features = []
@@ -585,3 +592,20 @@ class BackupsClient(util.BackupDrClientBase):
         requestId=request_id,
     )
     return self.service.Patch(request)
+
+  def FetchForResourceType(
+      self,
+      resource,
+      resource_type,
+      filter_expression=None,
+      page_size=None,
+      order_by=None,
+  ):
+    request = self.messages.BackupdrProjectsLocationsBackupVaultsDataSourcesBackupsFetchForResourceTypeRequest(
+        parent=resource.RelativeName(),
+        resourceType=resource_type,
+        pageSize=page_size,
+        filter=filter_expression,
+        orderBy=order_by,
+    )
+    return self.service.FetchForResourceType(request)
