@@ -26,6 +26,7 @@ from apitools.base.py import encoding as apitools_encoding
 from googlecloudsdk.api_lib.cloudbuild import cloudbuild_exceptions
 from googlecloudsdk.api_lib.util import apis
 from googlecloudsdk.calliope import base
+from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.core import yaml
 from googlecloudsdk.core.resource import resource_property
 from googlecloudsdk.core.util import files
@@ -86,13 +87,20 @@ def GetClientClass(release_track=base.ReleaseTrack.GA):
                              RELEASE_TRACK_TO_API_VERSION[release_track])
 
 
-def GetClientInstance(release_track=base.ReleaseTrack.GA, use_http=True):
+def GetClientInstance(
+    release_track=base.ReleaseTrack.GA,
+    use_http=True,
+    skip_activation_prompt=False,
+):
   """Returns an instance of the Cloud Build client.
 
   Args:
     release_track: The desired value of the enum
       googlecloudsdk.calliope.base.ReleaseTrack.
     use_http: bool, True to create an http object for this client.
+    skip_activation_prompt: bool, True to skip prompting for service activation.
+      Should be used only if service activation was checked earlier in the
+      command.
 
   Returns:
     base_api.BaseApiClient, An instance of the Cloud Build client.
@@ -100,7 +108,9 @@ def GetClientInstance(release_track=base.ReleaseTrack.GA, use_http=True):
   return apis.GetClientInstance(
       _API_NAME,
       RELEASE_TRACK_TO_API_VERSION[release_track],
-      no_http=(not use_http))
+      no_http=(not use_http),
+      skip_activation_prompt=skip_activation_prompt,
+  )
 
 
 def EncodeSubstitutions(substitutions, messages):
@@ -111,16 +121,14 @@ def EncodeSubstitutions(substitutions, messages):
       substitutions, messages.Build.SubstitutionsValue, sort_items=True)
 
 
-def EncodeTriggerSubstitutions(substitutions, messages):
+def EncodeTriggerSubstitutions(substitutions, value_type):
   if not substitutions:
     return None
   substitution_properties = []
   for key, value in sorted(six.iteritems(substitutions)):  # Sort for tests
     substitution_properties.append(
-        messages.BuildTrigger.SubstitutionsValue.AdditionalProperty(
-            key=key, value=value))
-  return messages.BuildTrigger.SubstitutionsValue(
-      additionalProperties=substitution_properties)
+        value_type.AdditionalProperty(key=key, value=value))
+  return value_type(additionalProperties=substitution_properties)
 
 
 def EncodeUpdatedTriggerSubstitutions(old_substitutions, substitutions,
@@ -634,8 +642,18 @@ def BitbucketServerConfigFromArgs(args, update=False):
   secret_location.webhookSecretVersionName = args.webhook_secret_secret_version
   if update or secret_location is not None:
     bbs.secrets = secret_location
-  if not update and args.peered_network is not None:
-    bbs.peeredNetwork = args.peered_network
+  if not update:
+    if args.peered_network is None and args.peered_network_ip_range is not None:
+      raise c_exceptions.RequiredArgumentException(
+          'peered-network-ip-range',
+          (
+              '--peered-network is required when specifying'
+              ' --peered-network-ip-range.'
+          ),
+      )
+    if args.peered_network is not None:
+      bbs.peeredNetwork = args.peered_network
+      bbs.peeredNetworkIpRange = args.peered_network_ip_range
   if args.IsSpecified('ssl_ca_file'):
     bbs.sslCa = args.ssl_ca_file
   return bbs
