@@ -470,189 +470,6 @@ class Orders(object):
       raise exceptions.HttpException(error)
 
 
-class OrderAllocations(object):
-  """The Order Allocations set of Commerce Procurement Consumer API functions."""
-
-  CREATE_REQUEST = GetMessagesModule(
-  ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsCreateRequest
-  DELETE_REQUEST = GetMessagesModule(
-  ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsDeleteRequest
-  GET_REQUEST = GetMessagesModule(
-  ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsGetRequest
-  LIST_REQUEST = GetMessagesModule(
-  ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsListRequest
-  UPDATE_REQUEST = GetMessagesModule(
-  ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsPatchRequest
-
-  @staticmethod
-  def GetService():
-    return GetClientInstance().billingAccounts_orders_orderAllocations
-
-  @staticmethod
-  def Create(order_name, display_name, int64_resource_value,
-             double_resource_value, string_resource_value, targets):
-    """Calls the Procurement Consumer OrdersAllocations.Create method.
-
-    Args:
-      order_name: Name of parent order.
-      display_name: Display name of the order allocation.
-      int64_resource_value: Resource value in int64 type.
-      double_resource_value: Resource value in double type.
-      string_resource_value: Resource value in string type.
-      targets: Targets of the order allocation.
-
-    Returns:
-      (Order Allocation operation)
-    """
-
-    target_list = []
-    for target in targets:
-      target_list.append(target)
-
-    alloc_entry_cls = GetMessagesModule(
-    ).GoogleCloudCommerceConsumerProcurementV1alpha1OrderAllocationAllocationEntry
-    alloc_entry = None
-    if int64_resource_value:
-      alloc_entry = alloc_entry_cls(
-          int64ResourceValue=int64_resource_value, targets=target_list)
-    elif double_resource_value:
-      alloc_entry = alloc_entry_cls(
-          doubleResourceValue=double_resource_value, targets=target_list)
-    elif string_resource_value:
-      alloc_entry = alloc_entry_cls(
-          stringResourceValue=string_resource_value, targets=target_list)
-    else:
-      raise ValueError('No resource value specified.')
-
-    order_allocation = GetMessagesModule(
-    ).GoogleCloudCommerceConsumerProcurementV1alpha1OrderAllocation(
-        displayName=display_name, allocationEntry=alloc_entry)
-
-    request = GetMessagesModule(
-    ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsCreateRequest(
-        parent=order_name,
-        googleCloudCommerceConsumerProcurementV1alpha1OrderAllocation=order_allocation
-    )
-
-    try:
-      return OrderAllocations.GetService().Create(request)
-    except apitools_exceptions.HttpError as error:
-      raise exceptions.HttpException(error)
-
-  @staticmethod
-  def Delete(order_allocation_name):
-    """Calls the Procurement Consumer OrderAllocations.Delete method.
-
-    Args:
-      order_allocation_name: Name of an order allocation.
-
-    Returns:
-      (Operation)
-    """
-    request = GetMessagesModule(
-    ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsDeleteRequest(
-        name=order_allocation_name)
-    try:
-      return OrderAllocations.GetService().Delete(request)
-    except apitools_exceptions.HttpError as error:
-      raise exceptions.HttpException(error)
-
-  @staticmethod
-  def Get(order_allocation_name):
-    """Calls the Procurement Consumer OrderAllocations.Get method.
-
-    Args:
-      order_allocation_name: Name of an order allocation.
-
-    Returns:
-      (OrderAllocation)
-    """
-    request = GetMessagesModule(
-    ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsGetRequest(
-        name=order_allocation_name)
-    try:
-      return OrderAllocations.GetService().Get(request)
-    except apitools_exceptions.HttpError as error:
-      raise exceptions.HttpException(error)
-
-  @staticmethod
-  def List(order_name, page_size, page_token):
-    """Calls the Procurement Consumer OrderAllocations.List method.
-
-    Args:
-      order_name: Name of an order allocation.
-      page_size: Max size of records to be retrieved in page.
-      page_token: Token to specify page in list.
-
-    Returns:
-      List of order allocations and next page token if applicable.
-    """
-    request = GetMessagesModule(
-    ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsListRequest(
-        parent=order_name, pageSize=page_size, pageToken=page_token)
-    try:
-      return OrderAllocations.GetService().List(request)
-    except apitools_exceptions.HttpError as error:
-      raise exceptions.HttpException(error)
-
-  @staticmethod
-  def Update(order_allocation_name, display_name, int64_resource_value,
-             double_resource_value, string_resource_value, targets,
-             update_mask):
-    """Calls the Procurement Consumer OrdersAllocations.Update method.
-
-    Args:
-      order_allocation_name: Name of order allocation.
-      display_name: Display name of the order allocation.
-      int64_resource_value: Resource value in int64 type.
-      double_resource_value: Resource value in double type.
-      string_resource_value: Resource value in string type.
-      targets: Targets of the order allocation.
-      update_mask: Update mask for this request.
-
-    Returns:
-      (Operation)
-    """
-
-    if targets:
-      target_list = []
-      for target in targets:
-        target_list.append(target)
-
-      alloc_entry_cls = GetMessagesModule(
-      ).GoogleCloudCommerceConsumerProcurementV1alpha1OrderAllocationAllocationEntry
-      alloc_entry = None
-      if int64_resource_value:
-        alloc_entry = alloc_entry_cls(
-            int64ResourceValue=int64_resource_value, targets=target_list)
-      elif double_resource_value:
-        alloc_entry = alloc_entry_cls(
-            doubleResourceValue=double_resource_value, targets=target_list)
-      elif string_resource_value:
-        alloc_entry = alloc_entry_cls(
-            stringResourceValue=string_resource_value, targets=target_list)
-      else:
-        raise ValueError('No resource value specified.')
-
-      order_allocation = GetMessagesModule(
-      ).GoogleCloudCommerceConsumerProcurementV1alpha1OrderAllocation(
-          displayName=display_name, allocationEntry=alloc_entry)
-    else:
-      order_allocation = None
-
-    request = GetMessagesModule(
-    ).CloudcommerceconsumerprocurementBillingAccountsOrdersOrderAllocationsPatchRequest(
-        name=order_allocation_name,
-        updateMask=update_mask,
-        googleCloudCommerceConsumerProcurementV1alpha1OrderAllocation=order_allocation
-    )
-
-    try:
-      return OrderAllocations.GetService().Patch(request)
-    except apitools_exceptions.HttpError as error:
-      raise exceptions.HttpException(error)
-
-
 class Operations(object):
   """The Operations set of Commerce Procurement Consumer API functions."""
 
