@@ -82,6 +82,14 @@ _HUMAN_FRIENDLY_OPERATION_TYPE_SUFFIXES = {
         'past': 'deleted',
         'present': 'delete'
     },
+    'releaseExternalIpv6Address': {
+        'past': 'deleted',
+        'present': 'delete'
+    },
+    'reserveExternalIpv6Address': {
+        'past': 'created',
+        'present': 'create'
+    },
     'insert': {
         'past': 'created',
         'present': 'create'
@@ -106,7 +114,8 @@ _HUMAN_FRIENDLY_OPERATION_TYPE_SUFFIXES = {
 # format:
 # reservations/<reservation-name>/<reservation-block-name>/<reservation-subblock-name>.
 _MULTI_NESTED_RESOURCE_OPERATION_TYPES = [
-    'ReservationSubBlocks.performMaintenance'
+    'ReservationSubBlocks.performMaintenance',
+    'ReservationSubBlocks.reportFaulty',
 ]
 
 
