@@ -299,15 +299,16 @@ class ConnectionProfilesClient(object):
       )
 
   def _GetSslConfig(self, args):
+    ssl_type = None
+    if self._SupportsSslType() and args.IsSpecified('ssl_type'):
+      ssl_type = self.messages.SslConfig.TypeValueValuesEnum.lookup_by_name(
+          args.ssl_type
+      )
     return self.messages.SslConfig(
         clientKey=args.private_key,
         clientCertificate=args.GetValue(self._ClientCertificateArgName()),
         caCertificate=args.ca_certificate,
-        type=self.messages.SslConfig.TypeValueValuesEnum.lookup_by_name(
-            args.ssl_type
-        )
-        if self._SupportsSslType() and args.IsSpecified('ssl_type')
-        else None,
+        type=ssl_type,
     )
 
   def _UpdateMySqlSslConfig(self, connection_profile, args, update_fields):
@@ -463,20 +464,31 @@ class ConnectionProfilesClient(object):
         alloydbClusterId=alloydb_cluster,
     )
 
-    private_service_connect_connectivity_ref = (
-        args.CONCEPTS.psc_service_attachment.Parse()
-    )
-    if private_service_connect_connectivity_ref:
-      psc_relative_name = (
-          private_service_connect_connectivity_ref.RelativeName()
+    if args.IsKnownAndSpecified('enable_iam_authentication'):
+      connection_profile_obj.enableIamAuthentication = bool(
+          args.enable_iam_authentication
       )
-      connection_profile_obj.privateServiceConnectConnectivity = (
-          self.messages.PrivateServiceConnectConnectivity(
-              serviceAttachment=psc_relative_name
+
+    if args.IsKnownAndSpecified('private_connection'):
+      private_connectivity = args.CONCEPTS.private_connection.Parse()
+      connection_profile_obj.privateConnectivity = (
+          self.messages.PrivateConnectivity(
+              privateConnection=private_connectivity.RelativeName()
           )
       )
-    elif args.static_ip_connectivity:
+    elif args.IsKnownAndSpecified('forward_ssh_hostname'):
+      connection_profile_obj.forwardSshConnectivity = (
+          self._GetForwardSshTunnelConnectivity(args)
+      )
+    elif args.IsKnownAndSpecified('static_ip_connectivity'):
       connection_profile_obj.staticIpConnectivity = {}
+    elif args.IsKnownAndSpecified('psc_service_attachment'):
+      psc_ref = args.CONCEPTS.psc_service_attachment.Parse()
+      connection_profile_obj.privateServiceConnectConnectivity = (
+          self.messages.PrivateServiceConnectConnectivity(
+              serviceAttachment=psc_ref.RelativeName()
+          )
+      )
     return connection_profile_obj
 
   def _UpdatePostgreSqlConnectionProfile(self, connection_profile, args,
@@ -497,6 +509,11 @@ class ConnectionProfilesClient(object):
     if args.IsSpecified('password'):
       connection_profile.postgresql.password = args.password
       update_fields.append('postgresql.password')
+    if args.IsKnownAndSpecified('enable_iam_authentication'):
+      connection_profile.postgresql.enableIamAuthentication = bool(
+          args.enable_iam_authentication
+      )
+      update_fields.append('postgresql.enable_iam_authentication')
     if args.IsSpecified(self._InstanceArgName()):
       connection_profile.postgresql.cloudSqlId = args.GetValue(
           self._InstanceArgName())
@@ -589,6 +606,15 @@ class ConnectionProfilesClient(object):
     if args.IsSpecified('cloudsql_project_id'):
       connection_profile.sqlserver.cloudSqlProjectId = args.cloudsql_project_id
       update_fields.append('sqlserver.cloudSqlProjectId')
+    if args.IsSpecified('host'):
+      connection_profile.sqlserver.host = args.host
+      update_fields.append('sqlserver.host')
+    if args.IsSpecified('port'):
+      connection_profile.sqlserver.port = args.port
+      update_fields.append('sqlserver.port')
+    if args.IsSpecified('dbm_port'):
+      connection_profile.sqlserver.dbmPort = args.dbm_port
+      update_fields.append('sqlserver.dbmPort')
     if args.IsSpecified('username'):
       connection_profile.sqlserver.username = args.username
       update_fields.append('sqlserver.username')
@@ -878,6 +904,8 @@ class ConnectionProfilesClient(object):
     if args.IsKnownAndSpecified('host'):
       connection_profile_obj.host = args.host
       connection_profile_obj.port = args.port
+      if args.IsKnownAndSpecified('dbm_port'):
+        connection_profile_obj.dbmPort = args.dbm_port
     elif args.IsKnownAndSpecified('gcs_bucket'):
       connection_profile_obj.backups = self._GetSqlServerBackups(args)
 
@@ -907,6 +935,13 @@ class ConnectionProfilesClient(object):
       )
     elif args.IsKnownAndSpecified('static_ip_connectivity'):
       connection_profile_obj.staticIpConnectivity = {}
+    elif args.IsKnownAndSpecified('psc_service_attachment'):
+      psc_ref = args.CONCEPTS.psc_service_attachment.Parse()
+      connection_profile_obj.privateServiceConnectConnectivity = (
+          self.messages.PrivateServiceConnectConnectivity(
+              serviceAttachment=psc_ref.RelativeName()
+          )
+      )
     return connection_profile_obj
 
   def _GetConnectionProfile(self, cp_type, args, connection_profile_id):
