@@ -94,7 +94,9 @@ class VersionsClient(object):
 
   def Patch(self, version_ref, labels_update, description=None,
             prediction_class_update=None, package_uris=None,
-            manual_scaling_nodes=None, auto_scaling_min_nodes=None):
+            manual_scaling_nodes=None, auto_scaling_min_nodes=None,
+            auto_scaling_max_nodes=None, sampling_percentage=None,
+            bigquery_table_name=None):
     """Update a version."""
     version = self.messages.GoogleCloudMlV1Version()
     update_mask = []
@@ -124,6 +126,27 @@ class VersionsClient(object):
       version.autoScaling = self.messages.GoogleCloudMlV1AutoScaling(
           minNodes=auto_scaling_min_nodes)
 
+    if auto_scaling_max_nodes is not None:
+      update_mask.append('autoScaling.maxNodes')
+      if version.autoScaling is not None:
+        version.autoScaling.maxNodes = auto_scaling_max_nodes
+      else:
+        version.autoScaling = self.messages.GoogleCloudMlV1AutoScaling(
+            maxNodes=auto_scaling_max_nodes)
+
+    if bigquery_table_name is not None:
+      update_mask.append('requestLoggingConfig')
+      version.requestLoggingConfig = self.messages.GoogleCloudMlV1RequestLoggingConfig(
+          bigqueryTableName=bigquery_table_name)
+
+    if sampling_percentage is not None:
+      if 'requestLoggingConfig' not in update_mask:
+        update_mask.append('requestLoggingConfig')
+        version.requestLoggingConfig = self.messages.GoogleCloudMlV1RequestLoggingConfig(
+            samplingPercentage=sampling_percentage)
+      else:
+        version.requestLoggingConfig.samplingPercentage = sampling_percentage
+
     if not update_mask:
       raise NoFieldsSpecifiedError('No updates requested.')
 
@@ -233,7 +256,36 @@ class VersionsClient(object):
           health=kwargs['health_route']
       )
 
-  def BuildVersion(self, name,
+  def _ConfigureAutoScaling(self, version, **kwargs):
+    """Adds `auto_scaling` fields to version."""
+    if not any(kwargs.values()):
+      # Nothing related to containers was specified!
+      return
+
+    version.autoScaling = self.messages.GoogleCloudMlV1AutoScaling()
+    if kwargs['min_nodes']:
+      version.autoScaling.minNodes = kwargs['min_nodes']
+    if kwargs['max_nodes']:
+      version.autoScaling.maxNodes = kwargs['max_nodes']
+    if kwargs['metrics']:
+      version.autoScaling.metrics = []
+      if 'cpu-usage' in kwargs['metrics']:
+        t = int(kwargs['metrics']['cpu-usage'])
+        version.autoScaling.metrics.append(
+            self.messages.GoogleCloudMlV1MetricSpec(
+                name=self.messages.GoogleCloudMlV1MetricSpec.NameValueValuesEnum
+                .CPU_USAGE,
+                target=t))
+      if 'gpu-duty-cycle' in kwargs['metrics']:
+        t = int(kwargs['metrics']['gpu-duty-cycle'])
+        version.autoScaling.metrics.append(
+            self.messages.GoogleCloudMlV1MetricSpec(
+                name=self.messages.GoogleCloudMlV1MetricSpec.NameValueValuesEnum
+                .GPU_DUTY_CYCLE,
+                target=t))
+
+  def BuildVersion(self,
+                   name,
                    path=None,
                    deployment_uri=None,
                    runtime_version=None,
@@ -256,7 +308,11 @@ class VersionsClient(object):
                    ports=None,
                    predict_route=None,
                    health_route=None,
-                   containers_hidden=True):
+                   min_nodes=None,
+                   max_nodes=None,
+                   metrics=None,
+                   containers_hidden=True,
+                   autoscaling_hidden=True):
     """Create a Version object.
 
     The object is based on an optional YAML configuration file and the
@@ -299,8 +355,14 @@ class VersionsClient(object):
         are sent to.
       health_route: The HTTP path within the container that health checks are
         sent to.
-      containers_hidden: Whether or not container-related fields are hidden
-        on this track.
+      min_nodes: The minimum number of nodes to scale this model under load.
+      max_nodes: The maximum number of nodes to scale this model under load.
+      metrics: List of key-value pairs to set as metrics' target for
+        autoscaling.
+      containers_hidden: Whether or not container-related fields are hidden on
+        this track.
+      autoscaling_hidden: Whether or not autoscaling fields are hidden on this
+        track.
 
     Returns:
       A Version object (for the corresponding API version).
@@ -362,6 +424,10 @@ class VersionsClient(object):
           predict_route=predict_route,
           health_route=health_route)
 
+    if not autoscaling_hidden:
+      self._ConfigureAutoScaling(
+          version, min_nodes=min_nodes, max_nodes=max_nodes, metrics=metrics)
+
     for field_name, value in additional_fields.items():
       if value is not None:
         setattr(version, field_name, value)
