@@ -723,6 +723,16 @@ def AddMachineType(parser, required=False):
       'c4a-highmem-48-lssd',
       'c4a-highmem-64-lssd',
       'c4a-highmem-72-lssd',
+      'c4-highmem-4-lssd',
+      'c4-highmem-8-lssd',
+      'c4-highmem-16-lssd',
+      'c4-highmem-24-lssd',
+      'c4-highmem-32-lssd',
+      'c4-highmem-48-lssd',
+      'c4-highmem-96-lssd',
+      'c4-highmem-144-lssd',
+      'c4-highmem-192-lssd',
+      'c4-highmem-288-lssd',
       'z3-highmem-14-standardlssd',
       'z3-highmem-22-standardlssd',
       'z3-highmem-44-standardlssd',
@@ -1749,12 +1759,13 @@ def AddRequireConnectors(parser):
   )
 
 
-def AddDatabaseVersion(parser, alloydb_messages):
+def AddDatabaseVersion(parser, alloydb_messages, release_track):
   """Adds Database Version flag.
 
   Args:
     parser: argparse.Parser: Parser object for command line inputs.
     alloydb_messages: Message module.
+    release_track: The command version being used - GA/BETA/ALPHA.
   """
   choices = [
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_14,
@@ -1762,6 +1773,10 @@ def AddDatabaseVersion(parser, alloydb_messages):
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_16,
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_17,
   ]
+  if release_track in (base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA):
+    choices.append(
+        alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_18
+    )
   parser.add_argument(
       '--database-version',
       required=False,
@@ -1913,7 +1928,6 @@ def AddMaintenanceVersion(parser):
       '--maintenance-version',
       required=False,
       type=str,
-      hidden=True,
       help=(
           'Maintenance version to update the cluster to. Use `latest` to'
           ' apply the latest available maintenance version.'
@@ -2403,3 +2417,128 @@ def AddMigrateCloudSqlFlags(parser: argparse.PARSER) -> None:
           ' backup ID (myBackup).'
       ),
   )
+
+
+def _AddAutoscalerFlags(group):
+  """Add Autoscaler specific flags to the group."""
+  group.add_argument(
+      '--enable-autoscaler',
+      required=False,
+      action=arg_parsers.StoreTrueFalseAction,
+      help='Enable autoscaler for the instance.',
+  )
+
+  group.add_argument(
+      '--autoscaler-max-node-count',
+      required=False,
+      type=arg_parsers.BoundedInt(lower_bound=1, upper_bound=20),
+      default=None,
+      help='Maximum node count for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-cool-down-period-seconds',
+      required=False,
+      type=arg_parsers.Duration(parsed_unit='s'),
+      default=None,
+      help='Cool down period in seconds for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-target-cpu-usage',
+      required=False,
+      type=arg_parsers.BoundedFloat(lower_bound=0, upper_bound=1),
+      default=None,
+      help='Target CPU usage for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-set-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to create or update for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-cron-exp',
+      required=False,
+      type=str,
+      default=None,
+      help='Cron expression for the autoscaler schedule.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-duration-seconds',
+      required=False,
+      type=arg_parsers.Duration(parsed_unit='s'),
+      default=None,
+      help='Duration for which the autoscaler schedule is active in seconds.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-time-zone',
+      required=False,
+      type=str,
+      default=None,
+      help='Time zone for the autoscaler schedule.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-min-node-count',
+      required=False,
+      type=int,
+      default=None,
+      help='Minimum node count for the autoscaler schedule.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-description',
+      required=False,
+      type=str,
+      default=None,
+      help='Description for the autoscaler schedule.',
+  )
+
+
+def AddAutoscalerCreateFlags(parser):
+  """Add Autoscaler specific flags for create command.
+
+  Args:
+    parser: argparse.Parser: Parser object for command line inputs.
+  """
+  group = parser.add_group(help='Autoscaler flags.', hidden=True)
+  _AddAutoscalerFlags(group)
+
+
+def AddAutoscalerUpdateFlags(parser):
+  """Add Autoscaler specific flags for update command.
+
+  Args:
+    parser: argparse.Parser: Parser object for command line inputs.
+  """
+  group = parser.add_group(help='Autoscaler flags.', hidden=True)
+  _AddAutoscalerFlags(group)
+  group.add_argument(
+      '--autoscaler-delete-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to delete for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-disable-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to disable for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-enable-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to enable for the autoscaler.',
+  )
