@@ -39,6 +39,13 @@ For more details on max_instances, see
 <https://cloud.google.com/appengine/docs/standard/reference/app-yaml.md#scaling_elements>.
 """
 
+TRY_CLOUD_RUN_NUDGE_MSG = """\
+Cloud Run offers the most modern fully managed application hosting experience
+with lower minimum billable times and support for GPUs on demand for your AI/ML workloads.
+Deploy code written in any programming language supported by App Engine on Cloud Run.
+Learn more at https://cloud.google.com/run/docs/quickstarts#build-and-deploy-a-web-service
+"""
+
 
 class UnspecifiedRegionError(exceptions.Error):
   """Region is not provided on the command line and running interactively."""
@@ -155,6 +162,8 @@ def CreateApp(
     log.warning(APP_CREATE_WARNING)
     # TODO: b/388712720 - Cleanup warning once backend experiments are cleaned
     log.warning(DEFAULT_MAX_INSTANCES_FORWARD_CHANGE_WARNING)
+
+    log.status.Print('NOTE: ' + TRY_CLOUD_RUN_NUDGE_MSG)
   try:
     api_client.CreateApp(
         region, service_account=service_account, ssl_policy=ssl_policy_enum
@@ -208,14 +217,18 @@ def CreateAppInteractively(
   # TODO: b/388712720 - Cleanup warning once backend experiments are cleaned
   log.warning(DEFAULT_MAX_INSTANCES_FORWARD_CHANGE_WARNING)
 
+  log.status.Print('NOTE: ' + TRY_CLOUD_RUN_NUDGE_MSG)
   regions = regions or sorted(set(api_client.ListRegions()), key=str)
   if extra_warning:
     log.warning(extra_warning)
   idx = console_io.PromptChoice(
       regions,
-      message=('Please choose the region where you want your App Engine '
-               'application located:\n\n'),
-      cancel_option=True)
+      message=(
+          'Please choose the region where you want your App Engine '
+          'application located:\n\n'
+      ),
+      cancel_option=True,
+  )
   region = regions[idx]
   CreateApp(
       api_client,
