@@ -19,6 +19,7 @@ from __future__ import unicode_literals
 
 import json
 
+from apitools.base.py import encoding as apitools_encoding
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.artifacts import exceptions as ar_exceptions
 from googlecloudsdk.core import log
@@ -47,23 +48,66 @@ def ParseCleanupPolicy(path):
   except ValueError as e:
     raise apitools_exceptions.InvalidUserInputError(
         'Could not read JSON file {}: {}'.format(path, e))
+  if not isinstance(file_policies, list):
+    raise apitools_exceptions.InvalidUserInputError(
+        'Policy file must contain a list of policies.'
+    )
   policies = dict()
-  for policy in file_policies:
-    for key in ['name', 'action', 'condition']:
-      if key not in policy:
-        raise ar_exceptions.InvalidInputValueError(
-            'Key "{}" not found in policy.'.format(key))
-    if 'type' not in policy['action']:
+  for i in range(len(file_policies)):
+    policy = file_policies[i]
+    if not isinstance(policy, dict):
+      raise apitools_exceptions.InvalidUserInputError(
+          'Invalid policy at index {}.'.format(i)
+      )
+    name = policy.get('name')
+    if name is None:
       raise ar_exceptions.InvalidInputValueError(
-          'Key "type" not found in policy action.')
-    condition = dict()
-    if 'versionAge' in policy['condition']:
-      seconds = times.ParseDuration(policy['condition']['versionAge'])
-      condition['versionAge'] = six.text_type(seconds.total_seconds) + 's'
-    policies[policy['name']] = {
-        'id': policy['name'],
+          'Key "name" not found in policy.'
+      )
+    if name in policies:
+      raise ar_exceptions.InvalidInputValueError(
+          'Duplicate key "{}" in policy list.'.format(name)
+      )
+    action = policy.get('action')
+    if action is None:
+      raise ar_exceptions.InvalidInputValueError(
+          'Key "action" not found in policy "{}".'.format(name)
+      )
+    try:
+      action = action.get('type', '')
+    except AttributeError as error:
+      six.raise_from(
+          ar_exceptions.InvalidInputValueError(
+              'Invalid action "{}" in policy "{}".'.format(action, name)
+          ),
+          error,
+      )
+    condition = policy.get('condition')
+    if condition is not None:
+      if not isinstance(condition, dict):
+        raise ar_exceptions.InvalidInputValueError(
+            'Invalid value for "condition" in policy "{}".'.format(name)
+        )
+      for duration_key in ['versionAge', 'olderThan', 'newerThan']:
+        if duration_key in condition:
+          seconds = times.ParseDuration(condition[duration_key])
+          condition[duration_key] = six.text_type(seconds.total_seconds) + 's'
+    most_recent_versions = policy.get('mostRecentVersions')
+    if 'condition' not in policy and 'mostRecentVersions' not in policy:
+      raise ar_exceptions.InvalidInputValueError(
+          'Key "condition" or "mostRecentVersions" not found in policy "{}".'
+          .format('name')
+      )
+    if 'condition' in policy and 'mostRecentVersions' in policy:
+      raise ar_exceptions.InvalidInputValueError(
+          'Only one of "condition" or "mostRecentVersions" '
+          'allowed in policy "{}".'.format(name)
+      )
+    policies[name] = {
+        'id': name,
+        'action': action,
         'condition': condition,
-        'action': policy['action']['type'],
+        'mostRecentVersions': most_recent_versions,
     }
   return policies
 
@@ -75,18 +119,20 @@ def SetDeleteCleanupPolicyUpdateMask(unused_ref, unused_args, request):
 
 
 def RepositoryToCleanupPoliciesResponse(response, unused_args):
-  if not response.cleanupPolicies:
-    log.status.Print('No cleanup policies set.')
-    return None
-  return response.cleanupPolicies.additionalProperties
-
-
-def SetOverwriteMask(unused_ref, args, request):
-  if args.overwrite:
-    request.updateMask = None
+  """Formats Cleanup Policies output and displays Dry Run status."""
+  if response.cleanupPolicyDryRun:
+    log.status.Print('Dry run is enabled.')
   else:
-    request.updateMask = 'cleanup_policies'
-  return request
+    log.status.Print('Dry run is disabled.')
+  if not response.cleanupPolicies:
+    return []
+  policies = apitools_encoding.MessageToDict(response.cleanupPolicies)
+  sorted_policies = sorted(policies.values(), key=lambda p: p['id'])
+  for policy in sorted_policies:
+    policy['name'] = policy['id']
+    del policy['id']
+    policy['action'] = {'type': policy['action']}
+  return sorted_policies
 
 
 def DeleteCleanupPolicyFields(unused_ref, args, request):
@@ -96,6 +142,6 @@ def DeleteCleanupPolicyFields(unused_ref, args, request):
     for policy in request.repository.cleanupPolicies.additionalProperties:
       if policy.key not in removed_policies:
         remaining_policies.append(policy)
-  request.repository.cleanupPolicies.additionalProperties = remaining_policies
+    request.repository.cleanupPolicies.additionalProperties = remaining_policies
   request.updateMask = None
   return request
