@@ -15,6 +15,8 @@
 
 """Utility functions for clusters command group."""
 
+from __future__ import annotations
+
 import collections
 import os
 import re
@@ -110,10 +112,11 @@ class ClusterUtil:
     """Makes a cluster message with network fields."""
     networks = self.message_module.Cluster.NetworkResourcesValue()
     if self.args.IsSpecified("create_network"):
-      network_name = self._GetNetworkName(self.args.create_network.get("name"))
+      network_id = self.args.create_network.get("name")
+      network_name = self._GetNetworkName(network_id)
       networks.additionalProperties.append(
           self.message_module.Cluster.NetworkResourcesValue.AdditionalProperty(
-              key=f"net-{network_name}",
+              key=f"net-{network_id}",
               value=self.message_module.NetworkResource(
                   config=self.message_module.NetworkResourceConfig(
                       newNetwork=self.message_module.NewNetworkConfig(
@@ -127,10 +130,11 @@ class ClusterUtil:
           )
       )
     if self.args.IsSpecified("network") and self.args.IsSpecified("subnet"):
-      network_name = self._GetNetworkName(self.args.network)
+      network_id = self.args.network
+      network_name = self._GetNetworkName(network_id)
       networks.additionalProperties.append(
           self.message_module.Cluster.NetworkResourcesValue.AdditionalProperty(
-              key=f"net-{network_name}",
+              key=f"net-{network_id}",
               value=self.message_module.NetworkResource(
                   config=self.message_module.NetworkResourceConfig(
                       existingNetwork=self.message_module.ExistingNetworkConfig(
@@ -417,6 +421,7 @@ class ClusterUtil:
   def MakeClusterPatch(self):
     """Returns the cluster patch message and update mask."""
     cluster = self.MakeClusterBasicPatch()
+    cluster.storageResources = self.MakeClusterStoragesPatch()
     cluster.computeResources = self.MakeClusterComputePatch()
     cluster.orchestrator = self.message_module.Orchestrator(
         slurm=self.MakeClusterSlurmOrchestratorPatch(cluster)
@@ -448,6 +453,317 @@ class ClusterUtil:
       self.update_mask.add("labels")
     return cluster
 
+  def MakeClusterStoragesPatch(self):
+    """Makes a cluster patch message with storage fields."""
+    storage_resources = self.message_module.Cluster.StorageResourcesValue()
+    storages = self._ConvertMessageToDict(
+        self.existing_cluster.storageResources
+    )
+    is_storage_updated = False
+
+    if self.args.IsSpecified("remove_filestore_instances"):
+      filestores_to_remove = {
+          self._GetFilestoreName(f)
+          for f in self.args.remove_filestore_instances
+      }
+      storage_ids_to_remove = set()
+      found_filestores = set()
+
+      for storage_id, storage_resource in storages.items():
+        config = storage_resource.config
+        filestore_name = None
+        if config and config.newFilestore:
+          filestore_name = config.newFilestore.filestore
+        elif config and config.existingFilestore:
+          filestore_name = config.existingFilestore.filestore
+
+        if filestore_name in filestores_to_remove:
+          storage_ids_to_remove.add(storage_id)
+          found_filestores.add(filestore_name)
+
+      if found_filestores != filestores_to_remove:
+        not_found = filestores_to_remove - found_filestores
+        raise exceptions.ToolException(
+            f"Filestore(s) not found: {', '.join(not_found)}"
+        )
+
+      for storage_id in storage_ids_to_remove:
+        storages.pop(storage_id)
+      is_storage_updated = True
+
+    if self.args.IsSpecified("remove_storage_buckets"):
+      buckets_to_remove = set(self.args.remove_storage_buckets)
+      storage_ids_to_remove = set()
+      found_buckets = set()
+
+      for storage_id, storage_resource in storages.items():
+        config = storage_resource.config
+        bucket_name = None
+        if config:
+          if config.newBucket:
+            bucket_name = config.newBucket.bucket
+          elif config.existingBucket:
+            bucket_name = config.existingBucket.bucket
+
+        if bucket_name in buckets_to_remove:
+          storage_ids_to_remove.add(storage_id)
+          found_buckets.add(bucket_name)
+
+      if found_buckets != buckets_to_remove:
+        not_found = buckets_to_remove - found_buckets
+        raise exceptions.ToolException(
+            "Cloud Storage bucket(s) not found:"
+            f" {', '.join(sorted(list(not_found)))}"
+        )
+
+      for storage_id in storage_ids_to_remove:
+        storages.pop(storage_id)
+      is_storage_updated = True
+
+    if self.args.IsSpecified("remove_lustre_instances"):
+      lustres_to_remove = {
+          self._GetLustreName(f) for f in self.args.remove_lustre_instances
+      }
+      storage_ids_to_remove = set()
+      found_lustres = set()
+
+      for storage_id, storage_resource in storages.items():
+        config = storage_resource.config
+        lustre_name = None
+        if config and config.newLustre:
+          lustre_name = config.newLustre.lustre
+        elif config and config.existingLustre:
+          lustre_name = config.existingLustre.lustre
+
+        if lustre_name in lustres_to_remove:
+          storage_ids_to_remove.add(storage_id)
+          found_lustres.add(lustre_name)
+
+      if found_lustres != lustres_to_remove:
+        not_found = lustres_to_remove - found_lustres
+        raise exceptions.ToolException(
+            f"Lustre(s) not found: {', '.join(not_found)}"
+        )
+
+      for storage_id in storage_ids_to_remove:
+        storages.pop(storage_id)
+      is_storage_updated = True
+
+    storage_counter = 10
+    if storages:
+      storage_ids = [
+          int(k[len("storage") :])
+          for k in storages.keys()
+          if k.startswith("storage") and k[len("storage") :].isdigit()
+      ]
+      if storage_ids:
+        storage_counter = max(storage_ids) + 1
+
+    if self.args.IsSpecified("add_new_filestore_instances"):
+      for filestore in self.args.add_new_filestore_instances:
+        storage_id = self._GetNextStorageId(storage_counter)
+        storage_counter += 1
+        filestore_name = self._GetFilestoreName(filestore.get("name"))
+        for storage_resource in storages.values():
+          config = storage_resource.config
+          if config and (
+              (
+                  config.newFilestore
+                  and config.newFilestore.filestore == filestore_name
+              )
+              or (
+                  config.existingFilestore
+                  and config.existingFilestore.filestore == filestore_name
+              )
+          ):
+            raise exceptions.ToolException(
+                f"Filestore {filestore_name} already exists."
+            )
+
+        storages[storage_id] = self.message_module.StorageResource(
+            config=self.message_module.StorageResourceConfig(
+                newFilestore=self.message_module.NewFilestoreConfig(
+                    filestore=filestore_name,
+                    tier=filestore.get("tier"),
+                    fileShares=[
+                        self.message_module.FileShareConfig(
+                            capacityGb=filestore.get("capacityGb"),
+                            fileShare=filestore.get("fileshare"),
+                        )
+                    ],
+                    protocol=filestore.get("protocol"),
+                    description=filestore.get("description"),
+                )
+            )
+        )
+      is_storage_updated = True
+
+    if self.args.IsSpecified("add_filestore_instances"):
+      for filestore in self.args.add_filestore_instances:
+        storage_id = self._GetNextStorageId(storage_counter)
+        storage_counter += 1
+        filestore_name = self._GetFilestoreName(filestore)
+        for storage_resource in storages.values():
+          config = storage_resource.config
+          if config and (
+              (
+                  config.newFilestore
+                  and config.newFilestore.filestore == filestore_name
+              )
+              or (
+                  config.existingFilestore
+                  and config.existingFilestore.filestore == filestore_name
+              )
+          ):
+            raise exceptions.ToolException(
+                f"Filestore {filestore_name} already exists."
+            )
+
+        storages[storage_id] = self.message_module.StorageResource(
+            config=self.message_module.StorageResourceConfig(
+                existingFilestore=self.message_module.ExistingFilestoreConfig(
+                    filestore=filestore_name,
+                )
+            )
+        )
+      is_storage_updated = True
+
+    if self.args.IsSpecified("add_new_lustre_instances"):
+      for lustre in self.args.add_new_lustre_instances:
+        storage_id = self._GetNextStorageId(storage_counter)
+        storage_counter += 1
+        lustre_name = self._GetLustreName(lustre.get("name"))
+        for storage_resource in storages.values():
+          config = storage_resource.config
+          if config and (
+              (config.newLustre and config.newLustre.lustre == lustre_name)
+              or (
+                  config.existingLustre
+                  and config.existingLustre.lustre == lustre_name
+              )
+          ):
+            raise exceptions.ToolException(
+                f"Lustre {lustre_name} already exists."
+            )
+
+        storages[storage_id] = self.message_module.StorageResource(
+            config=self.message_module.StorageResourceConfig(
+                newLustre=self.message_module.NewLustreConfig(
+                    lustre=self._GetLustreName(lustre.get("name")),
+                    filesystem=lustre.get("filesystem"),
+                    capacityGb=lustre.get("capacityGb"),
+                    description=lustre.get("description"),
+                )
+            )
+        )
+      is_storage_updated = True
+
+    if self.args.IsSpecified("add_lustre_instances"):
+      for lustre in self.args.add_lustre_instances:
+        storage_id = self._GetNextStorageId(storage_counter)
+        storage_counter += 1
+        lustre_name = self._GetLustreName(lustre)
+        for storage_resource in storages.values():
+          config = storage_resource.config
+          if config and (
+              (config.newLustre and config.newLustre.lustre == lustre_name)
+              or (
+                  config.existingLustre
+                  and config.existingLustre.lustre == lustre_name
+              )
+          ):
+            raise exceptions.ToolException(
+                f"Lustre {lustre_name} already exists."
+            )
+
+        storages[storage_id] = self.message_module.StorageResource(
+            config=self.message_module.StorageResourceConfig(
+                existingLustre=self.message_module.ExistingLustreConfig(
+                    lustre=lustre_name,
+                )
+            )
+        )
+      is_storage_updated = True
+
+    if self.args.IsSpecified("add_storage_buckets"):
+      for bucket in self.args.add_storage_buckets:
+        storage_id = self._GetNextStorageId(storage_counter)
+        storage_counter += 1
+        # Check for duplicates
+        for storage_resource in storages.values():
+          config = storage_resource.config
+          bucket_name_in_config = None
+          if config:
+            if config.newBucket:
+              bucket_name_in_config = config.newBucket.bucket
+            elif config.existingBucket:
+              bucket_name_in_config = config.existingBucket.bucket
+
+          if bucket_name_in_config == bucket:
+            raise exceptions.ToolException(
+                f"Cloud Storage bucket {bucket} already exists."
+            )
+
+        storages[storage_id] = self.message_module.StorageResource(
+            config=self.message_module.StorageResourceConfig(
+                existingBucket=self.message_module.ExistingBucketConfig(
+                    bucket=bucket,
+                )
+            )
+        )
+      is_storage_updated = True
+
+    if self.args.IsSpecified("add_new_storage_buckets"):
+      for gcs_bucket in self.args.add_new_storage_buckets:
+        storage_id = self._GetNextStorageId(storage_counter)
+        storage_counter += 1
+        bucket_name = gcs_bucket.get("name")
+        for storage_resource in storages.values():
+          config = storage_resource.config
+          b_name = None
+          if config:
+            if config.newBucket:
+              b_name = config.newBucket.bucket
+            elif config.existingBucket:
+              b_name = config.existingBucket.bucket
+          if b_name == bucket_name:
+            raise exceptions.ToolException(
+                f"Cloud Storage bucket {bucket_name} already exists."
+            )
+        gcs = self.message_module.NewBucketConfig(
+            bucket=gcs_bucket.get("name"),
+        )
+        if "storageClass" in gcs_bucket:
+          gcs.storageClass = gcs_bucket.get("storageClass")
+        if not gcs.storageClass and "enableAutoclass" in gcs_bucket:
+          gcs.autoclass = self.message_module.GcsAutoclassConfig(
+              enabled=gcs_bucket.get("enableAutoclass")
+          )
+        if not gcs.storageClass and not gcs.autoclass:
+          gcs.storageClass = (
+              self.message_module.NewBucketConfig.StorageClassValueValuesEnum.STANDARD
+          )
+        if "enableHNS" in gcs_bucket:
+          gcs.hierarchicalNamespace = (
+              self.message_module.GcsHierarchicalNamespaceConfig(
+                  enabled=gcs_bucket.get("enableHNS"),
+              )
+          )
+        storages[storage_id] = self.message_module.StorageResource(
+            config=self.message_module.StorageResourceConfig(newBucket=gcs)
+        )
+      is_storage_updated = True
+
+    if is_storage_updated:
+      storage_resources.additionalProperties = [
+          self.message_module.Cluster.StorageResourcesValue.AdditionalProperty(
+              key=key, value=value
+          )
+          for key, value in storages.items()
+      ]
+      self.update_mask.add("storage_resources")
+    return storage_resources
+
   def MakeClusterComputePatch(self):
     """Makes a cluster compute patch message with compute fields."""
     compute_resources = self.message_module.Cluster.ComputeResourcesValue()
@@ -460,7 +776,7 @@ class ClusterUtil:
         self._RemoveKeyByAttrFromDictSpec(
             key=compute_id,
             dict_spec=compute,
-            attr="newOnDemandInstances",
+            attrs=["newOnDemandInstances"],
             key_exception_message=ex_msg_not_found,
             attr_exception_message=f"On demand {ex_msg_not_found}",
         )
@@ -470,7 +786,7 @@ class ClusterUtil:
         self._RemoveKeyByAttrFromDictSpec(
             key=compute_id,
             dict_spec=compute,
-            attr="newSpotInstances",
+            attrs=["newSpotInstances"],
             key_exception_message=ex_msg_not_found,
             attr_exception_message=f"Spot {ex_msg_not_found}",
         )
@@ -480,7 +796,7 @@ class ClusterUtil:
         self._RemoveKeyByAttrFromDictSpec(
             key=compute_id,
             dict_spec=compute,
-            attr="newReservedInstances",
+            attrs=["newReservedInstances"],
             key_exception_message=ex_msg_not_found,
             attr_exception_message=f"Reserved {ex_msg_not_found}",
         )
@@ -490,7 +806,7 @@ class ClusterUtil:
         self._RemoveKeyByAttrFromDictSpec(
             key=compute_id,
             dict_spec=compute,
-            attr="newDwsFlexInstances",
+            attrs=["newDwsFlexInstances", "newFlexStartInstances"],
             key_exception_message=ex_msg_not_found,
             attr_exception_message=f"DWS Flex {ex_msg_not_found}",
         )
@@ -578,7 +894,13 @@ class ClusterUtil:
         is_node_sets_updated = True
     if self.args.IsSpecified("add_slurm_node_sets"):
       for node_set in self.args.add_slurm_node_sets:
-        storage_configs = self._GetStorageConfigs(self.existing_cluster)
+        storage_configs_source = self.existing_cluster
+        if (
+            cluster_patch.storageResources
+            and cluster_patch.storageResources.additionalProperties
+        ):
+          storage_configs_source = cluster_patch
+        storage_configs = self._GetStorageConfigs(storage_configs_source)
         compute_id = node_set.get("computeId")
         machine_type = self._GetComputeMachineTypeFromCluster(
             compute_id, cluster_patch, use_existing_cluster=True
@@ -636,6 +958,23 @@ class ClusterUtil:
       if not slurm.partitions:
         raise exceptions.ToolException("Slurm partitions cannot be empty.")
       self.update_mask.add("orchestrator.slurm.partitions")
+
+    if self.args.IsSpecified("update_slurm_login_node"):
+      if not self.existing_cluster.orchestrator.slurm.loginNodes:
+        raise exceptions.ToolException(
+            "Login node is not part of existing cluster spec and cannot be"
+            " updated."
+        )
+      login_nodes = self.existing_cluster.orchestrator.slurm.loginNodes
+      login_node_patch = self.args.update_slurm_login_node
+
+      if (count := login_node_patch.get("count")) is not None:
+        login_nodes.count = count
+      if (startup_script := login_node_patch.get("startupScript")) is not None:
+        login_nodes.startupScript = self._GetBashScript(startup_script)
+      slurm.loginNodes = login_nodes
+      self.update_mask.add("orchestrator.slurm.login_nodes")
+
     return slurm
 
   def _GetNetworkName(self, network) -> str:
@@ -665,8 +1004,21 @@ class ClusterUtil:
   def _GetReservationName(self, reservation) -> str:
     """Returns the reservation name."""
     project = self.cluster_ref.Parent().projectsId
+    if reservation.startswith("projects/"):
+      return reservation
     return f"projects/{project}/{reservation}"
 
+  def _GetReservationZone(self, reservation) -> str:
+    """Returns the reservation zone."""
+    # projects/{project}/zones/{zone}/reservations/{reservation}/reservationBlocks/{reservationBlock}
+    parts = reservation.split("/")
+    for current_part, next_part in zip(parts, parts[1:]):
+      if current_part == "zones" and next_part:
+        return next_part
+    raise exceptions.ToolException(
+        f"Reservation {reservation} does not contain a zone."
+    )
+
   def _GetComputeMachineTypeFromArgs(self, compute_id):
     """Returns the compute machine type from args."""
     instances = []
@@ -707,14 +1059,17 @@ class ClusterUtil:
       self, compute_id: str, compute_resources: Dict[str, Any]
   ):
     """Returns the compute machine type from compute resources."""
-    if compute_resources[compute_id].newOnDemandInstances:
-      return compute_resources[compute_id].newOnDemandInstances.machineType
-    if compute_resources[compute_id].newSpotInstances:
-      return compute_resources[compute_id].newSpotInstances.machineType
-    if compute_resources[compute_id].newReservedInstances:
-      return compute_resources[compute_id].newReservedInstances.machineType
-    if compute_resources[compute_id].newDwsFlexInstances:
-      return compute_resources[compute_id].newDwsFlexInstances.machineType
+    compute_resource = compute_resources[compute_id]
+    if compute_resource.config.newOnDemandInstances:
+      return compute_resource.config.newOnDemandInstances.machineType
+    if compute_resource.config.newSpotInstances:
+      return compute_resource.config.newSpotInstances.machineType
+    if compute_resource.config.newReservedInstances:
+      return compute_resource.config.newReservedInstances.machineType
+    if compute_resource.config.newDwsFlexInstances:
+      return compute_resource.config.newDwsFlexInstances.machineType
+    if compute_resource.config.newFlexStartInstances:
+      return compute_resource.config.newFlexStartInstances.machineType
     raise exceptions.ToolException("Compute instances type not supported.")
 
   def _GetStorageConfigs(self, cluster):
@@ -822,14 +1177,16 @@ class ClusterUtil:
       self,
       key: str,
       dict_spec: dict[str, Any],
-      attr: str,
+      attrs: List[str],
       key_exception_message: str,
       attr_exception_message: str,
   ) -> None | exceptions.ToolException:
     """Removes a cluster identifier (key) by attribute, if present in dict spec."""
     if key not in dict_spec:
       raise exceptions.ToolException(key_exception_message.format(key))
-    if not getattr(dict_spec[key], attr, None):
+    if not getattr(dict_spec[key], "config", None):
+      raise exceptions.ToolException(attr_exception_message.format(key))
+    if not any(getattr(dict_spec[key].config, attr, None) for attr in attrs):
       raise exceptions.ToolException(attr_exception_message.format(key))
     dict_spec.pop(key)
 
@@ -844,37 +1201,48 @@ class ClusterUtil:
   def _MakeOnDemandComputeResource(self, instance):
     """Makes a cluster compute resource message for on demand instances."""
     return self.message_module.ComputeResource(
-        newOnDemandInstances=self.message_module.NewOnDemandInstancesConfig(
-            zone=instance.get("zone"),
-            machineType=instance.get("machineType"),
+        config=self.message_module.ComputeResourceConfig(
+            newOnDemandInstances=self.message_module.NewOnDemandInstancesConfig(
+                zone=instance.get("zone"),
+                machineType=instance.get("machineType"),
+            ),
         ),
     )
 
   def _MakeSpotComputeResource(self, instance):
     """Makes a cluster compute resource message for spot instances."""
     return self.message_module.ComputeResource(
-        newSpotInstances=self.message_module.NewSpotInstancesConfig(
-            zone=instance.get("zone"),
-            machineType=instance.get("machineType"),
+        config=self.message_module.ComputeResourceConfig(
+            newSpotInstances=self.message_module.NewSpotInstancesConfig(
+                zone=instance.get("zone"),
+                machineType=instance.get("machineType"),
+            ),
         ),
     )
 
   def _MakeReservedComputeResource(self, instance):
     """Makes a cluster compute resource message for reserved instances."""
+    reservation = instance.get("reservation")
     return self.message_module.ComputeResource(
-        newReservedInstances=self.message_module.NewReservedInstancesConfig(
-            reservation=self._GetReservationName(instance.get("reservation")),
-            machineType=instance.get("machineType"),
+        config=self.message_module.ComputeResourceConfig(
+            newReservedInstances=self.message_module.NewReservedInstancesConfig(
+                reservation=self._GetReservationName(reservation),
+                machineType=instance.get("machineType"),
+                zone=self._GetReservationZone(reservation),
+                type=self.message_module.NewReservedInstancesConfig.TypeValueValuesEnum.SPECIFIC_RESERVATION,
+            ),
         ),
     )
 
   def _MakeDwsFlexComputeResource(self, instance):
     """Makes a cluster compute resource message for DWS Flex instances."""
     return self.message_module.ComputeResource(
-        newDwsFlexInstances=self.message_module.NewDWSFlexInstancesConfig(
-            zone=instance.get("zone"),
-            machineType=instance.get("machineType"),
-            maxDuration=instance.get("maxDuration"),
+        config=self.message_module.ComputeResourceConfig(
+            newDwsFlexInstances=self.message_module.NewDWSFlexInstancesConfig(
+                zone=instance.get("zone"),
+                machineType=instance.get("machineType"),
+                maxDuration=instance.get("maxDuration"),
+            ),
         ),
     )
 
