@@ -73,11 +73,13 @@ def FirewallPolicyArgument(required=False, plural=False, operation=None):
 
 def FirewallPolicyAssociationsArgument(required=False, plural=False):
   return compute_flags.ResourceArgument(
-      name='name',
-      resource_name='association',
-      completer=FirewallPoliciesCompleter,
+      name='--firewall-policy',
+      resource_name='firewall policy',
       plural=plural,
       required=required,
+      short_help=(
+          'Short name or ID of the firewall policy ID of the association.'
+      ),
       global_collection='compute.firewallPolicies',
   )
 
@@ -437,9 +439,9 @@ def AddArgsCreateAssociation(parser):
 def AddArgsDeleteAssociation(parser):
   """Adds the arguments of association deletion."""
   parser.add_argument(
-      '--firewall-policy',
-      required=True,
-      help='Short name or ID of the firewall policy ID of the association.',
+      'name',
+      metavar='NAME',
+      help='Name of the association to delete.',
   )
 
   parser.add_argument(
@@ -699,6 +701,21 @@ def AddSrcNetworkType(parser, required=False):
   )
 
 
+def AddSrcNetworkContext(parser, required=False):
+  """Adds source network context to this rule."""
+  parser.add_argument(
+      '--src-network-context',
+      required=required,
+      help=(
+          'Use this flag to indicate that the rule should match internet,'
+          ' non-internet traffic or traffic coming from the network specified'
+          ' by --src-network. It applies to ingress rules. Valid values are'
+          ' INTERNET, NON_INTERNET, VPC_NETWORKS and INTRA_VPC. Use empty'
+          ' string to clear the field.'
+      ),
+  )
+
+
 def AddSrcNetworks(parser):
   """Adds source network urls list to this rule."""
   parser.add_argument(
@@ -744,6 +761,20 @@ def AddDestNetworkType(parser, required=False):
   )
 
 
+def AddDestNetworkContext(parser, required=False):
+  """Adds destination network context to this rule."""
+  parser.add_argument(
+      '--dest-network-context',
+      required=required,
+      help=(
+          'Use this flag to indicate that the rule should match internet or'
+          ' non-internet traffic. It applies to destination traffic for egress'
+          ' rules. Valid values are INTERNET and NON_INTERNET. Use'
+          ' empty string to clear the field.'
+      ),
+  )
+
+
 def AddSrcSecureTags(parser, required=False, support_network_scopes=False):
   """Adds a  source secure tag to this rule."""
   help_text = (
