@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,17 +18,23 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.compute import completers as compute_completers
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 
 
+@base.UniverseCompatible
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
+)
 class InterconnectLocationsCompleter(compute_completers.ListCommandCompleter):
 
   def __init__(self, **kwargs):
     super(InterconnectLocationsCompleter, self).__init__(
         collection='compute.interconnectLocations',
-        list_command='alpha compute interconnects attachments list --uri',
-        **kwargs)
+        list_command='compute interconnects locations list --uri',
+        **kwargs
+    )
 
 
 def InterconnectLocationArgument(required=True):
