@@ -1,4 +1,5 @@
-# Copyright 2017 Google Inc. All Rights Reserved.
+# -*- coding: utf-8 -*- #
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +14,18 @@
 # limitations under the License.
 """Flags for the compute zones commands."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import unicode_literals
+
+from googlecloudsdk.command_lib.compute import completers as compute_completers
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 
 
 def MakeZoneArg():
   return compute_flags.ResourceArgument(
       resource_name='zone',
-      completion_resource_id='compute.zones',
+      completer=compute_completers.ZonesCompleter,
       plural=False,
       required=True,
       global_collection='compute.zones')
