@@ -132,6 +132,10 @@ _INFO = {
         display_name='Workload Identity',
         cmd_group='workload-identity',
     ),
+    'rbacrolebindingactuation': Info(
+        display_name='RBACRoleBinding Actuation',
+        cmd_group='rbacrolebindingactuation',
+    ),
 }
 
 
