@@ -65,12 +65,13 @@ class BatchMessageFactory(object):
         self.dataproc.messages.SparkRBatch: 'sparkRBatch',
         self.dataproc.messages.SparkSqlBatch: 'sparkSqlBatch',
         self.dataproc.messages.PySparkBatch: 'pysparkBatch',
+        self.dataproc.messages.RayBatch: 'rayBatch',
     }
 
     self.runtime_config_factory = runtime_config_factory_override
     if not self.runtime_config_factory:
       self.runtime_config_factory = rcf.RuntimeConfigFactory(
-          self.dataproc, include_autotuning=True
+          self.dataproc, include_autotuning=True, include_cohort=True
       )
 
     self.environment_config_factory = environment_config_factory_override
@@ -142,5 +143,5 @@ def AddArguments(parser):
 
 
 def _AddDependency(parser):
-  rcf.AddArguments(parser, include_autotuning=True)
+  rcf.AddArguments(parser, include_autotuning=True, include_cohort=True)
   ecf.AddArguments(parser)
