@@ -14,18 +14,43 @@
 # limitations under the License.
 """Utilities for the cloud deploy delivery pipeline resource."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
+
+import uuid
 
 from apitools.base.py import exceptions as apitools_exceptions
+from googlecloudsdk.api_lib.clouddeploy import client_util
 from googlecloudsdk.api_lib.clouddeploy import delivery_pipeline
 from googlecloudsdk.command_lib.deploy import exceptions as cd_exceptions
 from googlecloudsdk.core import log
 from googlecloudsdk.core import resources
 
 _PIPELINES_WITH_GIVEN_TARGET_FILTER_TEMPLATE = (
-    'serialPipeline.stages.targetId:"{}"')
+    'serialPipeline.stages.targetId:"{}"'
+)
+
+
+def DeliveryPipelineReference(name, project, region):
+  """Creates the delivery pipeline reference base on the parameters.
+
+    Returns the shared delivery pipeline reference.
+
+  Args:
+    name: str, delivery pipeline ID
+    project: str,project number or ID.
+    region: str, region ID.
+
+  Returns:
+    custom target type reference.
+  """
+  return resources.REGISTRY.Parse(
+      name,
+      collection='clouddeploy.projects.locations.deliveryPipelines',
+      params={
+          'projectsId': project,
+          'locationsId': region,
+          'deliveryPipelinesId': name,
+      },
+  )
 
 
 def ListDeliveryPipelinesWithTarget(target_ref, location_ref):
@@ -40,7 +65,8 @@ def ListDeliveryPipelinesWithTarget(target_ref, location_ref):
     a sorted list of delivery pipelines.
   """
   filter_str = _PIPELINES_WITH_GIVEN_TARGET_FILTER_TEMPLATE.format(
-      target_ref.Name())
+      target_ref.Name()
+  )
 
   pipelines = delivery_pipeline.DeliveryPipelinesClient().List(
       location=location_ref.RelativeName(),
@@ -52,13 +78,15 @@ def ListDeliveryPipelinesWithTarget(target_ref, location_ref):
   # so sort result to get the same result you would get by using
   # orderBy = 'createTime desc'
   return sorted(
-      pipelines, key=lambda pipeline: pipeline.createTime, reverse=True)
+      pipelines, key=lambda pipeline: pipeline.createTime, reverse=True
+  )
 
 
 def PipelineToPipelineRef(pipeline):
   pipeline_ref = resources.REGISTRY.ParseRelativeName(
       pipeline.name,
-      collection='clouddeploy.projects.locations.deliveryPipelines')
+      collection='clouddeploy.projects.locations.deliveryPipelines',
+  )
   return pipeline_ref
 
 
@@ -75,11 +103,13 @@ def GetPipeline(pipeline_name):
   """
   try:
     pipeline_obj = delivery_pipeline.DeliveryPipelinesClient().Get(
-        pipeline_name)
+        pipeline_name
+    )
     return pipeline_obj
   except apitools_exceptions.HttpError as error:
-    log.debug('Failed to get pipeline {}: {}'.format(pipeline_name,
-                                                     error.content))
+    log.debug(
+        'Failed to get pipeline {}: {}'.format(pipeline_name, error.content)
+    )
     log.status.Print('Unable to get delivery pipeline {}'.format(pipeline_name))
     raise error
 
@@ -99,4 +129,51 @@ def ThrowIfPipelineSuspended(pipeline_obj, suspended_pipeline_msg):
   if pipeline_obj.suspended:
     raise cd_exceptions.PipelineSuspendedError(
         pipeline_name=pipeline_obj.name,
-        failed_activity_msg=suspended_pipeline_msg)
+        failed_activity_msg=suspended_pipeline_msg,
+    )
+
+
+def CreateRollbackTarget(
+    pipeline_rel_name,
+    target_id,
+    validate_only=False,
+    release_id=None,
+    rollout_id=None,
+    rollout_to_rollback=None,
+    rollout_obj=None,
+    starting_phase=None,
+):
+  """Creates a rollback rollout for the target based on the given inputs.
+
+  Args:
+    pipeline_rel_name: delivery_pipeline name
+    target_id: the target to rollback
+    validate_only: whether or not to validate only for the call
+    release_id: the release_id to rollback to
+    rollout_id: the rollout_id of the new rollout
+    rollout_to_rollback: the rollout that is being rolled back by this rollout
+    rollout_obj: the rollout resource to pass into rollbackTargetConfig
+    starting_phase: starting_phase of the rollout
+
+  Returns:
+    RollbackTargetResponse
+  """
+  # if the rollout_id isn't provided, then generate one based off of UUID. This
+  # will give us the release id that we will use and generate the rollout id.
+  rollback_id = rollout_id if rollout_id else 'rollback-' + uuid.uuid4().hex
+
+  rollback_target_config = client_util.GetMessagesModule().RollbackTargetConfig(
+      rollout=rollout_obj, startingPhaseId=starting_phase
+  )
+
+  return delivery_pipeline.DeliveryPipelinesClient().RollbackTarget(
+      pipeline_rel_name,
+      client_util.GetMessagesModule().RollbackTargetRequest(
+          releaseId=release_id,
+          rollbackConfig=rollback_target_config,
+          rolloutId=rollback_id,
+          rolloutToRollBack=rollout_to_rollback,
+          targetId=target_id,
+          validateOnly=validate_only,
+      ),
+  )
