@@ -487,6 +487,7 @@ def AddNetworkArg(parser, api_version):
       'name': str,
       'reserved-ip-range': str,
       'connect-mode': str,
+      'address-mode': str,
       'psc-endpoint-project': str,
   }
 
@@ -522,7 +523,7 @@ def AddNetworkArg(parser, api_version):
 
   network_help_beta_v1 = """\
         Network configuration for a Cloud Filestore instance. Specifying
-        `reserved-ip-range` and `connect-mode` is optional.
+        `reserved-ip-range`, `address-mode` and `connect-mode` is optional.
         *name*::: The name of the Google Compute Engine
         [VPC network](/compute/docs/networks-and-firewalls#networks) to which
         the instance is connected.
@@ -543,6 +544,7 @@ def AddNetworkArg(parser, api_version):
         *connect-mode*::: Network connection mode used by instances.
         CONNECT_MODE must be one of: DIRECT_PEERING, PRIVATE_SERVICE_ACCESS or
         PRIVATE_SERVICE_CONNECT.
+        *address-mode*::: Internet protocol version for which the instance has IP address assigned.
         *psc-endpoint-project*::: Consumer service project in which the psc
         endpoint would be set up. This is optional, and only relevant in case
         the network is a shared VPC. If this is not specified, the psc endpoint
@@ -570,6 +572,7 @@ def AddFileShareArg(
     api_version,
     include_snapshot_flags=False,
     include_backup_flags=False,
+    include_backupdr_flags=False,
     clear_nfs_export_options_required=False,
     required=True,
 ):
@@ -580,6 +583,8 @@ def AddFileShareArg(
     api_version: filestore_client api version.
     include_snapshot_flags: bool, whether to include --source-snapshot flags.
     include_backup_flags: bool, whether to include --source-backup flags.
+    include_backupdr_flags: bool, whether to include --source-backupdr-backup
+    flag.
     clear_nfs_export_options_required: bool, whether to include
       --clear-nfs-export-options flags.
     required: bool, passthrough to parser.add_argument.
@@ -729,6 +734,8 @@ instance-zone will be used.
   if include_snapshot_flags:
     spec['source-snapshot'] = str
     spec['source-snapshot-region'] = str
+  if include_backupdr_flags:
+    spec['source-backupdr-backup'] = str
 
   file_share_help = file_share_help[api_version]
   if clear_nfs_export_options_required:
@@ -844,6 +851,7 @@ def AddInstanceCreateArgs(parser, api_version):
           api_version == filestore_client.ALPHA_API_VERSION
       ),
       include_backup_flags=True,
+      include_backupdr_flags=api_version != filestore_client.ALPHA_API_VERSION,
   )
   if api_version in [
       filestore_client.BETA_API_VERSION,
