@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,10 @@
 # limitations under the License.
 """Flags and helpers for the Cloud Filestore operations commands."""
 
+from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 OPERATIONS_LIST_FORMAT = """\
     table(
         name.basename():label=OPERATION_NAME,
