@@ -130,6 +130,27 @@ _VALID_EXTENDED_KEY_USAGES = [
 ]
 
 
+def AddEncryptionKeyFlag(parser):
+  """Adds the encryption key flag.
+
+  Registers the flag for the Cloud KMS key (CMEK) used to encrypt certificates
+  in this pool.
+
+  Args:
+    parser: The parser to add the flags to.
+  """
+  base.Argument(
+      '--encryption-key',
+      help=(
+          'The full resource name of the Cloud KMS key to use for encrypting'
+          ' certificate data at rest. The key must be in the same region as'
+          ' the CA pool.'
+      ),
+      required=False,
+      hidden=True,
+  ).AddToParser(parser)
+
+
 def AddPublishCrlFlag(parser, use_update_help_text=False):
   help_text = (
       PUBLISH_CRL_UPDATE_HELP
@@ -694,12 +715,8 @@ def AddExtensionConstraintsFlags(parser):
           'from the certificate request into the signed certificate.'
       ),
       type=arg_parsers.ArgList(
-          choices=known_extensions,
-          visible_choices=[
-              ext
-              for ext in known_extensions.keys()
-              if ext not in _HIDDEN_KNOWN_EXTENSIONS
-          ],
+          choices=known_extensions.keys(),
+          hidden_choices=_HIDDEN_KNOWN_EXTENSIONS,
       ),
       metavar='KNOWN_EXTENSIONS',
   ).AddToParser(copy_group)
@@ -791,12 +808,8 @@ def AddExtensionConstraintsFlagsForUpdate(parser):
           'from the certificate request into the signed certificate.'
       ),
       type=arg_parsers.ArgList(
-          choices=known_extensions,
-          visible_choices=[
-              ext
-              for ext in known_extensions.keys()
-              if ext not in _HIDDEN_KNOWN_EXTENSIONS
-          ],
+          choices=known_extensions.keys(),
+          hidden_choices=_HIDDEN_KNOWN_EXTENSIONS,
       ),
       metavar='KNOWN_EXTENSIONS',
   ).AddToParser(known_group)
@@ -848,6 +861,16 @@ def AddPredefinedValuesFileFlag(parser):
 # Flag parsing
 
 
+def ParseEncryptionSpec(args):
+  """Parses the encryption-key flag from args."""
+  if not args.IsSpecified('encryption_key'):
+    return None
+
+  messages = privateca_base.GetMessagesModule('v1')
+
+  return messages.EncryptionSpec(cloudKmsKey=args.encryption_key)
+
+
 def ParseIdentityConstraints(args):
   """Parses the identity flags into a CertificateIdentityConstraints object."""
   messages = privateca_base.GetMessagesModule('v1')
@@ -1039,7 +1062,7 @@ def ValidateIdentityConstraints(
     raise privateca_exceptions.UserAbortException('Aborted by user.')
 
 
-def ValidateSubjectConfig(subject_config, is_ca):
+def ValidateSubjectConfig(subject_config):
   """Validates a SubjectConfig object."""
   san_names = []
   if subject_config.subjectAltName:
@@ -1060,24 +1083,12 @@ def ValidateSubjectConfig(subject_config, is_ca):
         ' subject alternative name.',
     )
 
-  if (
-      is_ca
-      and not subject_config.subject.organization
-      and not subject_config.subject.rdnSequence
-  ):
-    raise exceptions.InvalidArgumentException(
-        '--subject',
-        'An organization must be provided for a certificate authority'
-        ' certificate.',
-    )
 
-
-def ParseSubjectFlags(args, is_ca):
+def ParseSubjectFlags(args):
   """Parses subject flags into a subject config.
 
   Args:
     args: The parser that contains all the flag values
-    is_ca: Whether to parse this subject as a CA or not.
 
   Returns:
     A subject config representing the parsed flags.
@@ -1094,7 +1105,7 @@ def ParseSubjectFlags(args, is_ca):
   if SanFlagsAreSpecified(args):
     subject_config.subjectAltName = ParseSanFlags(args)
 
-  ValidateSubjectConfig(subject_config, is_ca=is_ca)
+  ValidateSubjectConfig(subject_config)
 
   return subject_config
 
