@@ -21,15 +21,18 @@ from __future__ import unicode_literals
 import datetime
 import re
 
+from apitools.base.py import exceptions as apitools_exceptions
 from apitools.base.py.exceptions import HttpForbiddenError
 from googlecloudsdk.api_lib.cloudresourcemanager import organizations
 from googlecloudsdk.api_lib.cloudresourcemanager import projects_api
 from googlecloudsdk.api_lib.cloudresourcemanager import projects_util
 from googlecloudsdk.api_lib.iam import policies
 from googlecloudsdk.api_lib.resource_manager import folders
+from googlecloudsdk.command_lib.iam import iam_util
 from googlecloudsdk.command_lib.projects import exceptions
+from googlecloudsdk.core import exceptions as core_exceptions
+from googlecloudsdk.core import log
 from googlecloudsdk.core import resources
-import six
 
 PROJECTS_COLLECTION = 'cloudresourcemanager.projects'
 PROJECTS_API_VERSION = projects_util.DEFAULT_API_VERSION
@@ -38,7 +41,8 @@ LIST_FORMAT = """
     table(
       projectId:sort=1,
       name,
-      projectNumber
+      projectNumber,
+      tags.environment:label='ENVIRONMENT'
     )
 """
 
@@ -59,9 +63,30 @@ _VALID_PROJECT_REGEX = re.compile(
     r'$')
 
 
+_ENV_STANDARD_TO_VARIANT_VALUE_MAPPING = {
+    # Production
+    'Production': {'Prod', 'prod', 'Production', 'production'},
+    # Development
+    'Development': {'Dev', 'dev', 'Development', 'development'},
+    # Test
+    'Test': {'Test', 'test', 'Testing', 'testing QA', 'qa',
+             'Quality assurance', 'quality assurance'},
+    # Staging
+    'Staging': {'Staging', 'staging', 'Stage', 'stage'},
+}
+
+_ENV_VARIANT_TO_STANDARD_VALUE_MAPPING = {}
+for (
+    standard_value,
+    variant_values,
+) in _ENV_STANDARD_TO_VARIANT_VALUE_MAPPING.items():
+  for variant_value in variant_values:
+    _ENV_VARIANT_TO_STANDARD_VALUE_MAPPING[variant_value] = standard_value
+
+
 def ValidateProjectIdentifier(project):
   """Checks to see if the project string is valid project name or number."""
-  if not isinstance(project, six.string_types):
+  if not isinstance(project, str):
     return False
 
   if project.isdigit() or _VALID_PROJECT_REGEX.match(project):
@@ -135,6 +160,22 @@ def IdFromName(project_name):
   return None
 
 
+def GetDetailedHelpForRemoveIamPolicyBinding():
+  """Returns detailed_help for a remove-iam-policy-binding command."""
+  detailed_help = iam_util.GetDetailedHelpForRemoveIamPolicyBinding(
+      'project', 'example-project-id-1', condition=True
+  )
+  detailed_help[
+      'DESCRIPTION'
+  ] += ' One binding consists of a member, a role and an optional condition.'
+  detailed_help['API REFERENCE'] = (
+      'This command uses the cloudresourcemanager/v1 API. The full'
+      ' documentation for this API can be found at:'
+      ' https://cloud.google.com/resource-manager'
+  )
+  return detailed_help
+
+
 def SetIamPolicyFromFileHook(ref, args, request):
   """Hook to perserve SetIAMPolicy behavior for declarative surface."""
   del ref
@@ -226,3 +267,59 @@ def GetIamPolicyWithAncestors(project_id, include_deny, release_track):
     raise exceptions.AncestorsIamPolicyAccessDeniedError(
         'User is not permitted to access IAM policy for one or more of the'
         ' ancestors')
+
+
+def GetEnvironmentTag(tags):
+  """Returns the environment tag for the project."""
+  for tag in tags.additionalProperties:
+    if tag.key == 'environment':
+      return tag
+  return None
+
+
+def GetStandardEnvironmentValue(value):
+  return _ENV_VARIANT_TO_STANDARD_VALUE_MAPPING.get(value, None)
+
+
+def CheckAndPrintEnvironmentTagMessageWithProjectID(project_id):
+  """Checks for environment tag and prints a message given project ID."""
+  try:
+    project_ref = ParseProject(project_id)
+    project = projects_api.Get(project_ref)
+    CheckAndPrintEnvironmentTagMessageWithProject(project)
+  except (apitools_exceptions.HttpError, core_exceptions.Error) as e:
+    # Gracefully print a warning message.
+    log.info(
+        'Unable to get environment tag for project [{0}]: {1}'
+        .format(project_id, e)
+    )
+
+
+def CheckAndPrintEnvironmentTagMessageWithProject(project):
+  """Checks for environment tag and prints a message."""
+  env_tag = GetEnvironmentTag(project.tags) if project.tags else None
+  if env_tag:
+    env_standard_value = GetStandardEnvironmentValue(env_tag.value)
+    if env_standard_value:
+      log.info(
+          "Project '{0}' is tagged as 'environment: {1}'. Making"
+          " changes could affect your '{2}' apps. If incorrect, you can update"
+          " it by managing the tag binding for the 'environment' key using"
+          ' `gcloud resource-manager tags bindings create`.'.format(
+              project.projectId, env_tag.value, env_standard_value
+          )
+      )
+    else:
+      log.info(
+          "Project '{0}' has an 'environment' tag key with invalid"
+          " value. Use either 'Production', 'Development', 'Test', or"
+          " 'Staging'. Add an 'environment' tag using `gcloud resource-manager"
+          ' tags bindings create`.'.format(project.projectId)
+      )
+  else:
+    log.info(
+        "Project '{0}' has no 'environment' tag set. Use either"
+        " 'Production', 'Development', 'Test', or 'Staging'. Add an"
+        " 'environment' tag using `gcloud resource-manager tags bindings"
+        ' create`.'.format(project.projectId)
+    )
