@@ -19,17 +19,28 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.resource_manager import exceptions
+from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions as calliope_exceptions
 from googlecloudsdk.calliope.concepts import concepts
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
+import six
 
 
 def FolderIdArg(use_description):
   return base.Argument(
       'id',
       metavar='FOLDER_ID',
-      help='ID for the folder {0}'.format(use_description))
+      help='ID for the folder {0}'.format(use_description),
+  )
+
+
+def CapabilityIdArg(use_description):
+  return base.Argument(
+      'id',
+      metavar='CAPABILITY_ID',
+      help='ID for the capability {0}'.format(use_description),
+  )
 
 
 @base.Hidden
@@ -38,21 +49,24 @@ def FolderIdFlag(use_description):
       '--folder',
       metavar='FOLDER_ID',
       default=None,
-      help='ID for the folder {0}'.format(use_description))
+      help='ID for the folder {0}'.format(use_description),
+  )
 
 
 def OrganizationIdFlag(use_description):
   return base.Argument(
       '--organization',
       metavar='ORGANIZATION_ID',
-      help='ID for the organization {0}'.format(use_description))
+      help='ID for the organization {0}'.format(use_description),
+  )
 
 
 def OperationIdArg(use_description):
   return base.Argument(
       'id',
       metavar='OPERATION_ID',
-      help='ID for the operation {0}'.format(use_description))
+      help='ID for the operation {0}'.format(use_description),
+  )
 
 
 def OperationAsyncFlag():
@@ -63,7 +77,8 @@ def LienIdArg(use_description):
   return base.Argument(
       'id',
       metavar='LIEN_ID',
-      help='ID for the lien {0}'.format(use_description))
+      help='ID for the lien {0}'.format(use_description),
+  )
 
 
 def AddParentFlagsToParser(parser):
@@ -93,19 +108,21 @@ def CheckParentFlags(args, parent_required=True):
   """
   if getattr(args, 'folder', None) and args.organization:
     raise calliope_exceptions.ConflictingArgumentsException(
-        '--folder', '--organization')
+        '--folder', '--organization'
+    )
   if parent_required:
     if 'folder' in args and not args.folder and not args.organization:
       raise exceptions.ArgumentError(
-          'Neither --folder nor --organization provided, exactly one required')
+          'Neither --folder nor --organization provided, exactly one required'
+      )
     elif 'folder' not in args and not args.organization:
       raise exceptions.ArgumentError('--organization is required')
 
 
 def FolderAttributeConfig():
   return concepts.ResourceParameterAttributeConfig(
-      name='folder',
-      help_text='The folder id')
+      name='folder', help_text='The folder id'
+  )
 
 
 def GetFolderResourceSpec():
@@ -113,7 +130,8 @@ def GetFolderResourceSpec():
       'cloudresourcemanager.folders',
       resource_name='folder',
       api_version='v2',
-      foldersId=FolderAttributeConfig())
+      foldersId=FolderAttributeConfig(),
+  )
 
 
 def GetFolderResourceArg(verb):
@@ -121,4 +139,37 @@ def GetFolderResourceArg(verb):
       'folder_id',
       GetFolderResourceSpec(),
       'ID for the folder you want to {}'.format(verb),
-      required=True)
+      required=True,
+  )
+
+
+def TagsFlag():
+  """Makes the base.Argument for --tags flag."""
+  help_parts = [
+      'List of tags KEY=VALUE pairs to bind.',
+      'Each item must be expressed as',
+      '`<tag-key-namespaced-name>=<tag-value-short-name>`.\n',
+      'Example: `123/environment=production,123/costCenter=marketing`\n',
+      'Note: Currently this field is in Preview.',
+  ]
+  return base.Argument(
+      '--tags',
+      metavar='KEY=VALUE',
+      type=arg_parsers.ArgDict(),
+      action=arg_parsers.UpdateAction,
+      help='\n'.join(help_parts),
+  )
+
+
+def GetTagsFromFlags(args, tags_message, tags_arg_name='tags'):
+  """Makes the tags message object."""
+  tags = getattr(args, tags_arg_name)
+  if not tags:
+    return None
+  # Sorted for test stability
+  return tags_message(
+      additionalProperties=[
+          tags_message.AdditionalProperty(key=key, value=value)
+          for key, value in sorted(six.iteritems(tags))
+      ]
+  )
