@@ -611,6 +611,14 @@ class RegionsChangeAnnotationChange(NonTemplateConfigChanger):
   to_remove: str
 
   def Adjust(self, resource):
+    final_list = self.GetFinalList(resource)
+    resource.annotations[k8s_object.MULTI_REGION_REGIONS_ANNOTATION] = ','.join(
+        final_list
+    )
+    return resource
+
+  def GetFinalList(self, resource):
+    """Returns the final list of regions after applying the changes."""
     annotation = (
         resource.annotations.get(k8s_object.MULTI_REGION_REGIONS_ANNOTATION)
         or None
@@ -620,10 +628,7 @@ class RegionsChangeAnnotationChange(NonTemplateConfigChanger):
     to_remove = self.to_remove.split(',') if self.to_remove else []
     final_list = [x for x in existing if x not in to_remove]
     final_list.extend([x for x in to_add if x not in existing])
-    resource.annotations[k8s_object.MULTI_REGION_REGIONS_ANNOTATION] = ','.join(
-        final_list
-    )
-    return resource
+    return final_list
 
 
 @dataclasses.dataclass(frozen=True)
@@ -1301,9 +1306,9 @@ class RevisionNameChanges(TemplateConfigChanger):
     return resource
 
 
-def _GenerateVolumeName(prefix):
+def GenerateVolumeName(prefix):
   """Randomly generated name with the given prefix."""
-  return name_generator.GenerateName(sections=3, separator='-', prefix=prefix)
+  return name_generator.GenerateName(sections=2, separator='-', prefix=prefix)
 
 
 def _UniqueVolumeName(source_name, existing_volumes):
@@ -1321,7 +1326,7 @@ def _UniqueVolumeName(source_name, existing_volumes):
   """
   volume_name = None
   while volume_name is None or volume_name in existing_volumes:
-    volume_name = _GenerateVolumeName(source_name)
+    volume_name = GenerateVolumeName(source_name)
   return volume_name
 
 
@@ -1782,6 +1787,25 @@ class JobMaxRetriesChange(TemplateConfigChanger):
     return resource
 
 
+@dataclasses.dataclass(frozen=True)
+class JobPriorityTierChange(TemplateConfigChanger):
+  """Represents the intent to update the job's priority tier.
+
+  Attributes:
+    priority_tier: The priority tier to set.
+  """
+
+  priority_tier: str
+
+  def Adjust(self, resource):
+    resource.execution_template.spec.priorityTier = (
+        run_v1_messages.ExecutionSpec.PriorityTierValueValuesEnum(
+            self.priority_tier.upper()
+        )
+    )
+    return resource
+
+
 @dataclasses.dataclass(frozen=True)
 class JobTaskTimeoutChange(TemplateConfigChanger):
   """Represents the user intent to update a job's instance deadline.
@@ -2291,3 +2315,22 @@ class PresetChange(TemplateConfigChanger):
       }]
     resource.annotations[service.PRESETS_ANNOTATION] = json.dumps(presets)
     return resource
+
+
+@dataclasses.dataclass(frozen=True)
+class RemovePresetsChange(TemplateConfigChanger):
+  """Removes one or more presets from annotation from the service metadata.
+
+  Attributes:
+    clear_presets: Whether to clear all presets.
+  """
+
+  clear_presets: bool
+
+  def Adjust(self, resource):
+    presets = json.loads(
+        resource.annotations.get(service.PRESETS_ANNOTATION, '[]')
+    )
+    if presets and self.clear_presets:
+      del resource.annotations[service.PRESETS_ANNOTATION]
+      return resource
