@@ -41,6 +41,10 @@ class InvalidTestDataFileError(core_exceptions.Error):
   """Error if a test data file is improperly formatted."""
 
 
+class InvalidResourceFileError(core_exceptions.Error):
+  """Error if a resource file is improperly formatted."""
+
+
 def AppendOrgArg():
   """Add Organization as a positional resource."""
   org_spec_data = yaml_data.ResourceYAMLData.FromPath("scc.organization")
@@ -192,22 +196,58 @@ def ProcessCustomConfigFile(file_contents):
         "Error parsing custom config file [{}]".format(ype))
 
 
+def ExtractTestData(test_data_input):
+  """Extract test data into list structure, accept both list and dict."""
+  if isinstance(test_data_input, list):
+    return test_data_input
+  elif isinstance(test_data_input, dict):
+    if "testData" in test_data_input:
+      return test_data_input["testData"]
+    else:
+      return None
+  else:
+    if not test_data_input:
+      raise InvalidTestDataFileError(
+          "Error parsing test data file: no data records defined in file"
+      )
+
+
 def ProcessTestResourceDataFile(file_contents):
   """Process the test resource data file for the custom module to test against."""
   messages = sc_client.GetMessages()
   try:
-    test_data_dict = yaml.load(file_contents)
-
-    if not test_data_dict or not isinstance(test_data_dict, list):
-      raise InvalidTestDataFileError(
-          "Error parsing test data file: no data records defined in file")
-
+    test_data = ExtractTestData(yaml.load(file_contents))
     test_data_messages = []
-    for field in test_data_dict:
+    for field in test_data:
       test_data_messages.append(
-          encoding.DictToMessage(field, messages.TestData))
+          encoding.DictToMessage(field, messages.TestData)
+      )
 
     return test_data_messages
   except yaml.YAMLParseError as ype:
     raise InvalidTestDataFileError(
-        "Error parsing test data file [{}]".format(ype))
+        "Error parsing test data file [{}]".format(ype)
+    )
+
+
+def ProcessSimulatedResourceFile(file_contents):
+  """Process the simulate resource data file for the custom module to validate against."""
+  messages = sc_client.GetMessages()
+  try:
+    resource_dict = yaml.load(file_contents)
+
+    return encoding.DictToMessage(resource_dict, messages.SimulatedResource)
+  except yaml.YAMLParseError as ype:
+    raise InvalidResourceFileError(
+        "Error parsing resource file [{}]".format(ype)
+    )
+
+def ProcessTFPlanFile(file_contents):
+  """Process the custom configuration file for the custom module."""
+  try:
+    config = json.loads(file_contents)
+    return json.dumps(config).encode("utf-8")
+  except json.JSONDecodeError as e:
+    raise InvalidCustomConfigFileError(
+        "Error parsing terraform plan file [{}]".format(e)
+    )
