@@ -91,6 +91,21 @@ def available_service_flag(suffix='to act on', flag_name='service'):
       help='The name of the service(s) {0}.'.format(suffix))
 
 
+def service_flag(suffix='to act on', flag_name='service'):
+  return base.Argument(
+      flag_name, help='The name of the service {0}.'.format(suffix)
+  )
+
+
+def mcp_content_security_provider_flag(
+    suffix='to act on', flag_name='mcp_content_security_provider'
+):
+  return base.Argument(
+      flag_name,
+      help='The MCP content security provider {0}.'.format(suffix),
+  )
+
+
 # TODO(b/321801975) Link public documentation about consumer policy format
 # after public preview.
 def consumer_policy_file_flag():
@@ -133,6 +148,17 @@ def bypass_api_usage_check():
   )
 
 
+def skip_mcp_endpoint_check_flag(parser):
+  return base.Argument(
+      '--skip-mcp-endpoint-check',
+      action='store_true',
+      help=(
+          ' If true, the system will bypass the check for MCP endpoint while'
+          ' enabling a service.'
+      ),
+  ).AddToParser(parser)
+
+
 def _create_key_resource_arg(help_txt, api_version, required=True):
   return presentation_specs.ResourcePresentationSpec(
       'key', _get_key_resource_spec(api_version), help_txt, required=required
