@@ -52,22 +52,32 @@ def _should_perform_sliced_download(source_resource, destination_resource):
   if destination_resource.storage_url.is_stream:
     # Can't write to different indices of streams.
     return False
-  if (not source_resource.crc32c_hash and
-      properties.VALUES.storage.check_hashes.Get() !=
-      properties.CheckHashes.NEVER.value):
+  if (
+      not source_resource.crc32c_hash
+      and properties.VALUES.storage.check_hashes.Get()
+      != properties.CheckHashes.NEVER.value
+  ):
     # Do not perform sliced download if hash validation is not possible.
     return False
 
   threshold = scaled_integer.ParseInteger(
-      properties.VALUES.storage.sliced_object_download_threshold.Get())
+      properties.VALUES.storage.sliced_object_download_threshold.Get()
+  )
   component_size = scaled_integer.ParseInteger(
-      properties.VALUES.storage.sliced_object_download_component_size.Get())
-  api_capabilities = api_factory.get_capabilities(
-      source_resource.storage_url.scheme)
-  return (source_resource.size and threshold != 0 and
-          source_resource.size > threshold and component_size and
-          cloud_api.Capability.SLICED_DOWNLOAD in api_capabilities and
-          task_util.should_use_parallelism())
+      properties.VALUES.storage.sliced_object_download_component_size.Get()
+  )
+  args = [source_resource.storage_url.scheme]
+  if properties.VALUES.storage.enable_zonal_buckets_bidi_streaming.GetBool():
+    args.append(source_resource.storage_url.bucket_name)
+  api_capabilities = api_factory.get_capabilities(*args)
+  return (
+      source_resource.size
+      and threshold != 0
+      and source_resource.size > threshold
+      and component_size
+      and cloud_api.Capability.SLICED_DOWNLOAD in api_capabilities
+      and task_util.should_use_parallelism()
+  )
 
 
 class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
@@ -134,7 +144,7 @@ class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
 
   def _get_temporary_destination_resource(self):
     temporary_resource = copy.deepcopy(self._destination_resource)
-    temporary_resource.storage_url.object_name += (
+    temporary_resource.storage_url.resource_name += (
         storage_url.TEMPORARY_FILE_SUFFIX)
     return temporary_resource
 
@@ -182,7 +192,7 @@ class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
     log.status.Print('Temporary download file corrupt.'
                      ' Restarting download {}'.format(self._source_resource))
     temporary_download_url = self._temporary_destination_resource.storage_url
-    os.remove(temporary_download_url.object_name)
+    os.remove(temporary_download_url.resource_name)
     tracker_file_util.delete_download_tracker_files(temporary_download_url)
 
   def execute(self, task_status_queue=None):
@@ -205,7 +215,7 @@ class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
     # more information: https://github.com/GoogleCloudPlatform/gsutil/pull/1202.
     # Note that it's not enough to check the results of `exists()`, since that
     # method returns False if the path points to a broken symlink.
-    is_destination_symlink = os.path.islink(destination_url.object_name)
+    is_destination_symlink = os.path.islink(destination_url.resource_name)
     if is_destination_symlink or destination_url.exists():
       if self._user_request_args and self._user_request_args.no_clobber:
         log.status.Print(copy_util.get_no_clobber_message(destination_url))
@@ -215,12 +225,12 @@ class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
               self._destination_resource,
               copy_util.get_no_clobber_message(destination_url))
         return
-      os.remove(destination_url.object_name)
+      os.remove(destination_url.resource_name)
 
     temporary_download_file_exists = (
         self._temporary_destination_resource.storage_url.exists())
     if temporary_download_file_exists and os.path.getsize(
-        self._temporary_destination_resource.storage_url.object_name
+        self._temporary_destination_resource.storage_url.resource_name
     ) > self._source_resource.size:
       self._restart_download()
 
@@ -276,8 +286,8 @@ class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
     )
     download_util.finalize_download(
         self._source_resource,
-        temporary_file_url.object_name,
-        destination_url.object_name,
+        temporary_file_url.resource_name,
+        destination_url.resource_name,
         convert_symlinks=preserve_symlinks,
         do_not_decompress_flag=self._do_not_decompress,
         server_encoding=server_encoding,
