@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,9 +14,6 @@
 # limitations under the License.
 
 """OS specific console_attr helper functions."""
-# This file contains platform specific code which is not currently handled
-# by pytype.
-# pytype: skip-file
 
 from __future__ import absolute_import
 from __future__ import division
@@ -26,6 +23,7 @@ import os
 import sys
 
 from googlecloudsdk.core.util import encoding
+from googlecloudsdk.core.util import platforms
 
 
 def GetTermSize():
@@ -258,3 +256,28 @@ def _GetRawKeyFunctionWindows():
     return None if c in (_CONTROL_D, _CONTROL_Z) else c
 
   return _GetRawKeyWindows
+
+
+def ForceEnableAnsi():
+  """Attempts to enable virtual terminal processing on Windows.
+
+  Returns:
+    bool: True if ANSI support is now active; False otherwise.
+  """
+  if platforms.OperatingSystem.Current() != platforms.OperatingSystem.WINDOWS:
+    return False
+
+  try:
+    import ctypes  # pylint:disable=g-import-not-at-top
+
+    enable_virtual_terminal_processing = 0x0004
+    h = ctypes.windll.kernel32.GetStdHandle(-11)  # stdout handle is -11
+    old_mode = ctypes.wintypes.DWORD()
+
+    if ctypes.windll.kernel32.GetConsoleMode(h, ctypes.byref(old_mode)):
+      if ctypes.windll.kernel32.SetConsoleMode(
+          h, old_mode.value | enable_virtual_terminal_processing):
+        return True
+  except (OSError, AttributeError):
+    pass  # If we cannot force ANSI, we should simply return False
+  return False
