@@ -62,7 +62,6 @@ from googlecloudsdk.core.util import times_data
 
 import six
 
-
 try:
   from dateutil import tzwin  # pylint: disable=g-import-not-at-top, Windows
 except ImportError:
@@ -102,7 +101,9 @@ def _StrFtime(dt, fmt):
   """Convert strftime exceptions to Datetime Errors."""
   try:
     return dt.strftime(fmt)
-  except TypeError as e:
+  # With dateutil 2.8, strftime() now raises a UnicodeError when it cannot
+  # decode the string as 'ascii' on Python 2.
+  except (TypeError, UnicodeError) as e:
     if '%Z' not in fmt:
       raise DateTimeValueError(six.text_type(e))
     # Most likely a non-ascii tzname() in python2. Fall back to +-HH:MM.
@@ -178,6 +179,23 @@ def FormatDurationForJson(duration):
   return num + 's'
 
 
+def FormatDurationListForJson(duration_list):
+  """Returns a list of string representations of the durations, ending in 's'.
+
+  It will use FormatDurationForJson to process each duration object in the list.
+
+  Args:
+    duration_list: A list of iso_duration.Duration objects to be formatted.
+
+  Raises:
+    DurationValueError: A Duration numeric constant exceeded its range.
+
+  Returns:
+    A list of strings representation of the duration.
+  """
+  return [FormatDurationForJson(duration) for duration in duration_list]
+
+
 def ParseDuration(string, calendar=False, default_suffix=None):
   """Parses a duration string and returns a Duration object.
 
@@ -373,6 +391,26 @@ def FormatDateTime(dt, fmt=None, tzinfo=None):
   return ''.join(parts)
 
 
+def FormatDateTimeList(dt_list, fmt=None, tzinfo=None):
+  """Returns a list of strings of datetime objects formatted by FormatDateTime.
+
+  It will use FormatDateTime to process each datetime object in the list.
+
+  Args:
+    dt_list: A list of datetime objects to be formatted.
+    fmt: The strftime(3) format string, None for the RFC 3339 format in the dt
+      timezone ('%Y-%m-%dT%H:%M:%S.%3f%Ez').
+    tzinfo: Format dt relative to this timezone.
+
+  Raises:
+    DateTimeValueError: A DateTime numeric constant exceeded its range.
+
+  Returns:
+    A list of strings of a datetime objects formatted by an extended strftime().
+  """
+  return [FormatDateTime(dt, fmt, tzinfo) for dt in dt_list]
+
+
 class _TzInfoOrOffsetGetter(object):
   """A helper class for dateutil.parser.parse().
 
@@ -503,7 +541,10 @@ def GetDateTimeFromTimeStamp(timestamp, tzinfo=LOCAL):
   """
   try:
     return datetime.datetime.fromtimestamp(timestamp, tzinfo)
-  except ValueError as e:
+  # From python 3.3, it raises OverflowError instead of ValueError if the
+  # timestamp is out of the range of values supported by C localtime().
+  # It raises OSError instead of ValueError on localtime() failure.
+  except (ValueError, OSError, OverflowError) as e:
     raise DateTimeValueError(six.text_type(e))
 
 
