@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import json
+import logging as std_logging
+import pickle
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
@@ -22,8 +25,11 @@ from google.api_core import gapic_v1
 import google.auth                         # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+from cloudsdk.google.protobuf.json_format import MessageToJson
+import cloudsdk.google.protobuf.message
 
 import grpc  # type: ignore
+import proto  # type: ignore
 
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
@@ -32,6 +38,73 @@ from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import job
 from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import job as gcr_job
 from .base import JobsTransport, DEFAULT_CLIENT_INFO
 
+try:
+    from google.api_core import client_logging  # type: ignore
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):  # pragma: NO COVER
+    def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(std_logging.DEBUG)
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, cloudsdk.google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra = {
+                    "serviceName": "google.cloud.run.v2.Jobs",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = dict([(k, str(v)) for k, v in response_metadata]) if response_metadata else None
+            result = response.result()
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, cloudsdk.google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response for {client_call_details.method}.",
+                extra = {
+                    "serviceName": "google.cloud.run.v2.Jobs",
+                    "rpcName": client_call_details.method,
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class JobsGrpcTransport(JobsTransport):
     """gRPC backend transport for Jobs.
@@ -73,9 +146,10 @@ class JobsGrpcTransport(JobsTransport):
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
                 This argument is ignored if a ``channel`` instance is provided.
-            credentials_file (Optional[str]): A file with credentials that can
+            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is ignored if a ``channel`` instance is provided.
+                This argument will be removed in the next major version of this library.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if a ``channel`` instance is provided.
             channel (Optional[Union[grpc.Channel, Callable[..., grpc.Channel]]]):
@@ -125,7 +199,8 @@ class JobsGrpcTransport(JobsTransport):
 
         if isinstance(channel, grpc.Channel):
             # Ignore credentials if a channel was passed.
-            credentials = False
+            credentials = None
+            self._ignore_credentials = True
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
@@ -182,7 +257,10 @@ class JobsGrpcTransport(JobsTransport):
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientInterceptor()
+        self._logged_channel =  grpc.intercept_channel(self._grpc_channel, self._interceptor)
+
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @classmethod
@@ -201,9 +279,10 @@ class JobsGrpcTransport(JobsTransport):
                 credentials identify this application to the service. If
                 none are specified, the client will attempt to ascertain
                 the credentials from the environment.
-            credentials_file (Optional[str]): A file with credentials that can
+            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                This argument is mutually exclusive with credentials.
+                This argument is mutually exclusive with credentials.  This argument will be
+                removed in the next major version of this library.
             scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                 service. These are only used when credentials are not specified and
                 are passed to :func:`google.auth.default`.
@@ -246,7 +325,7 @@ class JobsGrpcTransport(JobsTransport):
         # Quick check: Only create a new client if we do not already have one.
         if self._operations_client is None:
             self._operations_client = operations_v1.OperationsClient(
-                self.grpc_channel
+                self._logged_channel
             )
 
         # Return the client from cache.
@@ -271,7 +350,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'create_job' not in self._stubs:
-            self._stubs['create_job'] = self.grpc_channel.unary_unary(
+            self._stubs['create_job'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/CreateJob',
                 request_serializer=gcr_job.CreateJobRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -297,7 +376,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'get_job' not in self._stubs:
-            self._stubs['get_job'] = self.grpc_channel.unary_unary(
+            self._stubs['get_job'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/GetJob',
                 request_serializer=job.GetJobRequest.serialize,
                 response_deserializer=job.Job.deserialize,
@@ -324,7 +403,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'list_jobs' not in self._stubs:
-            self._stubs['list_jobs'] = self.grpc_channel.unary_unary(
+            self._stubs['list_jobs'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/ListJobs',
                 request_serializer=job.ListJobsRequest.serialize,
                 response_deserializer=job.ListJobsResponse.deserialize,
@@ -350,7 +429,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'update_job' not in self._stubs:
-            self._stubs['update_job'] = self.grpc_channel.unary_unary(
+            self._stubs['update_job'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/UpdateJob',
                 request_serializer=gcr_job.UpdateJobRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -376,7 +455,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'delete_job' not in self._stubs:
-            self._stubs['delete_job'] = self.grpc_channel.unary_unary(
+            self._stubs['delete_job'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/DeleteJob',
                 request_serializer=job.DeleteJobRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -402,7 +481,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'run_job' not in self._stubs:
-            self._stubs['run_job'] = self.grpc_channel.unary_unary(
+            self._stubs['run_job'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/RunJob',
                 request_serializer=job.RunJobRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
@@ -430,7 +509,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'get_iam_policy' not in self._stubs:
-            self._stubs['get_iam_policy'] = self.grpc_channel.unary_unary(
+            self._stubs['get_iam_policy'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/GetIamPolicy',
                 request_serializer=iam_policy_pb2.GetIamPolicyRequest.SerializeToString,
                 response_deserializer=policy_pb2.Policy.FromString,
@@ -457,7 +536,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'set_iam_policy' not in self._stubs:
-            self._stubs['set_iam_policy'] = self.grpc_channel.unary_unary(
+            self._stubs['set_iam_policy'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/SetIamPolicy',
                 request_serializer=iam_policy_pb2.SetIamPolicyRequest.SerializeToString,
                 response_deserializer=policy_pb2.Policy.FromString,
@@ -486,7 +565,7 @@ class JobsGrpcTransport(JobsTransport):
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if 'test_iam_permissions' not in self._stubs:
-            self._stubs['test_iam_permissions'] = self.grpc_channel.unary_unary(
+            self._stubs['test_iam_permissions'] = self._logged_channel.unary_unary(
                 '/google.cloud.run.v2.Jobs/TestIamPermissions',
                 request_serializer=iam_policy_pb2.TestIamPermissionsRequest.SerializeToString,
                 response_deserializer=iam_policy_pb2.TestIamPermissionsResponse.FromString,
@@ -494,7 +573,7 @@ class JobsGrpcTransport(JobsTransport):
         return self._stubs['test_iam_permissions']
 
     def close(self):
-        self.grpc_channel.close()
+        self._logged_channel.close()
 
     @property
     def kind(self) -> str:
