@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,45 +13,56 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import logging
+import json  # type: ignore
 
 from google.auth.transport.requests import AuthorizedSession  # type: ignore
-import json  # type: ignore
-import grpc  # type: ignore
-from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.api_core import exceptions as core_exceptions
 from google.api_core import retry as retries
 from google.api_core import rest_helpers
 from google.api_core import rest_streaming
-from google.api_core import path_template
 from google.api_core import gapic_v1
+import cloudsdk.google.protobuf
 
 from cloudsdk.google.protobuf import json_format
 from google.api_core import operations_v1
+
 from requests import __version__ as requests_version
 import dataclasses
-import re
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
+
+from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import revision
+from google.longrunning import operations_pb2  # type: ignore
+
+
+from .rest_base import _BaseRevisionsRestTransport
+from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object, None]  # type: ignore
 
+try:
+    from google.api_core import client_logging  # type: ignore
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
 
-from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import revision
-from google.longrunning import operations_pb2  # type: ignore
-
-from .base import RevisionsTransport, DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
-
+_LOGGER = logging.getLogger(__name__)
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
     grpc_version=None,
-    rest_version=requests_version,
+    rest_version=f"requests@{requests_version}",
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = cloudsdk.google.protobuf.__version__
+
 
 class RevisionsRestInterceptor:
     """Interceptor for Revisions.
@@ -97,7 +108,7 @@ class RevisionsRestInterceptor:
 
 
     """
-    def pre_delete_revision(self, request: revision.DeleteRevisionRequest, metadata: Sequence[Tuple[str, str]]) -> Tuple[revision.DeleteRevisionRequest, Sequence[Tuple[str, str]]]:
+    def pre_delete_revision(self, request: revision.DeleteRevisionRequest, metadata: Sequence[Tuple[str, Union[str, bytes]]]) -> Tuple[revision.DeleteRevisionRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for delete_revision
 
         Override in a subclass to manipulate the request or metadata
@@ -108,12 +119,32 @@ class RevisionsRestInterceptor:
     def post_delete_revision(self, response: operations_pb2.Operation) -> operations_pb2.Operation:
         """Post-rpc interceptor for delete_revision
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_delete_revision_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the Revisions server but before
-        it is returned to user code.
+        it is returned to user code. This `post_delete_revision` interceptor runs
+        before the `post_delete_revision_with_metadata` interceptor.
         """
         return response
-    def pre_get_revision(self, request: revision.GetRevisionRequest, metadata: Sequence[Tuple[str, str]]) -> Tuple[revision.GetRevisionRequest, Sequence[Tuple[str, str]]]:
+
+    def post_delete_revision_with_metadata(self, response: operations_pb2.Operation, metadata: Sequence[Tuple[str, Union[str, bytes]]]) -> Tuple[operations_pb2.Operation, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for delete_revision
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the Revisions server but before it is returned to user code.
+
+        We recommend only using this `post_delete_revision_with_metadata`
+        interceptor in new development instead of the `post_delete_revision` interceptor.
+        When both interceptors are used, this `post_delete_revision_with_metadata` interceptor runs after the
+        `post_delete_revision` interceptor. The (possibly modified) response returned by
+        `post_delete_revision` will be passed to
+        `post_delete_revision_with_metadata`.
+        """
+        return response, metadata
+
+    def pre_get_revision(self, request: revision.GetRevisionRequest, metadata: Sequence[Tuple[str, Union[str, bytes]]]) -> Tuple[revision.GetRevisionRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for get_revision
 
         Override in a subclass to manipulate the request or metadata
@@ -124,12 +155,32 @@ class RevisionsRestInterceptor:
     def post_get_revision(self, response: revision.Revision) -> revision.Revision:
         """Post-rpc interceptor for get_revision
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_get_revision_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the Revisions server but before
-        it is returned to user code.
+        it is returned to user code. This `post_get_revision` interceptor runs
+        before the `post_get_revision_with_metadata` interceptor.
         """
         return response
-    def pre_list_revisions(self, request: revision.ListRevisionsRequest, metadata: Sequence[Tuple[str, str]]) -> Tuple[revision.ListRevisionsRequest, Sequence[Tuple[str, str]]]:
+
+    def post_get_revision_with_metadata(self, response: revision.Revision, metadata: Sequence[Tuple[str, Union[str, bytes]]]) -> Tuple[revision.Revision, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for get_revision
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the Revisions server but before it is returned to user code.
+
+        We recommend only using this `post_get_revision_with_metadata`
+        interceptor in new development instead of the `post_get_revision` interceptor.
+        When both interceptors are used, this `post_get_revision_with_metadata` interceptor runs after the
+        `post_get_revision` interceptor. The (possibly modified) response returned by
+        `post_get_revision` will be passed to
+        `post_get_revision_with_metadata`.
+        """
+        return response, metadata
+
+    def pre_list_revisions(self, request: revision.ListRevisionsRequest, metadata: Sequence[Tuple[str, Union[str, bytes]]]) -> Tuple[revision.ListRevisionsRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for list_revisions
 
         Override in a subclass to manipulate the request or metadata
@@ -140,12 +191,31 @@ class RevisionsRestInterceptor:
     def post_list_revisions(self, response: revision.ListRevisionsResponse) -> revision.ListRevisionsResponse:
         """Post-rpc interceptor for list_revisions
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_list_revisions_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the Revisions server but before
-        it is returned to user code.
+        it is returned to user code. This `post_list_revisions` interceptor runs
+        before the `post_list_revisions_with_metadata` interceptor.
         """
         return response
 
+    def post_list_revisions_with_metadata(self, response: revision.ListRevisionsResponse, metadata: Sequence[Tuple[str, Union[str, bytes]]]) -> Tuple[revision.ListRevisionsResponse, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for list_revisions
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the Revisions server but before it is returned to user code.
+
+        We recommend only using this `post_list_revisions_with_metadata`
+        interceptor in new development instead of the `post_list_revisions` interceptor.
+        When both interceptors are used, this `post_list_revisions_with_metadata` interceptor runs after the
+        `post_list_revisions` interceptor. The (possibly modified) response returned by
+        `post_list_revisions` will be passed to
+        `post_list_revisions_with_metadata`.
+        """
+        return response, metadata
+
 
 @dataclasses.dataclass
 class RevisionsRestStub:
@@ -154,8 +224,8 @@ class RevisionsRestStub:
     _interceptor: RevisionsRestInterceptor
 
 
-class RevisionsRestTransport(RevisionsTransport):
-    """REST backend transport for Revisions.
+class RevisionsRestTransport(_BaseRevisionsRestTransport):
+    """REST backend synchronous transport for Revisions.
 
     Cloud Run Revision Control Plane API.
 
@@ -164,10 +234,6 @@ class RevisionsRestTransport(RevisionsTransport):
     and call it.
 
     It sends JSON representations of protocol buffers over HTTP/1.1
-
-    NOTE: This REST transport functionality is currently in a beta
-    state (preview). We welcome your feedback via an issue in this
-    library's source repository. Thank you!
     """
 
     def __init__(self, *,
@@ -199,9 +265,10 @@ class RevisionsRestTransport(RevisionsTransport):
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
 
-            credentials_file (Optional[str]): A file with credentials that can
+            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                This argument is ignored if ``channel`` is provided.
+                This argument is ignored if ``channel`` is provided. This argument will be
+                removed in the next major version of this library.
             scopes (Optional(Sequence[str])): A list of scopes. This argument is
                 ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
@@ -224,19 +291,12 @@ class RevisionsRestTransport(RevisionsTransport):
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
         # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
         # credentials object
-        maybe_url_match = re.match("^(?P<scheme>http(?:s)?://)?(?P<host>.*)$", host)
-        if maybe_url_match is None:
-            raise ValueError(f"Unexpected hostname structure: {host}")  # pragma: NO COVER
-
-        url_match_items = maybe_url_match.groupdict()
-
-        host = f"{url_scheme}://{host}" if not url_match_items["scheme"] else host
-
         super().__init__(
             host=host,
             credentials=credentials,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            url_scheme=url_scheme,
             api_audience=api_audience
         )
         self._session = AuthorizedSession(
@@ -272,22 +332,37 @@ class RevisionsRestTransport(RevisionsTransport):
         # Return the client from cache.
         return self._operations_client
 
-    class _DeleteRevision(RevisionsRestStub):
+    class _DeleteRevision(_BaseRevisionsRestTransport._BaseDeleteRevision, RevisionsRestStub):
         def __hash__(self):
-            return hash("DeleteRevision")
+            return hash("RevisionsRestTransport.DeleteRevision")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] =  {
-        }
+        @staticmethod
+        def _get_response(
+            host,
+            metadata,
+            query_params,
+            session,
+            timeout,
+            transcoded_request,
+            body=None):
 
-        @classmethod
-        def _get_unset_required_fields(cls, message_dict):
-            return {k: v for k, v in cls.__REQUIRED_FIELDS_DEFAULT_VALUES.items() if k not in message_dict}
+            uri = transcoded_request['uri']
+            method = transcoded_request['method']
+            headers = dict(metadata)
+            headers['Content-Type'] = 'application/json'
+            response = getattr(session, method)(
+                "{host}{uri}".format(host=host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
+                )
+            return response
 
         def __call__(self,
                 request: revision.DeleteRevisionRequest, *,
                 retry: OptionalRetry=gapic_v1.method.DEFAULT,
                 timeout: Optional[float]=None,
-                metadata: Sequence[Tuple[str, str]]=(),
+                metadata: Sequence[Tuple[str, Union[str, bytes]]]=(),
                 ) -> operations_pb2.Operation:
             r"""Call the delete revision method over HTTP.
 
@@ -301,8 +376,10 @@ class RevisionsRestTransport(RevisionsTransport):
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.operations_pb2.Operation:
@@ -312,34 +389,39 @@ class RevisionsRestTransport(RevisionsTransport):
 
             """
 
-            http_options: List[Dict[str, str]] = [{
-                'method': 'delete',
-                'uri': '/v2/{name=projects/*/locations/*/services/*/revisions/*}',
-            },
-            ]
-            request, metadata = self._interceptor.pre_delete_revision(request, metadata)
-            pb_request = revision.DeleteRevisionRequest.pb(request)
-            transcoded_request = path_template.transcode(http_options, pb_request)
+            http_options = _BaseRevisionsRestTransport._BaseDeleteRevision._get_http_options()
 
-            uri = transcoded_request['uri']
-            method = transcoded_request['method']
+            request, metadata = self._interceptor.pre_delete_revision(request, metadata)
+            transcoded_request = _BaseRevisionsRestTransport._BaseDeleteRevision._get_transcoded_request(http_options, request)
 
             # Jsonify the query params
-            query_params = json.loads(json_format.MessageToJson(
-                transcoded_request['query_params'],
-                use_integers_for_enums=False,
-            ))
-            query_params.update(self._get_unset_required_fields(query_params))
+            query_params = _BaseRevisionsRestTransport._BaseDeleteRevision._get_query_params_json(transcoded_request)
+
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(logging.DEBUG):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(host=self._host, uri=transcoded_request['uri'])
+                method = transcoded_request['method']
+                try:
+                    request_payload = json_format.MessageToJson(request)
+                except:
+                    request_payload = None
+                http_request = {
+                  "payload": request_payload,
+                  "requestMethod": method,
+                  "requestUrl": request_url,
+                  "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.run_v2.RevisionsClient.DeleteRevision",
+                    extra = {
+                        "serviceName": "google.cloud.run.v2.Revisions",
+                        "rpcName": "DeleteRevision",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
 
             # Send the request
-            headers = dict(metadata)
-            headers['Content-Type'] = 'application/json'
-            response = getattr(self._session, method)(
-                "{host}{uri}".format(host=self._host, uri=uri),
-                timeout=timeout,
-                headers=headers,
-                params=rest_helpers.flatten_query_params(query_params, strict=True),
-                )
+            response = RevisionsRestTransport._DeleteRevision._get_response(self._host, metadata, query_params, self._session, timeout, transcoded_request)
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
             # subclass.
@@ -349,25 +431,62 @@ class RevisionsRestTransport(RevisionsTransport):
             # Return the response
             resp = operations_pb2.Operation()
             json_format.Parse(response.content, resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_delete_revision(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_delete_revision_with_metadata(resp, response_metadata)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(logging.DEBUG):  # pragma: NO COVER
+                try:
+                    response_payload = json_format.MessageToJson(resp)
+                except:
+                    response_payload = None
+                http_response = {
+                "payload": response_payload,
+                "headers":  dict(response.headers),
+                "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.run_v2.RevisionsClient.delete_revision",
+                    extra = {
+                        "serviceName": "google.cloud.run.v2.Revisions",
+                        "rpcName": "DeleteRevision",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
-    class _GetRevision(RevisionsRestStub):
+    class _GetRevision(_BaseRevisionsRestTransport._BaseGetRevision, RevisionsRestStub):
         def __hash__(self):
-            return hash("GetRevision")
+            return hash("RevisionsRestTransport.GetRevision")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] =  {
-        }
+        @staticmethod
+        def _get_response(
+            host,
+            metadata,
+            query_params,
+            session,
+            timeout,
+            transcoded_request,
+            body=None):
 
-        @classmethod
-        def _get_unset_required_fields(cls, message_dict):
-            return {k: v for k, v in cls.__REQUIRED_FIELDS_DEFAULT_VALUES.items() if k not in message_dict}
+            uri = transcoded_request['uri']
+            method = transcoded_request['method']
+            headers = dict(metadata)
+            headers['Content-Type'] = 'application/json'
+            response = getattr(session, method)(
+                "{host}{uri}".format(host=host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
+                )
+            return response
 
         def __call__(self,
                 request: revision.GetRevisionRequest, *,
                 retry: OptionalRetry=gapic_v1.method.DEFAULT,
                 timeout: Optional[float]=None,
-                metadata: Sequence[Tuple[str, str]]=(),
+                metadata: Sequence[Tuple[str, Union[str, bytes]]]=(),
                 ) -> revision.Revision:
             r"""Call the get revision method over HTTP.
 
@@ -378,8 +497,10 @@ class RevisionsRestTransport(RevisionsTransport):
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.revision.Revision:
@@ -391,34 +512,39 @@ class RevisionsRestTransport(RevisionsTransport):
 
             """
 
-            http_options: List[Dict[str, str]] = [{
-                'method': 'get',
-                'uri': '/v2/{name=projects/*/locations/*/services/*/revisions/*}',
-            },
-            ]
-            request, metadata = self._interceptor.pre_get_revision(request, metadata)
-            pb_request = revision.GetRevisionRequest.pb(request)
-            transcoded_request = path_template.transcode(http_options, pb_request)
+            http_options = _BaseRevisionsRestTransport._BaseGetRevision._get_http_options()
 
-            uri = transcoded_request['uri']
-            method = transcoded_request['method']
+            request, metadata = self._interceptor.pre_get_revision(request, metadata)
+            transcoded_request = _BaseRevisionsRestTransport._BaseGetRevision._get_transcoded_request(http_options, request)
 
             # Jsonify the query params
-            query_params = json.loads(json_format.MessageToJson(
-                transcoded_request['query_params'],
-                use_integers_for_enums=False,
-            ))
-            query_params.update(self._get_unset_required_fields(query_params))
+            query_params = _BaseRevisionsRestTransport._BaseGetRevision._get_query_params_json(transcoded_request)
+
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(logging.DEBUG):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(host=self._host, uri=transcoded_request['uri'])
+                method = transcoded_request['method']
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                  "payload": request_payload,
+                  "requestMethod": method,
+                  "requestUrl": request_url,
+                  "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.run_v2.RevisionsClient.GetRevision",
+                    extra = {
+                        "serviceName": "google.cloud.run.v2.Revisions",
+                        "rpcName": "GetRevision",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
 
             # Send the request
-            headers = dict(metadata)
-            headers['Content-Type'] = 'application/json'
-            response = getattr(self._session, method)(
-                "{host}{uri}".format(host=self._host, uri=uri),
-                timeout=timeout,
-                headers=headers,
-                params=rest_helpers.flatten_query_params(query_params, strict=True),
-                )
+            response = RevisionsRestTransport._GetRevision._get_response(self._host, metadata, query_params, self._session, timeout, transcoded_request)
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
             # subclass.
@@ -430,25 +556,62 @@ class RevisionsRestTransport(RevisionsTransport):
             pb_resp = revision.Revision.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_get_revision(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_get_revision_with_metadata(resp, response_metadata)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(logging.DEBUG):  # pragma: NO COVER
+                try:
+                    response_payload = revision.Revision.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                "payload": response_payload,
+                "headers":  dict(response.headers),
+                "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.run_v2.RevisionsClient.get_revision",
+                    extra = {
+                        "serviceName": "google.cloud.run.v2.Revisions",
+                        "rpcName": "GetRevision",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
-    class _ListRevisions(RevisionsRestStub):
+    class _ListRevisions(_BaseRevisionsRestTransport._BaseListRevisions, RevisionsRestStub):
         def __hash__(self):
-            return hash("ListRevisions")
+            return hash("RevisionsRestTransport.ListRevisions")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] =  {
-        }
+        @staticmethod
+        def _get_response(
+            host,
+            metadata,
+            query_params,
+            session,
+            timeout,
+            transcoded_request,
+            body=None):
 
-        @classmethod
-        def _get_unset_required_fields(cls, message_dict):
-            return {k: v for k, v in cls.__REQUIRED_FIELDS_DEFAULT_VALUES.items() if k not in message_dict}
+            uri = transcoded_request['uri']
+            method = transcoded_request['method']
+            headers = dict(metadata)
+            headers['Content-Type'] = 'application/json'
+            response = getattr(session, method)(
+                "{host}{uri}".format(host=host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
+                )
+            return response
 
         def __call__(self,
                 request: revision.ListRevisionsRequest, *,
                 retry: OptionalRetry=gapic_v1.method.DEFAULT,
                 timeout: Optional[float]=None,
-                metadata: Sequence[Tuple[str, str]]=(),
+                metadata: Sequence[Tuple[str, Union[str, bytes]]]=(),
                 ) -> revision.ListRevisionsResponse:
             r"""Call the list revisions method over HTTP.
 
@@ -459,8 +622,10 @@ class RevisionsRestTransport(RevisionsTransport):
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.revision.ListRevisionsResponse:
@@ -469,34 +634,39 @@ class RevisionsRestTransport(RevisionsTransport):
 
             """
 
-            http_options: List[Dict[str, str]] = [{
-                'method': 'get',
-                'uri': '/v2/{parent=projects/*/locations/*/services/*}/revisions',
-            },
-            ]
-            request, metadata = self._interceptor.pre_list_revisions(request, metadata)
-            pb_request = revision.ListRevisionsRequest.pb(request)
-            transcoded_request = path_template.transcode(http_options, pb_request)
+            http_options = _BaseRevisionsRestTransport._BaseListRevisions._get_http_options()
 
-            uri = transcoded_request['uri']
-            method = transcoded_request['method']
+            request, metadata = self._interceptor.pre_list_revisions(request, metadata)
+            transcoded_request = _BaseRevisionsRestTransport._BaseListRevisions._get_transcoded_request(http_options, request)
 
             # Jsonify the query params
-            query_params = json.loads(json_format.MessageToJson(
-                transcoded_request['query_params'],
-                use_integers_for_enums=False,
-            ))
-            query_params.update(self._get_unset_required_fields(query_params))
+            query_params = _BaseRevisionsRestTransport._BaseListRevisions._get_query_params_json(transcoded_request)
+
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(logging.DEBUG):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(host=self._host, uri=transcoded_request['uri'])
+                method = transcoded_request['method']
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                  "payload": request_payload,
+                  "requestMethod": method,
+                  "requestUrl": request_url,
+                  "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.run_v2.RevisionsClient.ListRevisions",
+                    extra = {
+                        "serviceName": "google.cloud.run.v2.Revisions",
+                        "rpcName": "ListRevisions",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
 
             # Send the request
-            headers = dict(metadata)
-            headers['Content-Type'] = 'application/json'
-            response = getattr(self._session, method)(
-                "{host}{uri}".format(host=self._host, uri=uri),
-                timeout=timeout,
-                headers=headers,
-                params=rest_helpers.flatten_query_params(query_params, strict=True),
-                )
+            response = RevisionsRestTransport._ListRevisions._get_response(self._host, metadata, query_params, self._session, timeout, transcoded_request)
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
             # subclass.
@@ -508,7 +678,29 @@ class RevisionsRestTransport(RevisionsTransport):
             pb_resp = revision.ListRevisionsResponse.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_list_revisions(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_list_revisions_with_metadata(resp, response_metadata)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(logging.DEBUG):  # pragma: NO COVER
+                try:
+                    response_payload = revision.ListRevisionsResponse.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                "payload": response_payload,
+                "headers":  dict(response.headers),
+                "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.run_v2.RevisionsClient.list_revisions",
+                    extra = {
+                        "serviceName": "google.cloud.run.v2.Revisions",
+                        "rpcName": "ListRevisions",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     @property
