@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -50,6 +50,11 @@ class CommitResponse(proto.Message):
             precommit token.
 
             This field is a member of `oneof`_ ``MultiplexedSessionRetry``.
+        snapshot_timestamp (google.protobuf.timestamp_pb2.Timestamp):
+            If ``TransactionOptions.isolation_level`` is set to
+            ``IsolationLevel.REPEATABLE_READ``, then the snapshot
+            timestamp is the timestamp at which all reads in the
+            transaction ran. This timestamp is never returned.
     """
 
     class CommitStats(proto.Message):
@@ -89,6 +94,11 @@ class CommitResponse(proto.Message):
         oneof='MultiplexedSessionRetry',
         message=transaction.MultiplexedSessionPrecommitToken,
     )
+    snapshot_timestamp: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
