@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -75,13 +75,13 @@ class TransactionOptions(proto.Message):
             it prevents read or write transactions from being tracked in
             change streams.
 
-            -  If the DDL option ``allow_txn_exclusion`` is set to
-               ``true``, then the updates made within this transaction
-               aren't recorded in the change stream.
+            - If the DDL option ``allow_txn_exclusion`` is set to
+              ``true``, then the updates made within this transaction
+              aren't recorded in the change stream.
 
-            -  If you don't set the DDL option ``allow_txn_exclusion``
-               or if it's set to ``false``, then the updates made within
-               this transaction are recorded in the change stream.
+            - If you don't set the DDL option ``allow_txn_exclusion`` or
+              if it's set to ``false``, then the updates made within
+              this transaction are recorded in the change stream.
 
             When ``exclude_txn_from_change_streams`` is set to ``false``
             or not set, modifications from this transaction are recorded
@@ -95,8 +95,9 @@ class TransactionOptions(proto.Message):
             Isolation level for the transaction.
     """
     class IsolationLevel(proto.Enum):
-        r"""``IsolationLevel`` is used when setting ``isolation_level`` for a
-        transaction.
+        r"""``IsolationLevel`` is used when setting the `isolation
+        level <https://cloud.google.com/spanner/docs/isolation-levels>`__
+        for a transaction.
 
         Values:
             ISOLATION_LEVEL_UNSPECIFIED (0):
@@ -123,8 +124,8 @@ class TransactionOptions(proto.Message):
                 ``SERIALIZABLE`` transactions, only write-write conflicts
                 are detected in snapshot transactions.
 
-                This isolation level does not support Read-only and
-                Partitioned DML transactions.
+                This isolation level does not support read-only and
+                partitioned DML transactions.
 
                 When ``REPEATABLE_READ`` is specified on a read-write
                 transaction, the locking semantics default to
@@ -155,22 +156,22 @@ class TransactionOptions(proto.Message):
                 READ_LOCK_MODE_UNSPECIFIED (0):
                     Default value.
 
-                    -  If isolation level is
-                       [REPEATABLE_READ][google.spanner.v1.TransactionOptions.IsolationLevel.REPEATABLE_READ],
-                       then it is an error to specify ``read_lock_mode``.
-                       Locking semantics default to ``OPTIMISTIC``. No
-                       validation checks are done for reads, except to validate
-                       that the data that was served at the snapshot time is
-                       unchanged at commit time in the following cases:
+                    - If isolation level is
+                      [REPEATABLE_READ][google.spanner.v1.TransactionOptions.IsolationLevel.REPEATABLE_READ],
+                      then it is an error to specify ``read_lock_mode``. Locking
+                      semantics default to ``OPTIMISTIC``. No validation checks
+                      are done for reads, except to validate that the data that
+                      was served at the snapshot time is unchanged at commit
+                      time in the following cases:
 
-                       1. reads done as part of queries that use
-                          ``SELECT FOR UPDATE``
-                       2. reads done as part of statements with a
-                          ``LOCK_SCANNED_RANGES`` hint
-                       3. reads done as part of DML statements
+                      1. reads done as part of queries that use
+                         ``SELECT FOR UPDATE``
+                      2. reads done as part of statements with a
+                         ``LOCK_SCANNED_RANGES`` hint
+                      3. reads done as part of DML statements
 
-                    -  At all other isolation levels, if ``read_lock_mode`` is
-                       the default value, then pessimistic read locks are used.
+                    - At all other isolation levels, if ``read_lock_mode`` is
+                      the default value, then pessimistic read locks are used.
                 PESSIMISTIC (1):
                     Pessimistic lock mode.
 
