@@ -32,6 +32,7 @@ from googlecloudsdk.core import resources
 @base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class Restore(base.RestoreCommand):
+  # TODO(b/407008589): update the description and examples for Backup DR.
   """Restore an AlloyDB cluster from a given backup or a source cluster and a timestamp."""
 
   detailed_help = {
@@ -67,15 +68,15 @@ class Restore(base.RestoreCommand):
         ),
     )
 
-  @staticmethod
-  def Args(parser):
+  @classmethod
+  def Args(cls, parser):
     """Specifies additional command flags.
 
     Args:
       parser: argparse.Parser: Parser object for command line inputs.
     """
     Restore.CommonArgs(parser)
-    flags.AddRestoreClusterSourceFlags(parser)
+    flags.AddRestoreClusterSourceFlags(parser, cls.ReleaseTrack())
 
   def ConstructRestoreRequestFromArgs(self, alloydb_messages, location_ref,
                                       resource_parser, args):
