@@ -22,6 +22,16 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA,
+    base.ReleaseTrack.BETA,
+    base.ReleaseTrack.GA,
+)
 class Anthos(base.Group):
   """Anthos command Group."""
   category = base.ANTHOS_CLI_CATEGORY
+
+  def Filter(self, context, args):
+    # TODO(b/190523915):  Determine if command group works with project number
+    base.RequireProjectID(args)
+    del context, args
