@@ -1,4 +1,5 @@
-# Copyright 2017 Google Inc. All Rights Reserved.
+# -*- coding: utf-8 -*- #
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +14,10 @@
 # limitations under the License.
 """Surface for retrieving a single SSL certificate for an App Engine app."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.app.api import appengine_ssl_api_client as api_client
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.app import flags
@@ -37,5 +42,5 @@ class Describe(base.DescribeCommand):
     flags.CERTIFICATE_ID_FLAG.AddToParser(parser)
 
   def Run(self, args):
-    client = api_client.GetApiClient(self.ReleaseTrack())
+    client = api_client.GetApiClientForTrack(self.ReleaseTrack())
     return client.GetSslCertificate(args.id)
