@@ -21,7 +21,8 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class AuditManager(base.Group):
   """Enroll resources, audit workloads and generate reports."""
 
@@ -32,3 +33,9 @@ class AuditManager(base.Group):
     # Don't ever take this off. Use gcloud quota for projects operations so
     # you can create a project before you have a project.
     base.DisableUserProjectQuota()
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class AuditManagerAlpha(AuditManager):
+  """Enroll resources, audit workloads and generate reports."""
