@@ -20,8 +20,9 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
-from googlecloudsdk.command_lib.auth import auth_util
 from googlecloudsdk.core import log
+from googlecloudsdk.core import properties
+from googlecloudsdk.core.credentials import store as c_store
 
 
 class List(base.ListCommand):
@@ -64,13 +65,54 @@ class List(base.ListCommand):
         List only credentials for one account. Use
         --filter="account~_PATTERN_" to select accounts that match
         _PATTERN_.""")
-    parser.display_info.AddFormat(auth_util.ACCOUNT_TABLE_FORMAT)
 
   def Run(self, args):
-    accounts = auth_util.AllAccounts()
+    """Run the 'gcloud auth list' command to list the accounts.
+
+    Args:
+      args: an argparse namespace. All the arguments that were provided to this
+        command invocation (i.e. group and command arguments combined).
+
+    Returns:
+      [googlecloudsdk.core.credentials.store.AcctInfo] or
+        [googlecloudsdk.core.credentials.store.AcctInfoWithUniverseDomain]: A
+        list of AcctInfo objects if all accounts are from googleapis.com,
+        otherwise a list of AcctInfoWithUniverseDomain objects.
+    """
+    account_info_list = c_store.AllAccountsWithUniverseDomains()
     if args.filter_account:
-      accounts = [a for a in accounts if a.account == args.filter_account]
-    return accounts
+      account_info_list = [
+          account_info
+          for account_info in account_info_list
+          if account_info.account == args.filter_account
+      ]
+
+    # If any of the accounts are non-GDU, then we should output the universe
+    # domain column.
+    show_universe_domain = False
+    for account_info in account_info_list:
+      if (
+          account_info.universe_domain
+          != properties.VALUES.core.universe_domain.default
+      ):
+        show_universe_domain = True
+        break
+
+    if show_universe_domain:
+      # Use the format with UNIVERSE_DOMAIN column.
+      args.GetDisplayInfo().AddFormat(
+          c_store.ACCOUNT_TABLE_WITH_UNIVERSE_DOMAIN_FORMAT
+      )
+    else:
+      # Convert to AcctInfo list, which doesn't contain universe domain info.
+      account_info_list = [
+          c_store.AcctInfo(account_info.account, account_info.status)
+          for account_info in account_info_list
+      ]
+      # Use the format without UNIVERSE_DOMAIN column.
+      args.GetDisplayInfo().AddFormat(c_store.ACCOUNT_TABLE_FORMAT)
+
+    return account_info_list
 
   def Epilog(self, resources_were_displayed):
     if resources_were_displayed:
