@@ -151,14 +151,13 @@ def _CommonArgs(parser):
   return network_group
 
 
-def _BuildJobMsg(args, job_msg, batch_msgs, release_track):
+def _BuildJobMsg(args, job_msg, batch_msgs):
   """Build the job API message from the args.
 
   Args:
     args: the args from the parser.
     job_msg: the output job message.
     batch_msgs: the related version of the batch message.
-    release_track: the release track from which _BuildJobMsg was called.
   """
 
   if job_msg.taskGroups is None:
@@ -202,19 +201,14 @@ def _BuildJobMsg(args, job_msg, batch_msgs, release_track):
   if args.priority:
     job_msg.priority = args.priority
 
-  # Add default empty allocation policy if there is no allocation policy.
-  # For alpha track, add only if an allocation policy is needed by some other
-  # argument.
-  if release_track == base.ReleaseTrack.ALPHA:
-    if job_msg.allocationPolicy is None and (
-        args.machine_type
-        or (args.network and args.subnetwork)
-        or args.provisioning_model
-    ):
-      job_msg.allocationPolicy = batch_msgs.AllocationPolicy()
-  else:
-    if job_msg.allocationPolicy is None:
-      job_msg.allocationPolicy = batch_msgs.AllocationPolicy()
+  # Add default empty allocation policy if there is no allocation policy and an
+  # allocation policy is needed by some other argument.
+  if job_msg.allocationPolicy is None and (
+      args.machine_type
+      or (args.network and args.subnetwork)
+      or args.provisioning_model
+  ):
+    job_msg.allocationPolicy = batch_msgs.AllocationPolicy()
 
   if args.machine_type:
     if job_msg.allocationPolicy.instances is None:
@@ -343,7 +337,7 @@ class Submit(base.Command):
     if args.config:
       job_msg = self._CreateJobMessage(batch_msgs, args.config)
 
-    _BuildJobMsg(args, job_msg, batch_msgs, release_track)
+    _BuildJobMsg(args, job_msg, batch_msgs)
 
     resp = batch_client.Create(job_id, location_ref, job_msg)
     log.status.Print(
@@ -354,7 +348,7 @@ class Submit(base.Command):
   def _GetJobId(self, job_ref, args):
     job_id = job_ref.RelativeName().split('/')[-1]
 
-    if job_id != resource_args.INVALIDJOBID and args.job_prefix:
+    if job_id != resource_args.INVALIDID and args.job_prefix:
       raise exceptions.Error(
           '--job-prefix cannot be specified when JOB ID positional '
           'argument is specified'
@@ -369,7 +363,7 @@ class Submit(base.Command):
       )
 
     # The case that both positional JOB ID and prefix are not specified
-    elif job_id == resource_args.INVALIDJOBID:
+    elif job_id == resource_args.INVALIDID:
       job_id = None
 
     return job_id
