@@ -12,7 +12,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""The command group for Google Cloud Build's GitLab Enterprise Configs."""
+"""The command group for Cloud Build's GitLab Enterprise Configs."""
 
 from __future__ import absolute_import
 from __future__ import division
@@ -23,5 +23,5 @@ from googlecloudsdk.calliope import base
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class GitLab(base.Group):
-  """Manage GitLab Enterprise configurations for Google Cloud Build."""
+  """Manage GitLab Enterprise configurations for Cloud Build."""
   category = base.CI_CD_CATEGORY
