@@ -42,7 +42,7 @@ class CreateGitHub(base.CreateCommand):
 
             To create a pull request trigger with a 2nd gen repository for master:
 
-              $ {command} --name="my-trigger"  --repository=projects/my-project/locations/us-central1/connections/my-conn/repositories/my-repo --pull-request-pattern="^master$" --build-config="cloudbuild.yaml"
+              $ {command} --name="my-trigger"  --repository=projects/my-project/locations/us-central1/connections/my-conn/repositories/my-repo --pull-request-pattern="^master$" --build-config="cloudbuild.yaml" --region=us-central1
 
           """,
   }
@@ -103,21 +103,7 @@ For example, --pull-request-pattern=foo will match "foo", "foobar", and "barfoo"
 The syntax of the regular expressions accepted is the syntax accepted by
 RE2 and described at https://github.com/google/re2/wiki/Syntax.
 """)
-    comment_control_choices = {
-        'COMMENTS_DISABLED': """Do not require comments on Pull Requests before builds are triggered.""",
-        'COMMENTS_ENABLED': """Enforce that repository owners or collaborators must comment on Pull Requests before builds are triggered.""",
-        'COMMENTS_ENABLED_FOR_EXTERNAL_CONTRIBUTORS_ONLY': """Enforce that repository owners or collaborators must comment on external contributors' Pull Requests before builds are triggered.""",
-    }
-
-    pr_config.add_argument(
-        '--comment-control',
-        choices=comment_control_choices,
-        default='COMMENTS_ENABLED',
-        help=("""\
-Require a repository collaborator or owner to comment '/gcbrun' on a pull
-request before running the build.
-"""),
-    )
+    trigger_utils.AddCommentControlArg(pr_config)
 
     trigger_utils.AddBuildConfigArgs(flag_config)
     trigger_utils.AddRepoEventArgs(flag_config)
