@@ -21,13 +21,12 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class CertificateManagerAlphaBeta(base.Group):
   """Manage SSL certificates for your Google Cloud projects."""
 
   category = base.NETWORKING_CATEGORY
 
   def Filter(self, context, args):
-    # TODO(b/190527816):  Determine if command group works with project number
-    base.RequireProjectID(args)
     del context, args
