@@ -23,9 +23,22 @@ from googlecloudsdk.command_lib.composer import resource_args
 from googlecloudsdk.command_lib.composer import storage_util
 
 
+DETAILED_HELP = {
+    'EXAMPLES':
+        """\
+        To list the dags for the Cloud Composer environment
+        ``environment-1'' and location ``us-central1'', run:
+
+          $ {command} --environment=environment-1 --location=us-central1
+        """
+}
+
+
 class List(base.Command):
   """List the DAG files for a Cloud Composer environment."""
 
+  detailed_help = DETAILED_HELP
+
   @staticmethod
   def Args(parser):
     resource_args.AddEnvironmentResourceArg(
