@@ -24,12 +24,15 @@ from googlecloudsdk.api_lib.compute import utils as compute_api
 from googlecloudsdk.api_lib.util import apis
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
+from googlecloudsdk.command_lib.compute import resource_manager_tags_utils
 from googlecloudsdk.command_lib.compute.firewall_rules import flags
 from googlecloudsdk.command_lib.compute.networks import flags as network_flags
 from googlecloudsdk.core.console import progress_tracker
+import six
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.UniverseCompatible
 class Create(base.CreateCommand):
   """Create a Compute Engine firewall rule."""
 
@@ -116,17 +119,43 @@ class Create(base.CreateCommand):
     if args.IsSpecified('logging_metadata') and not args.enable_logging:
       raise exceptions.InvalidArgumentException(
           '--logging-metadata',
-          'cannot toggle logging metadata if logging is not enabled.')
+          'cannot toggle logging metadata if logging is not enabled.',
+      )
 
     if args.IsSpecified('enable_logging'):
       log_config = client.messages.FirewallLogConfig(enable=args.enable_logging)
       if args.IsSpecified('logging_metadata'):
         log_config.metadata = flags.GetLoggingMetadataArg(
-            client.messages).GetEnumForChoice(args.logging_metadata)
+            client.messages
+        ).GetEnumForChoice(args.logging_metadata)
       firewall.logConfig = log_config
 
+    if args.IsSpecified(
+        'resource_manager_tags'
+    ):
+      firewall.params = self._CreateFirewallParams(
+          client.messages, args.resource_manager_tags
+      )
+
     return firewall, firewall_ref.project
 
+  def _CreateFirewallParams(self, messages, resource_manager_tags):
+    resource_manager_tags_map = (
+        resource_manager_tags_utils.GetResourceManagerTags(
+            resource_manager_tags
+        )
+    )
+    params = messages.FirewallParams
+    additional_properties = [
+        params.ResourceManagerTagsValue.AdditionalProperty(key=key, value=value)
+        for key, value in sorted(six.iteritems(resource_manager_tags_map))
+    ]
+    return params(
+        resourceManagerTags=params.ResourceManagerTagsValue(
+            additionalProperties=additional_properties
+        )
+    )
+
   def Run(self, args):
     """Issues requests necessary for adding firewall rules."""
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
