@@ -133,12 +133,13 @@ def _Run(
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class Create(base.CreateCommand):
   """Create a HTTPS health check."""
 
   _include_log_config = True
   _include_weighted_load_balancing = False
-  _include_source_regions = False
+  _include_source_regions = True
   detailed_help = _DetailedHelp()
 
   @classmethod
@@ -165,11 +166,9 @@ class Create(base.CreateCommand):
 class CreateBeta(Create):
 
   _include_weighted_load_balancing = False
-  _include_source_regions = False
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class CreateAlpha(CreateBeta):
 
   _include_weighted_load_balancing = True
-  _include_source_regions = True
