@@ -282,12 +282,13 @@ def _Run(
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class Update(base.UpdateCommand):
   """Update a HTTP health check."""
 
   _include_log_config = True
   _include_weighted_load_balancing = False
-  _include_source_regions = False
+  _include_source_regions = True
   detailed_help = _DetailedHelp()
 
   @classmethod
@@ -314,11 +315,9 @@ class Update(base.UpdateCommand):
 class UpdateBeta(Update):
 
   _include_weighted_load_balancing = False
-  _include_source_regions = False
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class UpdateAlpha(UpdateBeta):
 
   _include_weighted_load_balancing = True
-  _include_source_regions = True
