@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,10 +21,22 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
+@base.UniverseCompatible
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class Images(base.Group):
-  """List, create, and delete Google Compute Engine images."""
+  """List, create, and delete Compute Engine images."""
 
 
+Images.category = base.INSTANCES_CATEGORY
+
 Images.detailed_help = {
-    'brief': 'List, create, and delete Google Compute Engine images',
+    'DESCRIPTION': """
+        Create and manipulate Compute Engine images.
+
+        For more information about images, see the
+        [images documentation](https://cloud.google.com/compute/docs/images).
+
+        See also: [Images API](https://cloud.google.com/compute/docs/reference/rest/v1/images).
+    """,
 }
