@@ -162,6 +162,8 @@ class Create(base.Command):
   _support_source_snapshot_region = False
   _support_skip_guest_os_shutdown = True
   _support_preemption_notice_duration = False
+  _support_instance_flexibility_policy = False
+  _support_workload_identity_config = False
 
   _log_async = False
 
@@ -181,6 +183,8 @@ class Create(base.Command):
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
         support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_instance_flexibility_policy=cls._support_instance_flexibility_policy,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
     cls.AddSourceInstanceTemplate(parser)
 
@@ -224,6 +228,8 @@ class Create(base.Command):
         self._support_source_snapshot_region,
         self._support_skip_guest_os_shutdown,
         self._support_preemption_notice_duration,
+        self._support_instance_flexibility_policy,
+        self._support_workload_identity_config,
     )
     bulk_instance_resource = bulk_util.CreateBulkInsertInstanceResource(
         args,
@@ -272,6 +278,7 @@ class Create(base.Command):
         args,
         support_max_count_per_zone=self._support_max_count_per_zone,
         support_custom_hostnames=self._support_custom_hostnames,
+        support_instance_flexibility_policy=self._support_instance_flexibility_policy,
     )
 
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
@@ -369,6 +376,8 @@ class CreateBeta(Create):
   _support_source_snapshot_region = False
   _support_skip_guest_os_shutdown = True
   _support_preemption_notice_duration = False
+  _support_instance_flexibility_policy = False
+  _support_workload_identity_config = False
 
   @classmethod
   def Args(cls, parser):
@@ -388,6 +397,8 @@ class CreateBeta(Create):
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
         support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_instance_flexibility_policy=cls._support_instance_flexibility_policy,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
     cls.AddSourceInstanceTemplate(parser)
 
@@ -415,6 +426,8 @@ class CreateAlpha(Create):
   _support_source_snapshot_region = True
   _support_skip_guest_os_shutdown = True
   _support_preemption_notice_duration = True
+  _support_instance_flexibility_policy = True
+  _support_workload_identity_config = True
 
   @classmethod
   def Args(cls, parser):
@@ -434,6 +447,8 @@ class CreateAlpha(Create):
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
         support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_instance_flexibility_policy=cls._support_instance_flexibility_policy,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
 
     cls.AddSourceInstanceTemplate(parser)
