@@ -52,7 +52,9 @@ class Update(base.UpdateCommand):
     cls.INTERCONNECT_ATTACHMENT_ARG.AddArgument(parser, operation_type='patch')
     attachment_flags.AddDescription(parser)
     attachment_flags.AddAdminEnabled(parser, update=True)
-    attachment_flags.AddBandwidth(parser, required=False)
+    attachment_flags.AddBandwidth(
+        parser, required=False, release_track=cls.ReleaseTrack()
+    )
     attachment_flags.AddMtu(parser)
     attachment_flags.AddStackType(parser)
     attachment_flags.AddCandidateIpv6Subnets(parser)
@@ -91,7 +93,7 @@ class UpdateBeta(Update):
 
   @classmethod
   def Args(cls, parser):
-    super(UpdateBeta, cls).Args(parser)
+    super().Args(parser)
     labels_util.AddUpdateLabelsFlags(parser)
     attachment_flags.AddCandidateCloudRouterIpv6Address(parser)
     attachment_flags.AddCandidateCustomerRouterIpv6Address(parser)
@@ -134,6 +136,7 @@ class UpdateBeta(Update):
         candidate_customer_router_ipv6_address=getattr(
             args, 'candidate_customer_router_ipv6_address', None
         ),
+        supports_400g=self.ReleaseTrack() == base.ReleaseTrack.ALPHA,
     )
 
 
@@ -149,5 +152,5 @@ class UpdateAlpha(UpdateBeta):
 
   @classmethod
   def Args(cls, parser):
-    super(UpdateAlpha, cls).Args(parser)
+    super().Args(parser)
     attachment_flags.AddEnableMulticast(parser, update=True)
