@@ -63,6 +63,7 @@ class Create(base.CreateCommand):
     attachment_flags.AddEncryption(parser)
     attachment_flags.GetIpsecInternalAddressesFlag().AddToParser(parser)
     attachment_flags.AddStackType(parser)
+    attachment_flags.AddResourceManagerTags(parser)
 
   def Run(self, args):
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
@@ -119,7 +120,7 @@ class Create(base.CreateCommand):
         candidate_customer_router_ipv6_address=getattr(
             args, 'candidate_customer_router_ipv6_address', None
         ),
-        resource_manager_tags=getattr(args, 'resource_manager_tags', None),
+        resource_manager_tags=args.resource_manager_tags,
     )
     self._pairing_key = attachment.pairingKey
     return attachment
@@ -140,12 +141,11 @@ class CreateBeta(Create):
 
   @classmethod
   def Args(cls, parser):
-    super(CreateBeta, cls).Args(parser)
+    super().Args(parser)
     attachment_flags.AddCandidateCloudRouterIpAddress(parser)
     attachment_flags.AddCandidateCustomerRouterIpAddress(parser)
     attachment_flags.AddCandidateCloudRouterIpv6Address(parser)
     attachment_flags.AddCandidateCustomerRouterIpv6Address(parser)
-    attachment_flags.AddResourceManagerTags(parser)
 
 
 @base.UniverseCompatible
@@ -160,5 +160,5 @@ class CreateAlpha(CreateBeta):
 
   @classmethod
   def Args(cls, parser):
-    super(CreateAlpha, cls).Args(parser)
+    super().Args(parser)
     attachment_flags.AddDryRun(parser)
