@@ -57,6 +57,7 @@ class Create(base.CreateCommand):
     attachment_flags.AddDescription(parser)
     attachment_flags.AddCandidateSubnets(parser)
     attachment_flags.AddSubnetLength(parser)
+    attachment_flags.AddResourceManagerTags(parser)
 
   def Run(self, args):
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
@@ -114,7 +115,7 @@ class Create(base.CreateCommand):
         candidate_customer_router_ipv6_address=getattr(
             args, 'candidate_customer_router_ipv6_address', None
         ),
-        resource_manager_tags=getattr(args, 'resource_manager_tags', None),
+        resource_manager_tags=args.resource_manager_tags,
     )
 
 
@@ -136,7 +137,6 @@ class CreateBeta(Create):
     attachment_flags.AddCandidateCustomerRouterIpAddress(parser)
     attachment_flags.AddCandidateCloudRouterIpv6Address(parser)
     attachment_flags.AddCandidateCustomerRouterIpv6Address(parser)
-    attachment_flags.AddResourceManagerTags(parser)
 
 
 @base.UniverseCompatible
