@@ -24,10 +24,9 @@ from googlecloudsdk.api_lib.compute.interconnects import client
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.compute.interconnects import flags
 from googlecloudsdk.command_lib.util.args import labels_util
-from googlecloudsdk.core import properties
 
 
-def _ArgsCommon(cls, parser, support_labels=False, support_groups=False):
+def _ArgsCommon(cls, parser, support_labels=False):
   """Shared arguments for update commands."""
   cls.INTERCONNECT_ARG = flags.InterconnectArgument()
   cls.INTERCONNECT_ARG.AddArgument(parser, operation_type='update')
@@ -40,8 +39,6 @@ def _ArgsCommon(cls, parser, support_labels=False, support_groups=False):
   flags.AddRequestedLinkCountForUpdate(parser)
   if support_labels:
     labels_util.AddUpdateLabelsFlags(parser)
-  if support_groups:
-    flags.AddInterconnectGroups(parser)
 
 
 @base.UniverseCompatible
@@ -61,7 +58,7 @@ class Update(base.UpdateCommand):
   def Collection(self):
     return 'compute.interconnects'
 
-  def _DoRun(self, args, support_labels=False, support_groups=False):
+  def _DoRun(self, args, support_labels=False):
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
     ref = self.INTERCONNECT_ARG.ResolveAsResource(args, holder.resources)
     interconnect = client.Interconnect(ref, compute_client=holder.client)
@@ -78,18 +75,6 @@ class Update(base.UpdateCommand):
         if labels is not None:
           label_fingerprint = old_interconnect.labelFingerprint
 
-    group_refs = []
-    if support_groups and args.groups:
-      project = properties.VALUES.core.project.GetOrFail()
-      group_refs = [
-          holder.resources.Create(
-              'compute.interconnectGroups',
-              interconnectGroup=group,
-              project=project,
-          ).SelfLink()
-          for group in args.groups
-      ]
-
     return interconnect.Patch(
         description=args.description,
         interconnect_type=None,
@@ -100,9 +85,6 @@ class Update(base.UpdateCommand):
         location=None,
         labels=labels,
         label_fingerprint=label_fingerprint,
-        macsec_enabled=None,
-        macsec=None,
-        groups=group_refs,
     )
 
   def Run(self, args):
@@ -110,7 +92,7 @@ class Update(base.UpdateCommand):
 
 
 @base.UniverseCompatible
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class UpdateLabels(Update):
   """Update a Compute Engine interconnect.
 
@@ -120,24 +102,7 @@ class UpdateLabels(Update):
 
   @classmethod
   def Args(cls, parser):
-    _ArgsCommon(cls, parser, support_labels=True, support_groups=False)
+    _ArgsCommon(cls, parser, support_labels=True)
 
   def Run(self, args):
-    self._DoRun(args, support_labels=True, support_groups=False)
-
-
-@base.UniverseCompatible
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class UpdateLabelsAndGroups(UpdateLabels):
-  """Update a Compute Engine interconnect.
-
-  *{command}* is used to update interconnects. An interconnect represents a
-  single specific connection between Google and the customer.
-  """
-
-  @classmethod
-  def Args(cls, parser):
-    _ArgsCommon(cls, parser, support_labels=True, support_groups=True)
-
-  def Run(self, args):
-    self._DoRun(args, support_labels=True, support_groups=True)
+    self._DoRun(args, support_labels=True)
