@@ -35,6 +35,8 @@ def _ValidateArgs(
     support_auto_delete=False,
     support_reservation_sharing_policy=False,
     support_emergent_maintenance=False,
+    support_share_type=False,
+    support_scheduling_type=False,
 ):
   """Validates that both share settings arguments are mentioned.
 
@@ -45,6 +47,8 @@ def _ValidateArgs(
     support_reservation_sharing_policy: Check if reservation sharing policy is
       supported.
     support_emergent_maintenance: Check if emergent maintenance is supported.
+    support_share_type: Check if share setting is supported.
+    support_scheduling_type: Check if scheduling type is supported.
   """
   # Check the version and share-with option.
   share_with = False
@@ -86,6 +90,20 @@ def _ValidateArgs(
         '5- Modify emergent maintenance with specifying'
         ' enable-emergent-maintenance flag.'
     )
+  if support_share_type:
+    parameter_names.extend([
+        '--share-setting',
+    ])
+    one_option_exception_message += (
+        '6- Modify share setting with specifying share-setting flag.'
+    )
+  if support_scheduling_type:
+    parameter_names.extend([
+        '--scheduling-type',
+    ])
+    one_option_exception_message += (
+        '7- Modify scheduling type with specifying scheduling-type flag.'
+    )
 
   has_share_with = False
   if support_share_with_flag:
@@ -132,6 +150,10 @@ def _ValidateArgs(
         minimum_argument_specified
         and not args.IsSpecified('enable_emergent_maintenance')
     )
+  if support_scheduling_type:
+    minimum_argument_specified = (
+        minimum_argument_specified and not args.IsSpecified('scheduling_type')
+    )
 
   # Check parameters (add_share_with and remove_share_with are on GA).
   if minimum_argument_specified:
@@ -140,7 +162,8 @@ def _ValidateArgs(
 
 
 def _GetShareSettingUpdateRequest(
-    args, reservation_ref, holder, support_share_with_flag):
+    args, reservation_ref, holder, support_share_with_flag,
+    support_share_type):
   """Create Update Request for share-with.
 
   Returns:
@@ -150,34 +173,46 @@ def _GetShareSettingUpdateRequest(
    reservation_ref: reservation refrence.
    holder: base_classes.ComputeApiHolder.
    support_share_with_flag: Check if share_with is supported.
+   support_share_type: Check if share_type is supported.
   """
   messages = holder.client.messages
   # Set updated properties and build update mask.
   share_settings = None
-  setting_configs = 'projects'  # Only updating projects is supported now.
+  update_mask = []
+  setting_configs = None
+  if support_share_type and args.IsSpecified('share_setting'):
+    setting_configs = getattr(args, 'share_setting', None)
+    update_mask.append('shareSettings.shareType')
+
   if support_share_with_flag:
+    if not setting_configs and (args.IsSpecified('share_with') or
+                                args.IsSpecified('add_share_with') or
+                                args.IsSpecified('remove_share_with')):
+      setting_configs = 'projects'
+
     if args.IsSpecified('share_with'):
       share_settings = util.MakeShareSettingsWithArgs(
           messages, args, setting_configs, share_with='share_with')
-      update_mask = [
+      update_mask.extend([
           'shareSettings.projectMap.' + project
           for project in getattr(args, 'share_with', [])
-      ]
+      ])
+  else:
+    setting_configs = 'projects'
   if args.IsSpecified('add_share_with'):
     share_settings = util.MakeShareSettingsWithArgs(
         messages, args, setting_configs, share_with='add_share_with')
-    update_mask = [
+    update_mask.extend([
         'shareSettings.projectMap.' + project
         for project in getattr(args, 'add_share_with', [])
-    ]
+    ])
   elif args.IsSpecified('remove_share_with'):
-    share_settings = messages.ShareSettings(
-        shareType=messages.ShareSettings.ShareTypeValueValuesEnum
-        .SPECIFIC_PROJECTS)
-    update_mask = [
+    share_settings = util.MakeShareSettingsWithArgs(
+        messages, args, setting_configs, share_with='remove_share_with')
+    update_mask.extend([
         'shareSettings.projectMap.' + project
         for project in getattr(args, 'remove_share_with', [])
-    ]
+    ])
 
   # Build reservation object using new share-settings.
   r_resource = util.MakeReservationMessage(messages, reservation_ref.Name(),
@@ -329,6 +364,36 @@ def _EnableEmergentMaintenanceUpdateRequest(args, reservation_ref, holder):
   )
 
 
+def _SchedulingTypeUpdateRequest(args, reservation_ref, holder):
+  """Create Update Request for scheduling type."""
+  messages = holder.client.messages
+  update_mask = []
+  if args.IsSpecified('scheduling_type'):
+    update_mask.append('schedulingType')
+    scheduling_type = args.scheduling_type
+  else:
+    scheduling_type = None
+  r_resource = util.MakeReservationMessage(
+      messages,
+      reservation_ref.Name(),
+      None,
+      None,
+      None,
+      None,
+      reservation_ref.zone,
+      scheduling_type=scheduling_type,
+  )
+
+  # Build Update Request.
+  return messages.ComputeReservationsUpdateRequest(
+      reservation=reservation_ref.Name(),
+      reservationResource=r_resource,
+      paths=update_mask,
+      project=reservation_ref.project,
+      zone=reservation_ref.zone,
+  )
+
+
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 @base.UniverseCompatible
 class Update(base.UpdateCommand):
@@ -336,7 +401,9 @@ class Update(base.UpdateCommand):
   _support_share_with_flag = False
   _support_auto_delete = False
   _support_reservation_sharing_policy = True
-  _support_emergent_maintenance = False
+  _support_emergent_maintenance = True
+  _support_share_type = False
+  _support_scheduling_type = True
 
   @classmethod
   def Args(cls, parser):
@@ -346,6 +413,8 @@ class Update(base.UpdateCommand):
     r_flags.GetRemoveShareWithFlag().AddToParser(parser)
     r_flags.GetVmCountFlag(False).AddToParser(parser)
     r_flags.GetReservationSharingPolicyFlag().AddToParser(parser)
+    r_flags.GetEnableEmergentMaintenanceFlag().AddToParser(parser)
+    r_flags.GetSchedulingTypeFlag().AddToParser(parser)
 
   def Run(self, args):
     """Common routine for updating reservation."""
@@ -359,7 +428,9 @@ class Update(base.UpdateCommand):
         self._support_share_with_flag,
         self._support_auto_delete,
         self._support_reservation_sharing_policy,
-        self._support_emergent_maintenance
+        self._support_emergent_maintenance,
+        self._support_share_type,
+        self._support_scheduling_type,
     )
     reservation_ref = resource_args.GetReservationResourceArg(
     ).ResolveAsResource(
@@ -379,7 +450,8 @@ class Update(base.UpdateCommand):
 
     if share_with:
       r_update_request = _GetShareSettingUpdateRequest(
-          args, reservation_ref, holder, self._support_share_with_flag)
+          args, reservation_ref, holder, self._support_share_with_flag,
+          self._support_share_type)
       # Invoke Reservation.update API.
       result.append(
           list(
@@ -448,6 +520,26 @@ class Update(base.UpdateCommand):
                     batch_url=holder.client.batch_url,
                     errors=errors,
                 )))
+        if errors:
+          utils.RaiseToolException(errors)
+
+    if self._support_scheduling_type:
+      if args.IsSpecified('scheduling_type'):
+        r_update_request = _SchedulingTypeUpdateRequest(
+            args, reservation_ref, holder
+        )
+        result.append(
+            list(
+                request_helper.MakeRequests(
+                    requests=[(service, 'Update', r_update_request)],
+                    http=holder.client.apitools_client.http,
+                    batch_url=holder.client.batch_url,
+                    errors=errors,
+                )
+            )
+        )
+        if errors:
+          utils.RaiseToolException(errors)
 
     return result
 
@@ -458,7 +550,9 @@ class UpdateBeta(Update):
   _support_share_with_flag = True
   _support_auto_delete = True
   _support_reservation_sharing_policy = True
-  _support_emergent_maintenance = False
+  _support_emergent_maintenance = True
+  _support_share_type = True
+  _support_scheduling_type = True
 
   @classmethod
   def Args(cls, parser):
@@ -469,6 +563,10 @@ class UpdateBeta(Update):
     r_flags.GetRemoveShareWithFlag().AddToParser(parser)
     r_flags.GetVmCountFlag(False).AddToParser(parser)
     r_flags.GetReservationSharingPolicyFlag().AddToParser(parser)
+    r_flags.GetEnableEmergentMaintenanceFlag().AddToParser(parser)
+    r_flags.GetSharedSettingFlag(
+        support_folder_share_setting=False).AddToParser(parser)
+    r_flags.GetSchedulingTypeFlag().AddToParser(parser)
 
     auto_delete_group = base.ArgumentGroup(
         'Manage auto-delete properties for reservations.',
@@ -489,6 +587,8 @@ class UpdateAlpha(Update):
   _support_auto_delete = True
   _support_reservation_sharing_policy = True
   _support_emergent_maintenance = True
+  _support_share_type = True
+  _support_scheduling_type = True
 
   @classmethod
   def Args(cls, parser):
@@ -501,6 +601,9 @@ class UpdateAlpha(Update):
     r_flags.GetVmCountFlag(False).AddToParser(parser)
     r_flags.GetReservationSharingPolicyFlag().AddToParser(parser)
     r_flags.GetEnableEmergentMaintenanceFlag().AddToParser(parser)
+    r_flags.GetSharedSettingFlag(
+        support_folder_share_setting=False).AddToParser(parser)
+    r_flags.GetSchedulingTypeFlag().AddToParser(parser)
 
     auto_delete_group = base.ArgumentGroup(
         'Manage auto-delete properties for reservations.',
