@@ -12,7 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Command for exporting security policy configs to a file."""
 
 from __future__ import absolute_import
@@ -23,6 +22,7 @@ from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute.security_policies import client
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
+from googlecloudsdk.command_lib.compute import scope as compute_scope
 from googlecloudsdk.command_lib.compute.security_policies import flags
 from googlecloudsdk.command_lib.compute.security_policies import (
     security_policies_utils)
@@ -30,58 +30,21 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core.util import files
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Export(base.Command):
-  """Export security policy configs into yaml files."""
+  r"""Export security policy configs into YAML or JSON files.
 
-  SECURITY_POLICY_ARG = None
+  *{command}* exports all data associated with Compute Engine security
+  policy into a local file.
 
-  @classmethod
-  def Args(cls, parser):
-    cls.SECURITY_POLICY_ARG = flags.SecurityPolicyArgument()
-    cls.SECURITY_POLICY_ARG.AddArgument(parser, operation_type='export')
+  ## EXAMPLES
 
-    parser.add_argument(
-        '--file-name',
-        required=True,
-        help='The name of the file to export the security policy config to.')
+  To export a security policy in JSON format to a given file, run:
 
-    parser.add_argument(
-        '--file-format',
-        choices=['json', 'yaml'],
-        help=(
-            'The format of the file to export the security policy config to. '
-            'Specify either yaml or json. Defaults to yaml if not specified.'))
-
-  def Run(self, args):
-    # Get the security policy.
-    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    ref = self.SECURITY_POLICY_ARG.ResolveAsResource(args, holder.resources)
-
-    requests = []
-    security_policy = client.SecurityPolicy(ref, compute_client=holder.client)
-    requests.extend(security_policy.Describe(only_generate_request=True))
-    resources = holder.client.MakeRequests(requests)
-
-    # Export the security policy.
-    try:
-      with files.FileWriter(args.file_name) as export_file:
-        if args.file_format == 'json':
-          security_policies_utils.WriteToFile(export_file, resources[0], 'json')
-        else:
-          security_policies_utils.WriteToFile(export_file, resources[0], 'yaml')
-    except EnvironmentError as exp:
-      msg = 'Unable to export security policy to file [{0}]: {1}'.format(
-          args.file_name, exp)
-      raise exceptions.BadFileException(msg)
-
-    log.status.Print(
-        'Exported security policy to [{0}].'.format(args.file_name))
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class ExportAlpha(base.Command):
-  """Export security policy configs into yaml files."""
+    $ {command} my-policy \
+       --file-name=my-file-name \
+       --file-format=json
+  """
 
   SECURITY_POLICY_ARG = None
 
@@ -105,7 +68,8 @@ class ExportAlpha(base.Command):
   def Run(self, args):
     # Get the security policy.
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    ref = self.SECURITY_POLICY_ARG.ResolveAsResource(args, holder.resources)
+    ref = self.SECURITY_POLICY_ARG.ResolveAsResource(
+        args, holder.resources, default_scope=compute_scope.ScopeEnum.GLOBAL)
 
     requests = []
     security_policy = client.SecurityPolicy(ref, compute_client=holder.client)
@@ -124,5 +88,129 @@ class ExportAlpha(base.Command):
           args.file_name, exp)
       raise exceptions.BadFileException(msg)
 
-    log.status.Print(
-        'Exported security policy to [{0}].'.format(args.file_name))
+    log.status.Print('Exported security policy to [{0}].'.format(
+        args.file_name))
+
+
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class ExportBeta(base.Command):
+  r"""Export security policy configs into YAML or JSON files.
+
+  *{command}* exports all data associated with Compute Engine security
+  policy into a local file.
+
+  ## EXAMPLES
+
+  To export a security policy in JSON format to a given file, run:
+
+    $ {command} my-policy \
+       --file-name=my-file-name \
+       --file-format=json
+  """
+
+  SECURITY_POLICY_ARG = None
+
+  @classmethod
+  def Args(cls, parser):
+    cls.SECURITY_POLICY_ARG = flags.SecurityPolicyMultiScopeArgument()
+    cls.SECURITY_POLICY_ARG.AddArgument(parser, operation_type='export')
+
+    parser.add_argument(
+        '--file-name',
+        required=True,
+        help='The name of the file to export the security policy config to.')
+
+    parser.add_argument(
+        '--file-format',
+        choices=['json', 'yaml'],
+        help=(
+            'The format of the file to export the security policy config to. '
+            'Specify either yaml or json. Defaults to yaml if not specified.'))
+
+  def Run(self, args):
+    # Get the security policy.
+    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
+    ref = self.SECURITY_POLICY_ARG.ResolveAsResource(
+        args, holder.resources, default_scope=compute_scope.ScopeEnum.GLOBAL)
+
+    requests = []
+    security_policy = client.SecurityPolicy(ref, compute_client=holder.client)
+    requests.extend(security_policy.Describe(only_generate_request=True))
+    resources = holder.client.MakeRequests(requests)
+
+    # Export the security policy.
+    try:
+      with files.FileWriter(args.file_name) as export_file:
+        if args.file_format == 'json':
+          security_policies_utils.WriteToFile(export_file, resources[0], 'json')
+        else:
+          security_policies_utils.WriteToFile(export_file, resources[0], 'yaml')
+    except EnvironmentError as exp:
+      msg = 'Unable to export security policy to file [{0}]: {1}'.format(
+          args.file_name, exp)
+      raise exceptions.BadFileException(msg)
+
+    log.status.Print('Exported security policy to [{0}].'.format(
+        args.file_name))
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class ExportAlpha(base.Command):
+  r"""Export security policy configs into YAML or JSON files.
+
+  *{command}* exports all data associated with Compute Engine security
+  policy into a local file.
+
+  ## EXAMPLES
+
+  To export a security policy in JSON format to a given file, run:
+
+    $ {command} my-policy \
+       --file-name=my-file-name \
+       --file-format=json
+  """
+
+  SECURITY_POLICY_ARG = None
+
+  @classmethod
+  def Args(cls, parser):
+    cls.SECURITY_POLICY_ARG = flags.SecurityPolicyMultiScopeArgument()
+    cls.SECURITY_POLICY_ARG.AddArgument(parser, operation_type='export')
+
+    parser.add_argument(
+        '--file-name',
+        required=True,
+        help='The name of the file to export the security policy config to.')
+
+    parser.add_argument(
+        '--file-format',
+        choices=['json', 'yaml'],
+        help=(
+            'The format of the file to export the security policy config to. '
+            'Specify either yaml or json. Defaults to yaml if not specified.'))
+
+  def Run(self, args):
+    # Get the security policy.
+    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
+    ref = self.SECURITY_POLICY_ARG.ResolveAsResource(
+        args, holder.resources, default_scope=compute_scope.ScopeEnum.GLOBAL)
+
+    requests = []
+    security_policy = client.SecurityPolicy(ref, compute_client=holder.client)
+    requests.extend(security_policy.Describe(only_generate_request=True))
+    resources = holder.client.MakeRequests(requests)
+
+    # Export the security policy.
+    try:
+      with files.FileWriter(args.file_name) as export_file:
+        if args.file_format == 'json':
+          security_policies_utils.WriteToFile(export_file, resources[0], 'json')
+        else:
+          security_policies_utils.WriteToFile(export_file, resources[0], 'yaml')
+    except EnvironmentError as exp:
+      msg = 'Unable to export security policy to file [{0}]: {1}'.format(
+          args.file_name, exp)
+      raise exceptions.BadFileException(msg)
+
+    log.status.Print('Exported security policy to [{0}].'.format(
+        args.file_name))
