@@ -1,4 +1,5 @@
-# Copyright 2014 Google Inc. All Rights Reserved.
+# -*- coding: utf-8 -*- #
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +14,14 @@
 # limitations under the License.
 """Command for removing instances from target pools."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import utils
 from googlecloudsdk.calliope import base
-from googlecloudsdk.calliope import exceptions as calliope_exceptions
+from googlecloudsdk.command_lib.compute import exceptions as compute_exceptions
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 from googlecloudsdk.command_lib.compute.instances import flags as instance_flags
 from googlecloudsdk.command_lib.compute.target_pools import flags
@@ -62,8 +67,8 @@ class RemoveInstances(base.SilentCommand):
 
     if args.zone and not args.instances_zone:
       args.instances_zone = args.zone
-      log.warn('The --zone flag is deprecated. Use equivalent '
-               '--instances-zone=%s flag.', args.instances_zone)
+      log.warning('The --zone flag is deprecated. Use equivalent '
+                  '--instances-zone=%s flag.', args.instances_zone)
 
     instance_refs = self.INSTANCE_ARG.ResolveAsResource(
         args,
@@ -81,14 +86,14 @@ class RemoveInstances(base.SilentCommand):
                          for instance_ref in instance_refs)
 
     if len(unique_regions) > 1:
-      raise calliope_exceptions.ToolException(
+      raise compute_exceptions.ArgumentError(
           'Instances must all be in the same region as the target pool.')
 
     region = unique_regions.pop()
 
     # Check that the region of the instances is the same as target pool region.
     if args.region and region != args.region:
-      raise calliope_exceptions.ToolException(
+      raise compute_exceptions.ArgumentError(
           'Instances must all be in the same region as the target pool.')
 
     args.region = region
