@@ -574,6 +574,7 @@ def ParseCreateOptionsBase(
       enable_auto_ipam=get_default('enable_auto_ipam'),
       enable_k8s_tokens_via_dns=get_default('enable_k8s_tokens_via_dns'),
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
+      enable_lustre_multi_nic=get_default('enable_lustre_multi_nic'),
       enable_pod_snapshots=enable_pod_snapshots,
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
@@ -583,6 +584,7 @@ def ParseCreateOptionsBase(
       ),
       network_tier=get_default('network_tier'),
       control_plane_egress_mode=get_default('control_plane_egress'),
+      enable_slice_controller=get_default('enable_slice_controller'),
   )
 
 GA = 'ga'
@@ -839,6 +841,11 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'enableLustreMultiNic': (
+            lambda p: flags.AddEnableLustreMultiRailFlag(
+                p, hidden=True
+            )
+        ),
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
@@ -847,9 +854,10 @@ flags_to_add = {
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableSliceController': (
+            lambda p: flags.AddEnableSliceControllerFlag(p, hidden=True)
         ),
     },
     BETA: {
@@ -1063,10 +1071,16 @@ flags_to_add = {
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableLustreMultiNic': (
+            lambda p: flags.AddEnableLustreMultiRailFlag(
                 p, hidden=True
             )
         ),
+        'enableSliceController': (
+            lambda p: flags.AddEnableSliceControllerFlag(p, hidden=True)
+        ),
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1285,10 +1299,16 @@ flags_to_add = {
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableLustreMultiNic': (
+            lambda p: flags.AddEnableLustreMultiRailFlag(
                 p, hidden=True
             )
         ),
+        'enableSliceController': (
+            lambda p: flags.AddEnableSliceControllerFlag(p, hidden=True)
+        ),
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
