@@ -18,8 +18,6 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-import os
-import textwrap
 import time
 
 from googlecloudsdk.api_lib.services import enable_api
@@ -27,7 +25,6 @@ from googlecloudsdk.command_lib.container.fleet import resources
 from googlecloudsdk.command_lib.container.fleet.features import base
 from googlecloudsdk.command_lib.container.fleet.features import info
 from googlecloudsdk.core import exceptions
-from googlecloudsdk.core.console import console_io
 from googlecloudsdk.core.console import progress_tracker
 from googlecloudsdk.core.util import retry
 
@@ -48,33 +45,12 @@ class Enable(base.EnableCommand):
 
   @classmethod
   def Args(cls, parser):
-    if resources.UseRegionalMemberships(cls.ReleaseTrack()):
-      resources.AddMembershipResourceArg(
-          parser, membership_arg='--config-membership')
-    else:
-      parser.add_argument(
-          '--config-membership',
-          type=str,
-          help=textwrap.dedent("""\
-              Membership resource representing the cluster which hosts
-              the MultiClusterIngress and MultiClusterService CustomResourceDefinitions.
-              """),
-      )
+    resources.AddMembershipResourceArg(
+        parser, flag_override='--config-membership')
 
   def Run(self, args):
-    if not args.config_membership:
-      memberships = base.ListMemberships()
-      if not memberships:
-        raise exceptions.Error('No Memberships available in the fleet.')
-      index = console_io.PromptChoice(
-          options=memberships, message='Please specify a config membership:\n')
-      config_membership = memberships[index]
-    else:
-      # Strip to the final path component to allow short and long names.
-      # Assumes long names are for the same project and global location.
-      # TODO(b/192580393): Use the resource args instead of this hack.
-      config_membership = os.path.basename(args.config_membership)
-    config_membership = self.MembershipResourceName(config_membership)
+    config_membership = base.ParseMembership(
+        args, prompt=True, flag_override='config_membership')
 
     # MCI requires MCSD. Enablement of the fleet feature for MCSD is taken care
     # of by CLH but we need to enable the OP API before that happens. If not,
