@@ -20,8 +20,9 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base as calliope_base
 
 
-@calliope_base.Hidden
-@calliope_base.ReleaseTracks(calliope_base.ReleaseTrack.ALPHA)
+@calliope_base.ReleaseTracks(
+    calliope_base.ReleaseTrack.ALPHA, calliope_base.ReleaseTrack.BETA
+)
 class Debug(calliope_base.Group):
   """Debug Service Mesh memberships."""
 
