@@ -32,11 +32,12 @@ _VARIANT_STORAGE_STRATEGY_LABEL_VALUE_NESTED = 'nested'
 
 
 @base.DefaultUniverseOnly
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Describe(base.DescribeCommand):
   """Describe Package Rollouts Release."""
 
   detailed_help = _DETAILED_HELP
+  _api_version = 'v1'
 
   @staticmethod
   def Args(parser):
@@ -46,24 +47,27 @@ class Describe(base.DescribeCommand):
 
   def Run(self, args):
     """Run the describe command."""
-    client = apis.ReleasesClient()
+    client = apis.ReleasesClient(self._api_version)
     release = client.Describe(
         release=args.release,
         project=flags.GetProject(args),
         location=flags.GetLocation(args),
         resource_bundle=args.resource_bundle,
     )
-    # Don't show variants if they are nested resources.
-    if (
-        release.variants
-        and release.labels
-        and release.labels.additionalProperties
-    ):
-      for label in release.labels.additionalProperties:
-        if (
-            label.key == _VARIANT_STORAGE_STRATEGY_LABEL_KEY
-            and label.value == _VARIANT_STORAGE_STRATEGY_LABEL_VALUE_NESTED
-        ):
-          release.variants = None
-          break
     return release
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class DescribeBeta(Describe):
+  """Describe Package Rollouts Release."""
+
+  _api_version = 'v1beta'
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class DescribeAlpha(Describe):
+  """Describe Package Rollouts Release."""
+
+  _api_version = 'v1alpha'
