@@ -18,12 +18,10 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-from googlecloudsdk.calliope import base as calliope_base
 from googlecloudsdk.command_lib.container.fleet.features import base
 from googlecloudsdk.command_lib.container.fleet.policycontroller import flags
 
 
-@calliope_base.Hidden
 class Disable(base.UpdateCommand):
   """Disable (Uninstall) Policy Controller.
 
@@ -40,7 +38,11 @@ class Disable(base.UpdateCommand):
 
   @classmethod
   def Args(cls, parser):
-    cmd_flags = flags.PocoFlags(parser, 'disable')
+
+    top_group = parser.add_argument_group(mutex=True)
+    flags.no_fleet_default_cfg_flag().AddToParser(top_group)
+
+    cmd_flags = flags.PocoFlags(top_group, 'disable')
     cmd_flags.add_memberships()
 
   def Run(self, args):
