@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Abort operation command."""
 
 from __future__ import absolute_import
@@ -33,7 +32,6 @@ CANCEL_OPERATION_MESSAGE = (
     'check if the operation has been canceled successfully.')
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class Cancel(base.Command):
   """Cancel an operation."""
 
@@ -43,7 +41,7 @@ class Cancel(base.Command):
 
     Args:
       parser: An argparse.ArgumentParser-like object. It is mocked out in order
-          to capture some information, but behaves like an ArgumentParser.
+        to capture some information, but behaves like an ArgumentParser.
     """
     parser.add_argument('operation_id', help='The operation id to cancel.')
 
@@ -64,7 +62,7 @@ class Cancel(base.Command):
     try:
       op = adapter.GetOperation(op_ref)
     except apitools_exceptions.HttpError as error:
-      raise exceptions.HttpException(util.GetError(error))
+      raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
 
     console_io.PromptContinue(
         message='Are you sure you want to cancel operation {0}?'.format(
@@ -75,15 +73,17 @@ class Cancel(base.Command):
     try:
       adapter.CancelOperation(op_ref)
       log.status.Print(
-          CANCEL_OPERATION_MESSAGE
-          .format(args.operation_id, args.operation_id))
+          CANCEL_OPERATION_MESSAGE.format(args.operation_id, args.operation_id))
       return adapter.GetOperation(op_ref)
     except apitools_exceptions.HttpError as error:
       raise exceptions.HttpException(error)
 
+
 Cancel.detailed_help = {
-    'brief': 'Cancel a running operation.',
-    'DESCRIPTION': """
+    'brief':
+        'Cancel a running operation.',
+    'DESCRIPTION':
+        """
         Cancel a running operation.
 
 Cancel is a best-effort method for aborting a running operation. Operations that
@@ -93,5 +93,13 @@ have already completed can not be cancelled. If the operation has passed the
 An example of "point of no-return" in the context of Upgrade operations would
 be if all the nodes have been upgraded but the operation hasn't been marked as
 complete.
+
+Only node pool upgrade operations support cancellation.
 """,
+    'EXAMPLES':
+        """\
+        To cancel an operation, run:
+
+          $ {command} sample-operation-id
+        """,
 }
