@@ -143,9 +143,13 @@ class _Create(object):
     destination_ref = args.CONCEPTS.destination.Parse()
     if self.ReleaseTrack() == base.ReleaseTrack.GA:
       conversion_workspace_ref = args.CONCEPTS.conversion_workspace.Parse()
+      original_migration_name_ref = (
+          args.CONCEPTS.original_migration_name.Parse()
+      )
       cmek_key_ref = args.CONCEPTS.cmek_key.Parse()
     else:
       conversion_workspace_ref = None
+      original_migration_name_ref = None
       cmek_key_ref = None
 
     mj_client = migration_jobs.MigrationJobsClient(self.ReleaseTrack())
@@ -155,6 +159,7 @@ class _Create(object):
         source_ref,
         destination_ref,
         conversion_workspace_ref,
+        original_migration_name_ref,
         cmek_key_ref,
         args,
     )
