@@ -53,3 +53,7 @@ class Dataflow(base.Group):
     base.RequireProjectID(args)
     del context, args
     base.DisableUserProjectQuota()
+
+    self.EnableSelfSignedJwtForTracks(
+        [base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA]
+    )
