@@ -15,13 +15,16 @@
 
 """Update cluster command."""
 
+from googlecloudsdk.api_lib.dataproc import constants as dataproc_constants
 from googlecloudsdk.api_lib.dataproc import dataproc as dp
 from googlecloudsdk.api_lib.dataproc import exceptions
 from googlecloudsdk.api_lib.dataproc import util
 from googlecloudsdk.calliope import actions
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.dataproc import clusters
 from googlecloudsdk.command_lib.dataproc import flags
+from googlecloudsdk.command_lib.dataproc.utils import user_sa_mapping_util
 from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core import log
 from googlecloudsdk.core.util import times
@@ -120,8 +123,7 @@ class Update(base.UpdateCommand):
     idle_delete_group.add_argument(
         '--max-idle',
         type=arg_parsers.Duration(),
-        # TODO: b/368979261 - Hide this flag when --delete-max-idle is GA.
-        # hidden=True,
+        hidden=True,
         help="""\
         The duration after the last job completes to auto-delete the cluster,
         such as "2h" or "1d".
@@ -130,8 +132,7 @@ class Update(base.UpdateCommand):
     idle_delete_group.add_argument(
         '--no-max-idle',
         action='store_true',
-        # TODO: b/368979261 - Hide this flag when --no-delete-max-idle is GA.
-        # hidden=True,
+        hidden=True,
         help="""\
         Cancels the cluster auto-deletion by cluster idle duration (configured
          by --max-idle flag)
@@ -157,8 +158,7 @@ class Update(base.UpdateCommand):
     auto_delete_group.add_argument(
         '--max-age',
         type=arg_parsers.Duration(),
-        # TODO: b/368979261 - Hide this flag when --delete-max-age is GA.
-        # hidden=True,
+        hidden=True,
         help="""\
         The lifespan of the cluster, with auto-deletion upon completion,
         "2h" or "1d".
@@ -167,8 +167,7 @@ class Update(base.UpdateCommand):
     auto_delete_group.add_argument(
         '--expiration-time',
         type=arg_parsers.Datetime.Parse,
-        # TODO: b/368979261 - Hide this flag when --delete-expiration-time is GA
-        # hidden=True,
+        hidden=True,
         help="""\
         The time when the cluster will be auto-deleted, such as
         "2017-08-29T18:52:51.142Z". See $ gcloud topic datetimes for
@@ -177,8 +176,7 @@ class Update(base.UpdateCommand):
     auto_delete_group.add_argument(
         '--no-max-age',
         action='store_true',
-        # TODO: b/368979261 - Hide this flag when --no-delete-max-age is GA.
-        # hidden=True,
+        hidden=True,
         help="""\
         Cancels the cluster auto-deletion by maximum cluster age (configured by
          --max-age or --expiration-time flags)
@@ -261,6 +259,7 @@ class Update(base.UpdateCommand):
         Disable autoscaling, if it is enabled. This is an alias for passing the
         empty string to --autoscaling-policy'.
         """)
+    user_sa_mapping_util.AddUpdateUserSaMappingFlags(parser)
 
   def Run(self, args):
     dataproc = dp.Dataproc(self.ReleaseTrack())
@@ -270,6 +269,9 @@ class Update(base.UpdateCommand):
     changed_fields = []
 
     has_changes = False
+    no_update_error_msg = (
+        'Must specify at least one cluster parameter to update.'
+    )
 
     if args.num_workers is not None:
       worker_config = dataproc.messages.InstanceGroupConfig(
@@ -428,23 +430,12 @@ class Update(base.UpdateCommand):
       cluster_config.lifecycleConfig = lifecycle_config
       has_changes = True
 
-    def _GetCurrentCluster():
-      # This is used for labels and auxiliary_node_pool_configs
-      get_cluster_request = (
-          dataproc.messages.DataprocProjectsRegionsClustersGetRequest(
-              projectId=cluster_ref.projectId,
-              region=cluster_ref.region,
-              clusterName=cluster_ref.clusterName))
-      current_cluster = dataproc.client.projects_regions_clusters.Get(
-          get_cluster_request)
-      return current_cluster
-
     # Put in a thunk so we only make this call if needed
     def _GetCurrentLabels():
       # We need to fetch cluster first so we know what the labels look like. The
       # labels_util will fill out the proto for us with all the updates and
       # removals, but first we need to provide the current state of the labels
-      current_cluster = _GetCurrentCluster()
+      current_cluster = _GetCurrentCluster(dataproc, cluster_ref)
       return current_cluster.labels
     labels_update = labels_util.ProcessUpdateArgsLazy(
         args, dataproc.messages.Cluster.LabelsValue,
@@ -454,9 +445,75 @@ class Update(base.UpdateCommand):
       changed_fields.append('labels')
     labels = labels_update.GetOrNone()
 
+    def _GetCurrentUserServiceAccountMapping():
+      current_cluster = _GetCurrentCluster(dataproc, cluster_ref)
+      if (
+          current_cluster.config.securityConfig
+          and current_cluster.config.securityConfig.identityConfig
+      ):
+        return (
+            current_cluster.config.securityConfig.identityConfig.userServiceAccountMapping
+        )
+      return None
+
+    def _UpdateSecurityConfig(cluster_config, user_sa_mapping):
+      if cluster_config.securityConfig is None:
+        cluster_config.securityConfig = dataproc.messages.SecurityConfig()
+      if cluster_config.securityConfig.identityConfig is None:
+        cluster_config.securityConfig.identityConfig = (
+            dataproc.messages.IdentityConfig()
+        )
+
+      cluster_config.securityConfig.identityConfig.userServiceAccountMapping = (
+          user_sa_mapping
+      )
+
+    if args.add_user_mappings or args.remove_user_mappings:
+      if not _IsMultitenancyCluster(_GetCurrentCluster(dataproc, cluster_ref)):
+        raise exceptions.ArgumentError(
+            'User service account mapping can only be updated for multi-tenant'
+            ' clusters.'
+        )
+      user_sa_mapping_update = user_sa_mapping_util.ProcessUpdateArgsLazy(
+          args,
+          dataproc.messages.IdentityConfig.UserServiceAccountMappingValue,
+          orig_user_sa_mapping_thunk=_GetCurrentUserServiceAccountMapping,
+      )
+      if user_sa_mapping_update.needs_update:
+        changed_fields.append(
+            'config.security_config.identity_config.user_service_account_mapping'
+        )
+        has_changes = True
+      else:
+        if args.add_user_mappings:
+          no_update_error_msg += (
+              ' User to add is already present in service account mapping.'
+          )
+        if args.remove_user_mappings:
+          no_update_error_msg += (
+              ' User to remove is not present in service account mapping.'
+          )
+      user_sa_mapping = user_sa_mapping_update.GetOrNone()
+      if user_sa_mapping:
+        _UpdateSecurityConfig(cluster_config, user_sa_mapping)
+    elif args.identity_config_file:
+      if not _IsMultitenancyCluster(_GetCurrentCluster(dataproc, cluster_ref)):
+        raise exceptions.ArgumentError(
+            'User service account mapping can only be updated for multi-tenant'
+            ' clusters.'
+        )
+      if cluster_config.securityConfig is None:
+        cluster_config.securityConfig = dataproc.messages.SecurityConfig()
+      cluster_config.securityConfig.identityConfig = (
+          clusters.ParseIdentityConfigFile(dataproc, args.identity_config_file)
+      )
+      changed_fields.append(
+          'config.security_config.identity_config.user_service_account_mapping'
+      )
+      has_changes = True
+
     if not has_changes:
-      raise exceptions.ArgumentError(
-          'Must specify at least one cluster parameter to update.')
+      raise exceptions.ArgumentError(no_update_error_msg)
 
     cluster = dataproc.messages.Cluster(
         config=cluster_config,
@@ -515,3 +572,48 @@ def _AddAlphaArguments(parser, release_track):
         feature.
               """,
     )
+
+
+def _IsMultitenancyCluster(cluster) -> bool:
+  """Checks if the cluster is a multi-tenant cluster.
+
+  Args:
+    cluster: The cluster configuration.
+
+  Returns:
+    True if the cluster is a multi-tenant cluster, False otherwise.
+  """
+  config = cluster.config
+  if config and config.softwareConfig and config.softwareConfig.properties:
+    props = config.softwareConfig.properties
+    for prop in props.additionalProperties:
+      if (
+          prop.key == dataproc_constants.ENABLE_DYNAMIC_MULTI_TENANCY_PROPERTY
+          and prop.value.lower() == 'true'
+      ):
+        return True
+  return False
+
+
+def _GetCurrentCluster(dataproc, cluster_ref):
+  """Retrieves the current cluster configuration.
+
+  Args:
+    dataproc: The Dataproc API client.
+    cluster_ref: The reference to the cluster.
+
+  Returns:
+    The current cluster configuration.
+  """
+  # This is used for labels and auxiliary_node_pool_configs
+  get_cluster_request = (
+      dataproc.messages.DataprocProjectsRegionsClustersGetRequest(
+          projectId=cluster_ref.projectId,
+          region=cluster_ref.region,
+          clusterName=cluster_ref.clusterName,
+      )
+  )
+  current_cluster = dataproc.client.projects_regions_clusters.Get(
+      get_cluster_request
+  )
+  return current_cluster
