@@ -20,11 +20,12 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.dataproc import dataproc as dp
+from googlecloudsdk.api_lib.dataproc import iam_helpers
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.dataproc import flags
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class GetIamPolicy(base.Command):
   """Get IAM policy for a workflow template.
 
@@ -38,10 +39,11 @@ class GetIamPolicy(base.Command):
     $ {command} example-workflow
   """
 
-  @staticmethod
-  def Args(parser):
+  @classmethod
+  def Args(cls, parser):
+    dataproc = dp.Dataproc(cls.ReleaseTrack())
     flags.AddTemplateResourceArg(
-        parser, 'retrieve the policy for', api_version='v1')
+        parser, 'retrieve the policy for', api_version=dataproc.api_version)
 
   def Run(self, args):
     dataproc = dp.Dataproc(self.ReleaseTrack())
@@ -49,28 +51,13 @@ class GetIamPolicy(base.Command):
 
     template_ref = args.CONCEPTS.template.Parse()
     request = msgs.DataprocProjectsRegionsWorkflowTemplatesGetIamPolicyRequest(
-        resource=template_ref.RelativeName())
+        resource=template_ref.RelativeName(),
+        getIamPolicyRequest=msgs.GetIamPolicyRequest(
+            options=msgs.GetPolicyOptions(
+                requestedPolicyVersion=iam_helpers.MAX_LIBRARY_IAM_SUPPORTED_VERSION
+            )
+        ),
+    )
 
     return dataproc.client.projects_regions_workflowTemplates.GetIamPolicy(
         request)
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
-class GetIamPolicyBeta(GetIamPolicy):
-  """Get IAM policy for a workflow template.
-
-  Gets the IAM policy for a workflow template, given a template ID.
-
-  ## EXAMPLES
-
-  The following command prints the IAM policy for a workflow template with the
-  ID `example-workflow`:
-
-    $ {command} example-workflow
-  """
-
-  @staticmethod
-  def Args(parser):
-    flags.AddTemplateResourceArg(
-        parser, 'retrieve the policy for', api_version='v1beta2')
-    base.URI_FLAG.RemoveFromParser(parser)
