@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,4 +22,8 @@ from googlecloudsdk.calliope import base
 
 
 class Indexes(base.Group):
-  """Manage Cloud Datastore indexes."""
+  """Manage your Cloud Datastore indexes.
+
+    The gcloud datastore command group lets you create and delete Google Cloud
+    Datastore indexes.
+  """
