@@ -14,16 +14,11 @@
 # limitations under the License.
 """Rollback a Cloud Deploy target to a prior rollout."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import copy
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.clouddeploy import client_util
 from googlecloudsdk.api_lib.clouddeploy import release
-from googlecloudsdk.api_lib.util import apis as core_apis
 from googlecloudsdk.api_lib.util import exceptions as gcloud_exception
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
@@ -57,6 +52,7 @@ _ROLLBACK = 'rollback'
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class Rollback(base.CreateCommand):
   """Rollbacks a target to a prior rollout.
 
@@ -112,32 +108,13 @@ class Rollback(base.CreateCommand):
         rollback_release_ref.RelativeName()
     )
 
+    release_util.CheckReleaseSupportState(release_obj, 'roll back this target')
+
     if release_obj.abandoned:
       error_msg_annotation_prefix = 'Cannot perform rollback.'
       raise deploy_exceptions.AbandonedReleaseError(
           error_msg_annotation_prefix, rollback_release_ref.RelativeName()
       )
-    messages = core_apis.GetMessagesModule('clouddeploy', 'v1')
-    skaffold_support_state = release_util.GetSkaffoldSupportState(release_obj)
-    skaffold_support_state_enum = (
-        messages.SkaffoldSupportedCondition.SkaffoldSupportStateValueValuesEnum
-    )
-    if (skaffold_support_state ==
-        skaffold_support_state_enum.SKAFFOLD_SUPPORT_STATE_MAINTENANCE_MODE):
-      log.status.Print(
-          "WARNING: This release's Skaffold version is in maintenance mode and"
-          " will be unsupported soon.\n"
-          " https://cloud.google.com/deploy/docs/using-skaffold/select-skaffold"
-          "#skaffold_version_deprecation_and_maintenance_policy")
-
-    if (skaffold_support_state ==
-        skaffold_support_state_enum.SKAFFOLD_SUPPORT_STATE_UNSUPPORTED):
-      raise core_exceptions.Error(
-          "You can't roll back this target because the Skaffold version that"
-          " was used to create the release is no longer supported.\n"
-          "https://cloud.google.com/deploy/docs/using-skaffold/select-skaffold"
-          "#skaffold_version_deprecation_and_maintenance_policy"
-      )
 
     prompt = 'Rolling back target {} to release {}.\n\n'.format(
         target_ref.Name(), rollback_release_ref.Name()
@@ -156,7 +133,7 @@ class Rollback(base.CreateCommand):
     policies = deploy_policy_util.CreateDeployPolicyNamesFromIDs(
         pipeline_ref, args.override_deploy_policies
     )
-    return promote_util.Promote(
+    rollout_resource = promote_util.Promote(
         rollback_release_ref,
         release_obj,
         target_ref.Name(),
@@ -170,8 +147,28 @@ class Rollback(base.CreateCommand):
         override_deploy_policies=policies,
     )
 
+    if rollout_resource:
+      try:
+        # Any 403 errors should indicate to the user that they may need to
+        # add the new permission.
+        delivery_pipeline_util.CreateRollbackTarget(
+            pipeline_ref.RelativeName(),
+            target_ref.Name(),
+            validate_only=True,
+        )
+      except apitools_exceptions.HttpError as e:
+        if e.status_code == 403:
+          log.status.Print(
+              'Starting on September 14, 2026, the rollback feature will'
+              ' require a new permission: clouddeploy.rollouts.rollback. For'
+              ' more information, see'
+              ' https://docs.cloud.google.com/deploy/docs/rollout-perms-notice'
+          )
+    return rollout_resource
+
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.DefaultUniverseOnly
 class RollbackAlpha(Rollback):
   """Rollbacks a target to a prior rollout.
 
@@ -292,27 +289,8 @@ class RollbackAlpha(Rollback):
     except apitools_exceptions.HttpError as error:
       raise exceptions.HttpException(error)
 
-    messages = core_apis.GetMessagesModule('clouddeploy', 'v1')
-    skaffold_support_state_enum = (
-        messages.SkaffoldSupportedCondition.SkaffoldSupportStateValueValuesEnum
-    )
-    skaffold_support_state = release_util.GetSkaffoldSupportState(release_obj)
-    if (skaffold_support_state ==
-        skaffold_support_state_enum.SKAFFOLD_SUPPORT_STATE_MAINTENANCE_MODE):
-      log.status.Print(
-          "WARNING: This release's Skaffold version is in maintenance mode and"
-          " will be unsupported soon.\n"
-          " https://cloud.google.com/deploy/docs/using-skaffold/select-skaffold"
-          "#skaffold_version_deprecation_and_maintenance_policy")
+    release_util.CheckReleaseSupportState(release_obj, 'roll back this target')
 
-    if (skaffold_support_state ==
-        skaffold_support_state_enum.SKAFFOLD_SUPPORT_STATE_UNSUPPORTED):
-      raise core_exceptions.Error(
-          "You can't roll back this target because the Skaffold version that"
-          " was used to create the release is no longer supported.\n"
-          "https://cloud.google.com/deploy/docs/using-skaffold/select-skaffold"
-          "#skaffold_version_deprecation_and_maintenance_policy"
-      )
     # prompt to see whether user wants to continue.
     prompt = 'Rolling back target {} to release {}.\n\n'.format(
         target_ref.Name(), rollback_release_ref.Name()
