@@ -45,8 +45,7 @@ class Describe(base.DescribeCommand):
 
     resource_printer.RegisterFormatter(
         registration_printer.REGISTRATION_PRINTER_FORMAT,
-        registration_printer.RegistrationPrinter,
-        hidden=True)
+        registration_printer.RegistrationPrinter)
     parser.display_info.AddFormat(
         registration_printer.REGISTRATION_PRINTER_FORMAT)
 
@@ -57,14 +56,4 @@ class Describe(base.DescribeCommand):
 
     registration = client.Get(args.CONCEPTS.registration.Parse())
 
-    transfer_pending_enum = client.messages.Registration.StateValueValuesEnum.TRANSFER_PENDING
-    transfer_failed_enum = client.messages.Registration.StateValueValuesEnum.TRANSFER_FAILED
-    if (registration.state == transfer_pending_enum or
-        registration.state == transfer_failed_enum):
-      # We would prefer to print this after the resource but Epilog() doesn't
-      # accept other method arguments.
-      log.status.Print(
-          'For more details on the status of the domain transfer, sign into '
-          'Google Domains by visiting https://domains.google.com/registrar.')
-
     return registration
