@@ -42,11 +42,11 @@ class Start(base.Command):
   """
 
   detailed_help = {
-      'EXAMPLES': """\
-          To start a local pubsub emulator, run:
+      'EXAMPLES': """
+To start a local pubsub emulator, run:
 
-            $ {command} --data-dir DATA-DIR
-          """,
+  $ {command} --data-dir=DATA-DIR
+""",
   }
 
   @staticmethod
@@ -56,7 +56,7 @@ class Start(base.Command):
         required=False,
         type=lambda arg: arg_parsers.HostPort.Parse(arg, ipv6_enabled=True),
         help='The host:port to which the emulator should be bound. The default '
-             'value is localhost:8085.')
+             'value is [::1]:8085.')
 
   # Override
   def Run(self, args):
