@@ -29,6 +29,4 @@ class Eventarc(base.Group):
   category = base.SERVERLESS_CATEGORY
 
   def Filter(self, context, args):
-    # TODO(b/190533987):  Determine if command group works with project number
-    base.RequireProjectID(args)
     del context, args
