@@ -22,21 +22,8 @@ from googlecloudsdk.calliope import base
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class Locations(base.Group):
   """Explore locations available for Eventarc."""
 
-
-@base.Deprecate(
-    is_removed=False,
-    warning=(
-        'This command is deprecated. '
-        'Please use `gcloud eventarc locations` instead.'
-    ),
-    error=(
-        'This command has been removed. '
-        'Please use `gcloud eventarc locations` instead.'
-    ),
-)
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
-class LocationsBeta(base.Group):
-  """Explore locations available for Eventarc."""
+  category = base.SERVERLESS_CATEGORY
