@@ -22,6 +22,7 @@ from googlecloudsdk.api_lib.cloudkms import base as cloudkms_base
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.kms import exceptions
 from googlecloudsdk.command_lib.kms import flags
+from googlecloudsdk.command_lib.kms import resource_args
 
 
 class SetRotationSchedule(base.UpdateCommand):
@@ -53,7 +54,7 @@ class SetRotationSchedule(base.UpdateCommand):
 
   @staticmethod
   def Args(parser):
-    flags.AddKeyResourceArgument(parser, 'to update the schedule of')
+    resource_args.AddKmsKeyResourceArgForKMS(parser, True, 'key')
     flags.AddRotationPeriodFlag(parser)
     flags.AddNextRotationTimeFlag(parser)
 
