@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,7 @@ class Enable(base.Command):
   The following command enables version 3 of key `frodo` within
   keyring `fellowship` and location `us-east1`:
 
-    $ {command} 3 --location us-east1 --keyring fellowship --key frodo
+    $ {command} 3 --location=us-east1 --keyring=fellowship --key=frodo
   """
 
   @staticmethod
