@@ -22,5 +22,8 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
+@base.UniverseCompatible
 class Logs(base.Group):
   """Manages your project's logs."""
+
+  category = base.MANAGEMENT_TOOLS_CATEGORY
