@@ -26,12 +26,13 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.network_connectivity import flags
 from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core import log
+from googlecloudsdk.core import properties
 from googlecloudsdk.core import resources
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class Create(base.Command):
-  # TODO(b/216961706) Add documentation for VPC spokes.
   """Create a new VPC spoke.
 
   Create a new VPC spoke.
@@ -39,7 +40,9 @@ class Create(base.Command):
 
   @staticmethod
   def Args(parser):
-    flags.AddSpokeResourceArg(parser, 'to create', vpc_spoke_only_command=True)
+    flags.AddSpokeResourceArg(
+        parser, 'to create', flags.ResourceLocationType.GLOBAL_ONLY
+    )
     flags.AddRegionGroup(parser, hide_global_arg=False, hide_region_arg=True)
     flags.AddHubFlag(parser)
     flags.AddGroupFlag(parser)
@@ -47,33 +50,55 @@ class Create(base.Command):
     flags.AddDescriptionFlag(parser, 'Description of the spoke to create.')
     flags.AddAsyncFlag(parser)
     flags.AddExcludeExportRangesFlag(
-        parser,
-        hide_exclude_export_ranges_flag=False)
+        parser, hide_exclude_export_ranges_flag=False
+    )
     flags.AddIncludeExportRangesFlag(
-        parser, hide_include_export_ranges_flag=True
+        parser, hide_include_export_ranges_flag=False
     )
     labels_util.AddCreateLabelsFlags(parser)
 
   def Run(self, args):
     client = networkconnectivity_api.SpokesClient(
-        release_track=self.ReleaseTrack())
-
-    spoke_ref = args.CONCEPTS.spoke.Parse()
-    labels = labels_util.ParseCreateArgs(
-        args, client.messages.Spoke.LabelsValue)
-    spoke = client.messages.Spoke(
-        hub=args.hub,
-        group=args.group,
-        linkedVpcNetwork=client.messages.LinkedVpcNetwork(
-            uri=args.vpc_network,
-            excludeExportRanges=args.exclude_export_ranges,
-            includeExportRanges=args.include_export_ranges,
-        ),
-        description=args.description,
-        labels=labels,
+        release_track=self.ReleaseTrack()
     )
 
-    op_ref = client.CreateVPCSpoke(spoke_ref, spoke)
+    spoke_ref = args.CONCEPTS.spoke.Parse()
+
+    if self.ReleaseTrack() == base.ReleaseTrack.BETA:
+      labels = labels_util.ParseCreateArgs(
+          args,
+          client.messages.GoogleCloudNetworkconnectivityV1betaSpoke.LabelsValue,
+      )
+
+      spoke = client.messages.GoogleCloudNetworkconnectivityV1betaSpoke(
+          hub=args.hub,
+          group=args.group,
+          linkedVpcNetwork=client.messages.GoogleCloudNetworkconnectivityV1betaLinkedVpcNetwork(
+              uri=args.vpc_network,
+              excludeExportRanges=args.exclude_export_ranges,
+              includeExportRanges=args.include_export_ranges,
+          ),
+          description=args.description,
+          labels=labels,
+      )
+      op_ref = client.CreateSpokeBeta(spoke_ref, spoke)
+    else:
+      labels = labels_util.ParseCreateArgs(
+          args, client.messages.Spoke.LabelsValue
+      )
+
+      spoke = client.messages.Spoke(
+          hub=args.hub,
+          group=args.group,
+          linkedVpcNetwork=client.messages.LinkedVpcNetwork(
+              uri=args.vpc_network,
+              excludeExportRanges=args.exclude_export_ranges,
+              includeExportRanges=args.include_export_ranges,
+          ),
+          description=args.description,
+          labels=labels,
+      )
+      op_ref = client.CreateSpoke(spoke_ref, spoke)
 
     log.status.Print('Create request issued for: [{}]'.format(spoke_ref.Name()))
 
@@ -88,27 +113,33 @@ class Create(base.Command):
     op_resource = resources.REGISTRY.ParseRelativeName(
         op_ref.name,
         collection='networkconnectivity.projects.locations.operations',
-        api_version=networkconnectivity_util.VERSION_MAP[self.ReleaseTrack()])
-    poller = waiter.CloudOperationPoller(client.spoke_service,
-                                         client.operation_service)
+        api_version=networkconnectivity_util.VERSION_MAP[self.ReleaseTrack()],
+    )
+    poller = waiter.CloudOperationPoller(
+        client.spoke_service, client.operation_service
+    )
     res = waiter.WaitFor(
-        poller, op_resource,
-        'Waiting for operation [{}] to complete'.format(op_ref.name))
+        poller,
+        op_resource,
+        'Waiting for operation [{}] to complete'.format(op_ref.name),
+    )
     log.CreatedResource(spoke_ref.Name(), kind='spoke')
     return res
 
-
-Create.detailed_help = {
-    'EXAMPLES':
-        """ \
+UNIVERSE_DOMAIN = properties.VALUES.core.universe_domain.Get()
+DETAILED_HELP = {
+    'EXAMPLES': f""" \
   To create a VPC spoke named ``myspoke'', run:
 
-    $ {command} myspoke --hub="https://www.googleapis.com/networkconnectivity/v1/projects/my-project/locations/global/hubs/my-hub" --global --vpc-network="https://www.googleapis.com/compute/v1/projects/my-project/global/networks/my-vpc"
+    $ {{command}} myspoke --hub=https://www.{UNIVERSE_DOMAIN}/networkconnectivity/v1/projects/my-project/locations/global/hubs/my-hub \
+        --global \
+        --vpc-network=https://www.{UNIVERSE_DOMAIN}/compute/v1/projects/my-project/global/networks/my-vpc
   """,
-    'API REFERENCE':
-        """ \
+    'API REFERENCE': """ \
   This command uses the networkconnectivity/v1 API. The full documentation
   for this API can be found at:
   https://cloud.google.com/network-connectivity/docs/reference/networkconnectivity/rest
   """,
 }
+
+Create.detailed_help = DETAILED_HELP
