@@ -24,6 +24,13 @@ from googlecloudsdk.calliope import base
 @base.DefaultUniverseOnly
 @base.Hidden
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class Attachments(base.Group):
+class AttachmentsAlpha(base.Group):
+  """Manage Secure Access Connect attachments."""
+  category = base.NETWORK_SECURITY_CATEGORY
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class AttachmentsBeta(base.Group):
   """Manage Secure Access Connect attachments."""
   category = base.NETWORK_SECURITY_CATEGORY
