@@ -41,10 +41,11 @@ DETAILED_HELP = {
 class Start(base.Command):
   """Request for starting runtimes."""
 
-  @staticmethod
-  def Args(parser):
+  @classmethod
+  def Args(cls, parser):
     """Register flags for this command."""
-    flags.AddStartRuntimeFlags(parser)
+    api_version = util.ApiVersionSelector(cls.ReleaseTrack())
+    flags.AddStartRuntimeFlags(api_version, parser)
 
   def Run(self, args):
     release_track = self.ReleaseTrack()
