@@ -77,7 +77,7 @@ class Create(base.CreateCommand):
         --cert-output-file=./cert.pem \
         --validity=P30D
 
-    To create a certificate using a client-generated key:
+  To create a certificate using a client-generated key:
 
       $ {command} frontend-server-tls \
         --issuer-pool=my-pool --issuer-location=us-west1 \
@@ -313,7 +313,7 @@ class Create(base.CreateCommand):
     config.publicKey = self.messages.PublicKey()
     config.publicKey.key = public_key
     config.publicKey.format = self.messages.PublicKey.FormatValueValuesEnum.PEM
-    config.subjectConfig = flags.ParseSubjectFlags(args, is_ca=args.is_ca_cert)
+    config.subjectConfig = flags.ParseSubjectFlags(args)
     config.x509Config = flags.ParseX509Parameters(args, is_ca_command=False)
     config.subjectKeyId = flags.ParseSubjectKeyId(args, self.messages)
     return config
