@@ -94,7 +94,10 @@ class Ack(base.Command):
     flags.AddAckIdFlag(parser, 'acknowledge.')
 
   def Run(self, args):
-    result, _ = _Run(args, args.ack_ids)
+    result, ack_ids_and_failure_reasons = _Run(
+        args, args.ack_ids, capture_failures=True)
+    if ack_ids_and_failure_reasons:
+      return ack_ids_and_failure_reasons
     return result
 
 
