@@ -24,7 +24,8 @@ from googlecloudsdk.command_lib.resource_manager import org_policies_base
 from googlecloudsdk.command_lib.resource_manager import org_policies_flags as flags
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class SetPolicy(base.DescribeCommand):
   """Set Organization Policy.
 
@@ -33,6 +34,22 @@ class SetPolicy(base.DescribeCommand):
 
   ## EXAMPLES
 
+  Organization policy list constraint YAML file example:
+
+    constraint: constraints/CONSTRAINT_NAME
+    listPolicy:
+      deniedValues:
+      - VALUE_A
+
+  Organization policy list constraint JSON file example:
+
+    {
+      "constraint": "constraints/CONSTRAINT_NAME",
+      "listPolicy": {
+        "deniedValues": ["VALUE_A"]
+      }
+    }
+
   The following command sets an Organization Policy for a constraint
   on project `foo-project` from file `/tmp/policy.yaml`:
 
