@@ -31,6 +31,7 @@ from googlecloudsdk.command_lib.util.concepts import presentation_specs
 from googlecloudsdk.core.resource import resource_printer
 
 
+@base.UniverseCompatible
 class Describe(base.DescribeCommand):
   """Obtain details about revisions."""
 
@@ -39,9 +40,9 @@ class Describe(base.DescribeCommand):
           {description}
           """,
       'EXAMPLES': """\
-          To describe all revisions of service default in us-central1:
+          To describe a revision `my-service-00001-abc`in us-central1:
 
-              $ {command} --region=us-central1 default
+              $ {command} --region=us-central1 my-service-00001-abc
           """,
   }
 
@@ -58,11 +59,11 @@ class Describe(base.DescribeCommand):
 
     resource_printer.RegisterFormatter(
         revision_printer.REVISION_PRINTER_FORMAT,
-        revision_printer.RevisionPrinter, hidden=True)
+        revision_printer.RevisionPrinter)
     parser.display_info.AddFormat(revision_printer.REVISION_PRINTER_FORMAT)
     resource_printer.RegisterFormatter(
         export_printer.EXPORT_PRINTER_FORMAT,
-        export_printer.ExportPrinter, hidden=True)
+        export_printer.ExportPrinter)
 
   @staticmethod
   def Args(parser):
@@ -77,7 +78,8 @@ class Describe(base.DescribeCommand):
     with serverless_operations.Connect(conn_context) as client:
       wrapped_revision = client.GetRevision(revision_ref)
 
-    if not wrapped_revision:
+    # If the revision is a worker pool revision, we should not show it.
+    if not wrapped_revision or wrapped_revision.worker_pool_name is not None:
       raise exceptions.ArgumentError('Cannot find revision [{}]'.format(
           revision_ref.revisionsId))
     return wrapped_revision
