@@ -33,7 +33,7 @@ from googlecloudsdk.core.console import console_io
 
 
 @base.UniverseCompatible
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class Delete(base.Command):
   """Delete a worker pool revision."""
 
@@ -52,7 +52,7 @@ class Delete(base.Command):
   def CommonArgs(parser):
     revision_presentation = presentation_specs.ResourcePresentationSpec(
         'WORKER_POOL_REVISION',
-        resource_args.GetWorkerPoolRevisionResourceSpec(),
+        resource_args.GetV2WorkerPoolRevisionResourceSpec(prompt=True),
         'Worker pool revision to delete.',
         required=True,
         prefixes=False,
