@@ -15,9 +15,7 @@
 
 """services list command."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
+import sys
 
 from googlecloudsdk.api_lib.services import services_util
 from googlecloudsdk.api_lib.services import serviceusage
@@ -26,14 +24,14 @@ from googlecloudsdk.command_lib.services import common_flags
 
 
 # TODO(b/321801975) make command public after preview.
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.UniverseCompatible
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class ListAlpha(base.ListCommand):
   """List services for a project, folder or organization.
 
-  This command lists the services that are enabled or available (Google first
-  party services) to be enabled
-  by a project, folder or organization. Service enablement can be inherited from
+  This command lists the services that are enabled or available to be enabled
+  by a project, folder or organization. Service enablement and availability can
+  be inherited from
   resource ancestors. A resource's enabled services include services that are
   enabled on the resource itself and enabled on all resource ancestors.
   services by using exactly one of the `--enabled` or `--available` flags.
@@ -45,7 +43,7 @@ class ListAlpha(base.ListCommand):
 
     $ {command} --enabled
 
-  To list the Google first party services the current project can enable for
+  To list the services the current project can enable for
   consumption, run:
 
     $ {command} --available
@@ -74,16 +72,14 @@ class ListAlpha(base.ListCommand):
         '--available',
         action='store_true',
         help=(
-            'Return the Google first party services available to the '
-            'project, folder or organization to enable. This list will '
-            'include any services that the project, folder or organization '
-            'has already enabled.'
+            'Return the services available to the '
+            'project, folder or organization to enable.'
         ),
     )
 
     common_flags.add_resource_args(parser)
 
-    base.PAGE_SIZE_FLAG.SetDefault(parser, 200)
+    base.PAGE_SIZE_FLAG.SetDefault(parser, 1000)
 
     # Remove unneeded list-related flags from parser
     base.URI_FLAG.RemoveFromParser(parser)
@@ -121,26 +117,23 @@ class ListAlpha(base.ListCommand):
       organization = args.organization
     else:
       organization = None
+
     if args.IsSpecified('limit'):
-      return serviceusage.ListServicesV2Alpha(
-          project,
-          args.enabled,
-          args.page_size,
-          args.limit,
-          folder=folder,
-          organization=organization,
-      )
+      limit = args.limit
     else:
-      return serviceusage.ListServicesV2Alpha(
-          project,
-          args.enabled,
-          args.page_size,
-          folder=folder,
-          organization=organization,
-      )
+      limit = sys.maxsize
+
+    return serviceusage.ListServicesV2Beta(
+        project,
+        args.enabled,
+        args.page_size,
+        limit,
+        folder=folder,
+        organization=organization,
+    )
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class List(base.ListCommand):
 
   """List services for a project.
