@@ -13,9 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """services policies get command."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import json
 
@@ -37,9 +34,8 @@ _INVALID_TIMESTAMP = (
 )
 
 
-# TODO(b/321801975) make command public after suv2 launch.
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.UniverseCompatible
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class Get(base.Command):
   """Get consumer policy for a project, folder or organization.
 
@@ -102,7 +98,7 @@ class Get(base.Command):
       project = properties.VALUES.core.project.Get(required=True)
       resource_name = _PROJECT_RESOURCE.format(project)
 
-    policy = serviceusage.GetConsumerPolicyV2Alpha(
+    policy = serviceusage.GetConsumerPolicyV2Beta(
         resource_name + _CONSUMER_POLICY_DEFAULT.format(args.policy_name),
     )
 
@@ -125,6 +121,8 @@ class Get(base.Command):
         log.status.Print(
             'Policy written to the output file %s ' % args.output_file
         )
+    elif args.IsSpecified('format'):
+      return policy
     else:
       result = _ConvertToDict(policy)
       for k, v in result.items():
