@@ -26,6 +26,7 @@ from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.command_lib.spanner import resource_args
 from googlecloudsdk.command_lib.spanner import sql
 from googlecloudsdk.command_lib.spanner.sql import QueryHasDml
+from googlecloudsdk.command_lib.util.apis import arg_utils
 from googlecloudsdk.core import log
 from googlecloudsdk.core import resources
 
@@ -74,13 +75,26 @@ def AddBaseArgs(parser):
       'described at https://cloud.google.com/spanner/docs/query-syntax')
 
   query_mode_choices = {
-      'NORMAL': 'Returns only the query result, without any information about '
-                'the query plan.',
-      'PLAN': 'Returns only the query plan, without any result rows or '
-              'execution statistics information.',
-      'PROFILE':
-          'Returns both the query plan and the execution statistics along '
-          'with the result rows.'
+      'NORMAL': (
+          'Returns only the query result, without any information about '
+          'the query plan.'
+      ),
+      'PLAN': (
+          'Returns only the query plan, without any result rows or '
+          'execution statistics information.'
+      ),
+      'PROFILE': (
+          'Returns the query plan, overall execution statistics, '
+          'operator-level execution statistics, along with the result rows.'
+      ),
+      'WITH_STATS': (
+          'Returns the overall (but not operator-level) execution statistics '
+          'along with the results.'
+      ),
+      'WITH_PLAN_AND_STATS': (
+          'Returns the query plan, overall (but not operator-level) execution '
+          'statistics, along with the results.'
+      ),
   }
 
   parser.add_argument(
@@ -102,6 +116,9 @@ def AddBaseArgs(parser):
       help='Maximum time to wait for the SQL query to complete. See $ gcloud '
            'topic datetimes for information on duration formats.')
 
+  msgs = apis.GetMessagesModule('spanner', 'v1')
+  GetRequestPriorityMapper(msgs).choice_arg.AddToParser(parser)
+
   timestamp_bound_group = parser.add_argument_group(
       mutex=True,
       help='Read-only query timestamp bound. The default is --strong. See '
@@ -119,6 +136,21 @@ def AddBaseArgs(parser):
       help='Database role user assumes while accessing the database.')
 
 
+def GetRequestPriorityMapper(messages):
+  return arg_utils.ChoiceEnumMapper(
+      '--priority',
+      messages.RequestOptions.PriorityValueValuesEnum,
+      custom_mappings={
+          'PRIORITY_LOW': 'low',
+          'PRIORITY_MEDIUM': 'medium',
+          'PRIORITY_HIGH': 'high',
+          'PRIORITY_UNSPECIFIED': 'unspecified',
+      },
+      help_str='The priority for the execute SQL request.',
+  )
+
+
+@base.DefaultUniverseOnly
 @base.UnicodeIsSupported
 class Query(base.Command):
   """Executes a SQL query against a Cloud Spanner database."""
@@ -139,6 +171,10 @@ class Query(base.Command):
     Returns:
       Some value that we want to have printed later.
     """
+    msgs = apis.GetMessagesModule('spanner', 'v1')
+    request_options = msgs.RequestOptions(
+        priority=GetRequestPriorityMapper(msgs).GetEnumForChoice(args.priority)
+    )
     read_only_options = self.ParseReadOnlyOptions(args)
     session = CreateSession(args, args.database_role)
     try:
@@ -147,6 +183,7 @@ class Query(base.Command):
           args.query_mode,
           session,
           read_only_options,
+          request_options,
           args.enable_partitioned_dml,
           args.timeout)
     finally:
@@ -202,18 +239,18 @@ class Query(base.Command):
     Args:
       args: The arguments originally passed to the command.
       result: The output of the command before display.
-
-    Raises:
-      ValueError: The query mode is not valid.
     """
-    if args.query_mode == 'NORMAL':
-      sql.DisplayQueryResults(result, log.out)
-    elif args.query_mode == 'PLAN':
+    display_plan = (
+        args.query_mode == 'PLAN'
+        or args.query_mode == 'PROFILE'
+        or args.query_mode == 'WITH_PLAN_AND_STATS'
+    )
+    display_results = args.query_mode != 'PLAN'
+    if sql.QueryHasAggregateStats(result):
+      sql.DisplayQueryAggregateStats(result.stats.queryStats, log.out)
+    if display_plan:
       sql.DisplayQueryPlan(result, log.out)
-    elif args.query_mode == 'PROFILE':
-      if sql.QueryHasAggregateStats(result):
-        sql.DisplayQueryAggregateStats(result.stats.queryStats, log.out)
-      sql.DisplayQueryPlan(result, log.out)
-      sql.DisplayQueryResults(result, log.status)
-    else:
-      raise ValueError('Invalid query mode: {}'.format(args.query_mode))
+    if display_results:
+      sql.DisplayQueryResults(
+          result, log.status if args.query_mode == 'PROFILE' else log.out
+      )
