@@ -24,19 +24,14 @@ from googlecloudsdk.api_lib.spanner import backup_operations
 from googlecloudsdk.api_lib.spanner import database_operations
 from googlecloudsdk.api_lib.spanner import instance_config_operations
 from googlecloudsdk.api_lib.spanner import instance_operations
+from googlecloudsdk.api_lib.spanner import instance_partition_operations
+from googlecloudsdk.api_lib.spanner import ssd_cache_operations
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.command_lib.spanner import flags
 
-
-@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
-                    base.ReleaseTrack.ALPHA)
-class Describe(base.DescribeCommand):
-  """Describe a Cloud Spanner operation."""
-
-  detailed_help = {
-      'EXAMPLES':
-          textwrap.dedent("""\
+DETAILED_HELP = {
+    'EXAMPLES': textwrap.dedent("""\
         To describe a Cloud Spanner instance operation, run:
 
           $ {command} _auto_12345 --instance=my-instance-id
@@ -50,8 +45,20 @@ class Describe(base.DescribeCommand):
 
           $ {command}  _auto_12345 --instance=my-instance-id
               --backup=my-backup-id
+
+        To describe an instance partition operation, run:
+
+          $ {command} _auto_12345 --instance=my-instance-id --instance-partition=my-partition-id
         """),
-  }
+}
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.GA)
+class Describe(base.DescribeCommand):
+  """Describe a Cloud Spanner operation."""
+
+  detailed_help = DETAILED_HELP
 
   @staticmethod
   def Args(parser):
@@ -91,11 +98,9 @@ class Describe(base.DescribeCommand):
       return instance_config_operations.Get(args.instance_config,
                                             args.operation)
 
-    # Checks that user only specified either database or backup flag.
-    if (args.IsSpecified('database') and args.IsSpecified('backup')):
-      raise c_exceptions.InvalidArgumentException(
-          '--database or --backup',
-          'Must specify either --database or --backup.')
+    # Checks that user only specified database or backup or instance partition
+    # flag.
+    flags.CheckExclusiveLROFlagsUnderInstance(args)
 
     if args.backup:
       return backup_operations.Get(args.instance, args.backup, args.operation)
@@ -103,5 +108,79 @@ class Describe(base.DescribeCommand):
     if args.database:
       return database_operations.Get(args.instance, args.database,
                                      args.operation)
+    if args.instance_partition:
+      return instance_partition_operations.Get(
+          args.instance, args.instance_partition, args.operation
+      )
 
     return instance_operations.Get(args.instance, args.operation)
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class BetaDescribe(Describe):
+  """Describe a Cloud Spanner operation."""
+
+  detailed_help = {
+      'EXAMPLES': DETAILED_HELP['EXAMPLES'] + textwrap.dedent("""\
+        """),
+  }
+
+  @staticmethod
+  def Args(parser):
+    """Args is called by calliope to gather arguments for this command.
+
+    Please add arguments in alphabetical order except for no- or a clear-
+    pair for that argument which can follow the argument itself.
+    Args:
+      parser: An argparse parser that you can use to add arguments that go on
+        the command line after this command. Positional arguments are allowed.
+    """
+    super(BetaDescribe, BetaDescribe).Args(parser)
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class AlphaDescribe(BetaDescribe):
+  """Describe a Cloud Spanner operation."""
+
+  @staticmethod
+  def Args(parser):
+    """Args is called by calliope to gather arguments for this command.
+
+    Please add arguments in alphabetical order except for no- or a clear-
+    pair for that argument which can follow the argument itself.
+    Args:
+      parser: An argparse parser that you can use to add arguments that go on
+        the command line after this command. Positional arguments are allowed.
+    """
+    super(AlphaDescribe, AlphaDescribe).Args(parser)
+
+    flags.SsdCache(
+        positional=False,
+        required=False,
+        hidden=True,
+        text='The ID of the SSD Cache the operation is executing on.',
+    ).AddToParser(parser)
+
+  def Run(self, args):
+    """This is what gets called when the user runs this command.
+
+    Args:
+      args: an argparse namespace. All the arguments that were provided to this
+        command invocation.
+
+    Returns:
+      Some value that we want to have printed later.
+    """
+    if args.ssd_cache:
+      if args.instance:
+        raise c_exceptions.InvalidArgumentException(
+            '--instance or --ssd-cache',
+            'The `--instance` flag cannot be used with `--ssd-cache`.',
+        )
+      return ssd_cache_operations.Get(
+          args.operation, args.ssd_cache, args.instance_config
+      )
+
+    return super().Run(args)
