@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2013 Google Inc. All Rights Reserved.
+# Copyright 2013 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,28 +27,32 @@ from apitools.base.py import list_pager
 from googlecloudsdk.api_lib.sql import api_util
 from googlecloudsdk.api_lib.sql import validate
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.sql import filter_rewrite
 from googlecloudsdk.command_lib.sql import flags
+from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 
 
+@base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
                     base.ReleaseTrack.ALPHA)
 class List(base.ListCommand):
-  """Lists all backups associated with a given instance.
+  """Lists all backups associated with the project or a given instance.
 
-  Lists all backups associated with a given Cloud SQL instance and
-  configuration in the reverse chronological order of the enqueued time.
+  Lists all backups associated with the project or a given Cloud SQL instance
+  and configuration in the reverse chronological order of the enqueued time.
   """
 
   @staticmethod
   def Args(parser):
-    flags.AddInstance(parser)
+    flags.AddOptionalInstance(parser, True)
     parser.display_info.AddFormat("""
       table(
         id,
         windowStartTime.iso(),
         error.code.yesno(no="-"):label=ERROR,
-        status
+        status,
+        instance
       )
     """)
     parser.display_info.AddCacheUpdater(None)
@@ -69,6 +73,43 @@ class List(base.ListCommand):
     sql_client = client.sql_client
     sql_messages = client.sql_messages
 
+    if not args.instance:
+      # For project-level backups, this command updates the output table.
+      # pylint:disable-next=protected-access
+      args._GetParser().ai.display_info.AddFormat("""table(
+            name,
+            backupInterval.startTime.iso():label=WINDOW_START_TIME,
+            error.errors[0].code.yesno(no="-"):label=ERROR,
+            state:label=STATE,
+            instance,
+            type,
+            instanceDeletionTime.iso(undefined='-'):label=INSTANCE_DELETION_TIME
+          )""")
+
+      args.filter, server_filter = filter_rewrite.Backend().Rewrite(
+          args.filter)
+
+      if args.filter:
+        log.info('client_filter: %s', args.filter)
+
+      if server_filter:
+        log.info('server_filter: %s', server_filter)
+
+      return list_pager.YieldFromList(
+          sql_client.backups,
+          sql_messages.SqlBackupsListBackupsRequest(
+              parent='projects/{0}'.format(
+                  properties.VALUES.core.project.GetOrFail()
+              ),
+              filter=server_filter,
+          ),
+          limit=args.limit,
+          batch_size=args.page_size,
+          batch_size_attribute='pageSize',
+          method='ListBackups',
+          field='backups',
+      )
+
     validate.ValidateInstanceName(args.instance)
     instance_ref = client.resource_parser.Parse(
         args.instance,
@@ -78,5 +119,4 @@ class List(base.ListCommand):
     return list_pager.YieldFromList(
         sql_client.backupRuns,
         sql_messages.SqlBackupRunsListRequest(
-            project=instance_ref.project, instance=instance_ref.instance),
-        limit=args.limit)
+            project=instance_ref.project, instance=instance_ref.instance))
