@@ -139,6 +139,7 @@ def AddBaseArgs(parser):
   flags.AddThreadsPerCore(parser)
   flags.AddCascadableReplica(parser)
   flags.AddEnableDataCache(parser)
+  flags.AddEnableAutoUpgrade(parser)
   flags.AddRecreateReplicasOnPrimaryCrash(parser)
   psc_setup_group = parser.add_group()
   flags.AddEnablePrivateServiceConnect(psc_setup_group)
@@ -156,7 +157,17 @@ def AddBaseArgs(parser):
   flags.AddStorageProvisionedThroughput(parser)
   flags.AddInstanceType(parser)
   flags.AddNodeCount(parser)
+  flags.AddActiveDirectoryMode(parser)
+  flags.AddActiveDirectorySecretManagerKey(parser)
+  flags.AddActiveDirectoryOrganizationalUnit(parser)
+  flags.AddActiveDirectoryDNSServers(parser)
+  flags.ClearActiveDirectoryDNSServers(parser)
   flags.AddForceSqlNetworkArchitecture(parser)
+  flags.AddFinalBackup(parser)
+  flags.AddFinalbackupRetentionDays(parser)
+  flags.AddEnableConnectionPooling(parser)
+  flags.AddConnectionPoolFlags(parser)
+  flags.AddReadPoolAutoScaleConfig(parser)
 
   # When adding a new field for instance creation, determine if it should also
   # be included in the restore to new instance command. This command uses backup
@@ -172,12 +183,13 @@ def AddBetaArgs(parser):
   flags.AddAllocatedIpRangeName(parser)
   labels_util.AddCreateLabelsFlags(parser)
   flags.AddReplicationLagMaxSecondsForRecreate(parser)
-  flags.AddEnableConnectionPooling(parser)
-  flags.AddConnectionPoolFlags(parser)
   flags.AddEnableDbAlignedAtomicWrites(parser)
-  flags.AddFinalBackup(parser)
-  flags.AddFinalbackupRetentionDays(parser, hidden=True)
   flags.AddEnableAcceleratedReplicaMode(parser)
+  flags.AddDataApiAccess(parser)
+  flags.AddServerCertificateRotationMode(parser)
+  flags.AddPerformanceCaptureConfig(parser, hidden=True)
+  flags.AddUncMappings(parser)
+  flags.AddSqlServerEntraId(parser, hidden=True)
 
 
 def AddAlphaArgs(unused_parser):
@@ -375,6 +387,15 @@ def RunBaseCreateCommand(args, release_track):
         ' for more details.'
     )
 
+  if (
+      args.IsKnownAndSpecified('performance_capture_config')
+      and args.IsSpecified('database_version')
+      and not args.database_version.startswith('MYSQL')
+  ):
+    raise sql_exceptions.ArgumentError(
+        '`--performance-capture-config` is only supported for MySQL.'
+    )
+
   if args.IsSpecified('edition') and args.edition == 'enterprise-plus':
     # This logic is awkward because we only want to change behavior for "new"
     # database types to avoid breaking changes.
