@@ -122,8 +122,6 @@ class Cat(base.Command):
     flags.add_encryption_flags(parser, command_only_reads_data=True)
 
   def Run(self, args):
-    # TODO(b/190541521):  Determine if command group works with project number
-    base.RequireProjectID(args)
 
     encryption_util.initialize_key_store(args)
     if args.url:
