@@ -25,6 +25,9 @@ from googlecloudsdk.command_lib.storage import flags
 _COMMAND_DESCRIPTION = """
 Copy data between your local file system and the cloud, within the cloud,
 and between cloud storage providers.
+
+Please Note - By default, the `cp` command does not follow directory symlinks.
+You can use the `--preserve-symlinks` flag to follow directory symlinks.
 """
 _GA_EXAMPLES = """
 The following command uploads all text files from the local directory to a
@@ -60,6 +63,13 @@ would be copied in the following.
   $ {command} ~/Downloads/**/dir gs://my-bucket
 """
 _ALPHA_EXAMPLES = """
+The contexts are preserved when copying to Google Cloud Storage. To overwrite
+contexts on the destination object, use `--custom-contexts` or
+`--custom-contexts-file`. For example:
+
+  $ {command} gs://my-bucket/object \
+    gs://destination-bucket/object \
+    --custom-contexts=key1=value1,key2=value2
 """
 
 
