@@ -72,6 +72,11 @@ structure:
   $ {command} gs://my_bucket/oldprefix gs://my_bucket/newprefix
 """
 _ALPHA_EXAMPLES = """
+The following command would clear all custom contexts from the destination
+object while moving the object to the destination bucket.
+
+  $ {command} gs://my-bucket/object gs://destination-bucket/object \
+      --clear-custom-contexts
 """
 
 
