@@ -14,12 +14,10 @@
 # limitations under the License.
 """'vmware locations list' command."""
 
-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-
 from googlecloudsdk.api_lib.vmware.locations import LocationsClient
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.vmware import flags
@@ -38,8 +36,8 @@ DETAILED_HELP = {
 }
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class ListAlpha(base.ListCommand):
+@base.ReleaseTracks(base.ReleaseTrack.GA)
+class List(base.ListCommand):
   """List Google Cloud VMware Engine locations."""
 
   detailed_help = DETAILED_HELP
@@ -57,10 +55,4 @@ class ListAlpha(base.ListCommand):
   def Run(self, args):
     project = args.CONCEPTS.project.Parse()
     client = LocationsClient()
-    return client.List(project, limit=args.limit)
-
-
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
-class ListBeta(ListAlpha):
-  """List Google Cloud VMware Engine locations."""
+    return client.List(project)
