@@ -97,7 +97,7 @@ class Create(base.CreateCommand):
       workstations_flags.AddBoostConfigs(parser)
       workstations_flags.AddDisableLocalhostReplacementFlag(parser)
       workstations_flags.AddReservationAffinity(parser)
-      workstations_flags.AddStartUpScriptUri(parser)
+      workstations_flags.AddStartupScriptUri(parser)
 
   def Collection(self):
     return (
