@@ -724,6 +724,7 @@ class Update(bigquery_command.BigqueryCmd):
         ]),
         flag_values=fv,
     )
+
     self._ProcessCommandRc(fv)
 
   def printSuccessMessage(self, object_name: str, reference: Any):
@@ -842,10 +843,6 @@ class Update(bigquery_command.BigqueryCmd):
           )
           print(object_info)
         else:
-          if self.max_slots is not None or self.scaling_mode is not None:
-            utils_flags.fail_if_not_using_alpha_feature(
-                bq_flags.AlphaFeatures.RESERVATION_MAX_SLOTS
-            )
           if self.reservation_group_name is not None:
             utils_flags.fail_if_not_using_alpha_feature(
                 bq_flags.AlphaFeatures.RESERVATION_GROUPS
@@ -1185,7 +1182,6 @@ class Update(bigquery_command.BigqueryCmd):
           self.range_partitioning
       )
       clustering = frontend_utils.ParseClustering(self.clustering_fields)
-
       encryption_configuration = None
       if self.destination_kms_key:
         encryption_configuration = {'kmsKeyName': self.destination_kms_key}
@@ -1270,7 +1266,6 @@ class Update(bigquery_command.BigqueryCmd):
         )
         client_data_transfer.update_transfer_config(
             transfer_client=client.GetTransferV1ApiClient(),
-            apiclient=client.apiclient,
             id_fallbacks=client,
             reference=reference,
             target_dataset=self.target_dataset,
