@@ -6,7 +6,9 @@ import datetime
 import json
 import sys
 import time
-from typing import Dict, List, Optional, Type
+from typing import Any, Dict, List, Optional, Tuple, Type, Union, cast
+
+from typing_extensions import TypeAlias
 
 import table_formatter
 import bq_flags
@@ -118,8 +120,8 @@ def maybe_print_manual_instructions_for_connection(
       'federatedApplicationClientId'
   ):
     obj = {
-        'federatedApplicationClientId': connection['azure'].get(
-            'federatedApplicationClientId'
+        'federatedApplicationClientId': (
+            connection['azure'].get('federatedApplicationClientId')
         ),
         'identity': connection['azure'].get('identity'),
     }
@@ -219,21 +221,36 @@ def format_time_from_proto_timestamp_json_string(json_string: str) -> str:
   return format_time(seconds)
 
 
-def format_acl(acl):
+StringReference: TypeAlias = str  # eg. 'project:dataset.routine'
+ResourceType: TypeAlias = str  # eg. 'ROUTINE' or 'All ROUTINES in DATASET'
+# Conditions is used as a key for the dictionary of ACL entries that is printed.
+# eg. (('title', 'Expires_2024'),
+# ('description', 'Expires at noon on 2024-12-31'),
+# ('expression', "request.time <timestamp('2024-12-31T12:00:00Z')"))
+Conditions: TypeAlias = Tuple[Tuple[str, str], Tuple[str, str], Tuple[str, str]]
+ResourceTypeAndConditions: TypeAlias = Tuple[ResourceType, Conditions]
+DatasetAccess: TypeAlias = List[Dict[str, Union[Dict[str, str], str]]]
+
+
+def format_acl(acl: DatasetAccess) -> str:
   """Format a server-returned ACL for printing."""
-  acl_entries = collections.defaultdict(list)
+
+  acl_entries: Dict[ResourceTypeAndConditions, List[StringReference]] = (
+      collections.defaultdict(list)
+  )
   for entry in acl:
     entry = entry.copy()
-    view = entry.pop('view', None)
-    dataset = entry.pop('dataset', None)
-    routine = entry.pop('routine', None)
+    view = cast(Dict[str, str], entry.pop('view', None))
+    dataset = cast(Dict[str, Dict[str, str]], entry.pop('dataset', None))
+    routine = cast(Dict[str, str], entry.pop('routine', None))
+    role = cast(str, entry.pop('role', None))
     if view:
       acl_entries['VIEW', ()].append(
           '%s:%s.%s'
           % (view.get('projectId'), view.get('datasetId'), view.get('tableId'))
       )
     elif dataset:
-      dataset_reference = dataset.get('dataset')
+      dataset_reference = cast(Dict[str, str], dataset.get('dataset'))
       for target in dataset.get('targetTypes'):
         acl_entries['All ' + target + ' in DATASET', ()].append(
             '%s:%s'
@@ -243,17 +260,15 @@ def format_acl(acl):
             )
         )
     elif routine:
-      acl_entries['ROUTINE', ()].append(
-          '%s:%s.%s'
-          % (
-              routine.get('projectId'),
-              routine.get('datasetId'),
-              routine.get('routineId'),
-          )
+      routine_reference = str(
+          bq_id_utils.ApiClientHelper.RoutineReference(**routine)
       )
+      if role:
+        acl_entries[role, ()].append('ROUTINE: %s' % routine_reference)
+      else:
+        acl_entries['ROUTINE', ()].append(routine_reference)
     else:
-      role = entry.pop('role', None)
-      condition = entry.pop('condition', None)
+      condition = cast(Dict[str, str], entry.pop('condition', None))
       if not role or len(list(entry.values())) != 1:
         raise bq_error.BigqueryInterfaceError(
             'Invalid ACL returned by server: %s' % acl, {}, []
@@ -483,8 +498,20 @@ def configure_formatter(
             'File URIs',
             'Archive URIs',
         ))
+      if 'pythonOptions' in object_info:
+        formatter.AddColumns((
+            'Entry Point',
+            'Packages',
+        ))
+      if 'externalRuntimeOptions' in object_info:
+        formatter.AddColumns((
+            'Connection',
+            'Runtime Version',
+            'Container Memory',
+            'Container CPU',
+        ))
   elif reference_type == bq_id_utils.ApiClientHelper.RowAccessPolicyReference:
-    if print_format == 'list':
+    if print_format == 'list' or print_format == 'show':
       formatter.AddColumns((
           'Id',
           'Filter Predicate',
@@ -568,15 +595,18 @@ def configure_formatter(
         'updateTime',
         'multiRegionAuxiliary',
         'edition',
+        'autoscaleMaxSlots',
+        'autoscaleCurrentSlots',
+        'maxSlots',
+        'scalingMode',
     )
-    final_columns = None
-    if not final_columns:
-      final_columns = (
+    # TODO(b/426869105): Remove alpha flag after GA.
+    if bq_flags.AlphaFeatures.RESERVATION_GROUPS in bq_flags.ALPHA.value:
+      shared_columns = (
           *shared_columns,
-          'autoscaleMaxSlots',
-          'autoscaleCurrentSlots',
+          'reservationGroup',
       )
-    formatter.AddColumns(final_columns)
+    formatter.AddColumns(shared_columns)
   elif (
       reference_type == bq_id_utils.ApiClientHelper.CapacityCommitmentReference
   ):
@@ -597,6 +627,8 @@ def configure_formatter(
       == bq_id_utils.ApiClientHelper.ReservationAssignmentReference
   ):
     formatter.AddColumns(('name', 'jobType', 'assignee'))
+  elif reference_type == bq_id_utils.ApiClientHelper.ReservationGroupReference:
+    formatter.AddColumns(('name',))
   elif reference_type == bq_id_utils.ApiClientHelper.ConnectionReference:
     formatter.AddColumns((
         'name',
@@ -649,6 +681,10 @@ def format_info_by_type(
       object_type, bq_id_utils.ApiClientHelper.ReservationAssignmentReference
   ):
     return format_reservation_assignment_info(object_info)
+  elif issubclass(
+      object_type, bq_id_utils.ApiClientHelper.ReservationGroupReference
+  ):
+    return format_reservation_group_info(object_info)
   elif object_type == bq_id_utils.ApiClientHelper.ConnectionReference:
     return format_connection_info(object_info)
   else:
@@ -918,6 +954,28 @@ def format_routine_info(routine_info):
     result['User Defined Context'] = routine_info['remoteFunctionOptions'].get(
         'userDefinedContext', ''
     )
+  if 'pythonOptions' in routine_info:
+    result['Entry Point'] = routine_info['pythonOptions']['entryPoint']
+    result['Packages'] = routine_info['pythonOptions'].get('packages')
+    # if 'pythonOptions' is present, the routine is guaranteed to be a pythonUDF
+    # and 'importedLibraries' value is used for imported .py library files.
+    result['Libraries'] = routine_info.get('importedLibraries')
+  if 'externalRuntimeOptions' in routine_info:
+    result['Runtime Version'] = routine_info['externalRuntimeOptions'].get(
+        'runtimeVersion'
+    )
+    result['Container Memory'] = routine_info['externalRuntimeOptions'].get(
+        'containerMemory'
+    )
+    result['Container CPU'] = routine_info['externalRuntimeOptions'].get(
+        'containerCpu'
+    )
+    result['Connection'] = routine_info['externalRuntimeOptions'].get(
+        'runtimeConnection'
+    )
+    result['Max Batching Rows'] = routine_info['externalRuntimeOptions'].get(
+        'maxBatchingRows'
+    )
   if 'sparkOptions' in routine_info:
     spark_options = routine_info['sparkOptions']
     options = [
@@ -1230,6 +1288,34 @@ def format_reservation_info(
   return result
 
 
+def format_reservation_group_info(
+    reservation_group: Dict[str, Any],
+) -> Dict[str, Any]:
+  """Prepare a reservation group for printing.
+
+  Arguments:
+    reservation_group: reservation group to format.
+
+  Returns:
+    A dictionary of reservation group properties.
+  """
+  result = {}
+  for key, value in reservation_group.items():
+    if key == 'name':
+      project_id, location, reservation_group_id = (
+          bq_client_utils.ParseReservationGroupPath(value)
+      )
+      reference = bq_id_utils.ApiClientHelper.ReservationGroupReference.Create(
+          projectId=project_id,
+          location=location,
+          reservationGroupId=reservation_group_id,
+      )
+      result[key] = reference.__str__()
+    else:
+      result[key] = value
+  return result
+
+
 def format_capacity_commitment_info(capacity_commitment):
   """Prepare a capacity commitment for printing.
 
@@ -1304,8 +1390,8 @@ def format_connection_info(connection):
   result = {}
   for key, value in connection.items():
     if key == 'name':
-      project_id, location, connection_id = (
-          bq_client_utils.ParseConnectionPath(value)
+      project_id, location, connection_id = bq_client_utils.ParseConnectionPath(
+          value
       )
       reference = bq_id_utils.ApiClientHelper.ConnectionReference.Create(
           projectId=project_id, location=location, connectionId=connection_id
