@@ -44,6 +44,12 @@ try:
 except ImportError:
   HAS_OPENSSL = False
 
+try:
+  import cryptography
+  HAS_CRYPTO = True
+except ImportError:
+  HAS_CRYPTO = False
+
 ERROR_MESSAGE = "This is the error message"
 
 
@@ -74,8 +80,10 @@ def getBotoCredentialsConfig(
 class TestGcsJsonCredentials(testcase.GsUtilUnitTestCase):
   """Test logic for interacting with GCS JSON Credentials."""
 
-  @unittest.skipUnless(HAS_OPENSSL, 'signurl requires pyopenssl.')
-  def testOauth2ServiceAccountCredential(self):
+  @mock.patch.object(gcs_json_credentials.P12Credentials,
+                     "from_service_account_pkcs12_keystring",
+                     return_value=gcs_json_credentials.P12Credentials(mock.Mock(), token_uri='123', service_account_email='123', scopes=['a', 'b']))
+  def testOauth2ServiceAccountCredential(self, _):
     contents = pkgutil.get_data("gslib", "tests/test_data/test.p12")
     tmpfile = self.CreateTempFile(contents=contents)
     with SetBotoConfigForTest(
@@ -85,10 +93,17 @@ class TestGcsJsonCredentials(testcase.GsUtilUnitTestCase):
         })):
       self.assertTrue(gcs_json_credentials._HasOauth2ServiceAccountCreds())
       client = gcs_json_api.GcsJsonApi(None, None, None, None)
-      self.assertIsInstance(client.credentials, ServiceAccountCredentials)
+      self.assertEqual(client.credentials.service_account_email, '123')
+      self.assertIsInstance(client.credentials, gcs_json_credentials.P12Credentials)
 
-  @unittest.skipUnless(HAS_OPENSSL, 'signurl requires pyopenssl.')
-  @mock.patch.object(ServiceAccountCredentials,
+  def testP12CredentialsthrowsErrorIfProvidedWithMissingFields(self):
+    contents = pkgutil.get_data("gslib", "tests/test_data/test.p12")
+    tmpfile = self.CreateTempFile(contents=contents)
+    with self.assertRaises(Exception) as exc:
+      gcs_json_credentials.CreateP12ServiceAccount(tmpfile)
+
+  @unittest.skipUnless(HAS_CRYPTO, 'p12credentials requires cryptography.')
+  @mock.patch.object(gcs_json_credentials.P12Credentials,
                      "__init__",
                      side_effect=ValueError(ERROR_MESSAGE))
   def testOauth2ServiceAccountFailure(self, _):
